## Amy Tanner: 27/08/2015. This R code corresponds to the analysis in: 
## Tanner, A.L., Leroux, S.J., and Saunders, P. W. [submitted]. Road characteristics best predict the probability of vehicle collisions with a non-native, hyperabundant ungulate.

## Clear the workspace
rm(list=ls(all=TRUE))

## New dataset required
spatialallcorr<-read.table("E:/Spatial Analysis Work/Exported Data/spatialallcorr.csv", header=T, sep=",")
print(spatialallcorr)

## cor.test(vegdata$x, vegdata$y)
## Used to get cor, t, and p-values for Pearson's and rho, s, and p-values for Spearman's correlation
## considered correlated if cor or rho value was >|0.5|

## Travel Corridor Based Models (Distance) 
cor.test(spatialallcorr$DisFAR_m, spatialallcorr$DisRW_m, method="pearson")
cor.test(spatialallcorr$DisFAR_m, spatialallcorr$DisTL_m, method="pearson")
cor.test(spatialallcorr$DisFAR_m, spatialallcorr$DisTR_m, method="pearson")
cor.test(spatialallcorr$DisRW_m, spatialallcorr$DisTL_m, method="pearson")
cor.test(spatialallcorr$DisRW_m, spatialallcorr$DisTR_m, method="pearson")
cor.test(spatialallcorr$DisTL_m, spatialallcorr$DisTR_m, method="pearson")

## Water Feature Based Models
cor.test(spatialallcorr$DisRiv_m, spatialallcorr$DisWet_m, method="pearson")
cor.test(spatialallcorr$DisRiv_m, spatialallcorr$DisOcn_m, method="pearson")
cor.test(spatialallcorr$DisRiv_m, spatialallcorr$DisLak_m, method="pearson")
cor.test(spatialallcorr$DisWet_m, spatialallcorr$DisOcn_m, method="pearson")
cor.test(spatialallcorr$DisWet_m, spatialallcorr$DisLak_m, method="pearson")
cor.test(spatialallcorr$DisOcn_m, spatialallcorr$DisLak_m, method="pearson")

## Terrain Based Models 
cor.test(spatialallcorr$TerrRugg500, spatialallcorr$Aspect, method="pearson")
cor.test(spatialallcorr$TerrRugg500, spatialallcorr$Slope_mean500, method="pearson")
cor.test(spatialallcorr$Aspect, spatialallcorr$Slope_mean500, method="pearson")
cor.test(spatialallcorr$TerrRugg2736, spatialallcorr$Aspect, method="pearson")
cor.test(spatialallcorr$TerrRugg2736, spatialallcorr$Slope_mean2736, method="pearson")
cor.test(spatialallcorr$Aspect, spatialallcorr$Slope_mean2736, method="pearson")
cor.test(spatialallcorr$TerrRugg5471, spatialallcorr$Aspect, method="pearson")
cor.test(spatialallcorr$TerrRugg5471, spatialallcorr$Slope_mean5471, method="pearson")
cor.test(spatialallcorr$Aspect, spatialallcorr$Slope_mean5471, method="pearson")

## Disturbance/ Road Based Models
cor.test(spatialallcorr$RdClass, spatialallcorr$Sinuosity, method="spearman")
cor.test(spatialallcorr$RdClass, spatialallcorr$DisMA_m, method="spearman")
cor.test(spatialallcorr$RdClass, spatialallcorr$DisDevA_m, method="spearman")
cor.test(spatialallcorr$RdClass, spatialallcorr$DisDevL_m, method="spearman")
cor.test(spatialallcorr$RdClass, spatialallcorr$DisDevM_m, method="spearman")
cor.test(spatialallcorr$RdClass, spatialallcorr$DisDevS_m, method="spearman")
cor.test(spatialallcorr$Sinuosity, spatialallcorr$DisMA_m, method="pearson")
cor.test(spatialallcorr$Sinuosity, spatialallcorr$DisDevA_m, method="pearson")
cor.test(spatialallcorr$Sinuosity, spatialallcorr$DisDevL_m, method="pearson")
cor.test(spatialallcorr$Sinuosity, spatialallcorr$DisDevM_m, method="pearson")
cor.test(spatialallcorr$Sinuosity, spatialallcorr$DisDevS_m, method="pearson")
cor.test(spatialallcorr$DisMA_m, spatialallcorr$DisDevA_m, method="pearson")
cor.test(spatialallcorr$DisMA_m, spatialallcorr$DisDevL_m, method="pearson")
cor.test(spatialallcorr$DisMA_m, spatialallcorr$DisDevM_m, method="pearson")
cor.test(spatialallcorr$DisMA_m, spatialallcorr$DisDevS_m, method="pearson")
cor.test(spatialallcorr$DisDevA_m, spatialallcorr$DisDevL_m, method="pearson")
cor.test(spatialallcorr$DisDevA_m, spatialallcorr$DisDevM_m, method="pearson")
cor.test(spatialallcorr$DisDevA_m, spatialallcorr$DisDevS_m, method="pearson")
cor.test(spatialallcorr$DisDevL_m, spatialallcorr$DisDevM_m, method="pearson")
cor.test(spatialallcorr$DisDevL_m, spatialallcorr$DisDevS_m, method="pearson")
cor.test(spatialallcorr$DisDevM_m, spatialallcorr$DisDevS_m, method="pearson")

## Travel Corridor Based Models (Density)
cor.test(spatialallcorr$DenFAR500, spatialallcorr$DenRW500, method="pearson")
cor.test(spatialallcorr$DenFAR500, spatialallcorr$DenTL500, method="pearson")
cor.test(spatialallcorr$DenFAR500, spatialallcorr$DenTR500, method="pearson")
cor.test(spatialallcorr$DenRW500, spatialallcorr$DenTL500, method="pearson")
cor.test(spatialallcorr$DenRW500, spatialallcorr$DenTR500, method="pearson")
cor.test(spatialallcorr$DenTL500, spatialallcorr$DenTR500, method="pearson")
cor.test(spatialallcorr$DenFAR2736, spatialallcorr$DenRW2736, method="pearson")
cor.test(spatialallcorr$DenFAR2736, spatialallcorr$DenTL2736, method="pearson")
cor.test(spatialallcorr$DenFAR2736, spatialallcorr$DenTR2736, method="pearson")
cor.test(spatialallcorr$DenRW2736, spatialallcorr$DenTL2736, method="pearson")
cor.test(spatialallcorr$DenRW2736, spatialallcorr$DenTR2736, method="pearson")
cor.test(spatialallcorr$DenTL2736, spatialallcorr$DenTR2736, method="pearson")
cor.test(spatialallcorr$DenFAR5471, spatialallcorr$DenRW5471, method="pearson")
cor.test(spatialallcorr$DenFAR5471, spatialallcorr$DenTL5471, method="pearson")
cor.test(spatialallcorr$DenFAR5471, spatialallcorr$DenTR5471, method="pearson")
cor.test(spatialallcorr$DenRW5471, spatialallcorr$DenTL5471, method="pearson")
cor.test(spatialallcorr$DenRW5471, spatialallcorr$DenTR5471, method="pearson")
cor.test(spatialallcorr$DenTL5471, spatialallcorr$DenTR5471, method="pearson")

## Composition Based Models 
cor.test(spatialallcorr$PropDecid500, spatialallcorr$PropConif500, method="pearson")
cor.test(spatialallcorr$PropDecid500, spatialallcorr$PropWater500, method="pearson")
cor.test(spatialallcorr$PropDecid500, spatialallcorr$PropDev500, method="pearson")
cor.test(spatialallcorr$PropDecid500, spatialallcorr$PropGrass500, method="pearson")
cor.test(spatialallcorr$PropDecid500, spatialallcorr$PropShrub500, method="pearson")
cor.test(spatialallcorr$PropDecid500, spatialallcorr$PropBare500, method="pearson")
cor.test(spatialallcorr$PropConif500, spatialallcorr$PropWater500, method="pearson")
cor.test(spatialallcorr$PropConif500, spatialallcorr$PropDev500, method="pearson")
cor.test(spatialallcorr$PropConif500, spatialallcorr$PropGrass500, method="pearson")
cor.test(spatialallcorr$PropConif500, spatialallcorr$PropShrub500, method="pearson")
cor.test(spatialallcorr$PropConif500, spatialallcorr$PropBare500, method="pearson")
cor.test(spatialallcorr$PropWater500, spatialallcorr$PropDev500, method="pearson")
cor.test(spatialallcorr$PropWater500, spatialallcorr$PropGrass500, method="pearson")
cor.test(spatialallcorr$PropWater500, spatialallcorr$PropShrub500, method="pearson")
cor.test(spatialallcorr$PropWater500, spatialallcorr$PropBare500, method="pearson")
cor.test(spatialallcorr$PropDev500, spatialallcorr$PropGrass500, method="pearson")
cor.test(spatialallcorr$PropDev500, spatialallcorr$PropShrub500, method="pearson")
cor.test(spatialallcorr$PropDev500, spatialallcorr$PropBare500, method="pearson")
cor.test(spatialallcorr$PropGrass500, spatialallcorr$PropShrub500, method="pearson")
cor.test(spatialallcorr$PropGrass500, spatialallcorr$PropBare500, method="pearson")
cor.test(spatialallcorr$PropShrub500, spatialallcorr$PropBare500, method="pearson")
cor.test(spatialallcorr$PropDecid2736, spatialallcorr$PropConif2736, method="pearson")
cor.test(spatialallcorr$PropDecid2736, spatialallcorr$PropWater2736, method="pearson")
cor.test(spatialallcorr$PropDecid2736, spatialallcorr$PropDev2736, method="pearson")
cor.test(spatialallcorr$PropDecid2736, spatialallcorr$PropGrass2736, method="pearson")
cor.test(spatialallcorr$PropDecid2736, spatialallcorr$PropShrub2736, method="pearson")
cor.test(spatialallcorr$PropDecid2736, spatialallcorr$PropBare2736, method="pearson")
cor.test(spatialallcorr$PropConif2736, spatialallcorr$PropWater2736, method="pearson")
cor.test(spatialallcorr$PropConif2736, spatialallcorr$PropDev2736, method="pearson")
cor.test(spatialallcorr$PropConif2736, spatialallcorr$PropGrass2736, method="pearson")
cor.test(spatialallcorr$PropConif2736, spatialallcorr$PropShrub2736, method="pearson")
cor.test(spatialallcorr$PropConif2736, spatialallcorr$PropBare2736, method="pearson")
cor.test(spatialallcorr$PropWater2736, spatialallcorr$PropDev2736, method="pearson")
cor.test(spatialallcorr$PropWater2736, spatialallcorr$PropGrass2736, method="pearson")
cor.test(spatialallcorr$PropWater2736, spatialallcorr$PropShrub2736, method="pearson")
cor.test(spatialallcorr$PropWater2736, spatialallcorr$PropBare2736, method="pearson")
cor.test(spatialallcorr$PropDev2736, spatialallcorr$PropGrass2736, method="pearson")
cor.test(spatialallcorr$PropDev2736, spatialallcorr$PropShrub2736, method="pearson")
cor.test(spatialallcorr$PropDev2736, spatialallcorr$PropBare2736, method="pearson")
cor.test(spatialallcorr$PropGrass2736, spatialallcorr$PropShrub2736, method="pearson")
cor.test(spatialallcorr$PropGrass2736, spatialallcorr$PropBare2736, method="pearson")
cor.test(spatialallcorr$PropShrub2736, spatialallcorr$PropBare2736, method="pearson")
cor.test(spatialallcorr$PropDecid5471, spatialallcorr$PropConif5471, method="pearson")
cor.test(spatialallcorr$PropDecid5471, spatialallcorr$PropWater5471, method="pearson")
cor.test(spatialallcorr$PropDecid5471, spatialallcorr$PropDev5471, method="pearson")
cor.test(spatialallcorr$PropDecid5471, spatialallcorr$PropGrass5471, method="pearson")
cor.test(spatialallcorr$PropDecid5471, spatialallcorr$PropShrub5471, method="pearson")
cor.test(spatialallcorr$PropDecid5471, spatialallcorr$PropBare5471, method="pearson")
cor.test(spatialallcorr$PropConif5471, spatialallcorr$PropWater5471, method="pearson")
cor.test(spatialallcorr$PropConif5471, spatialallcorr$PropDev5471, method="pearson")
cor.test(spatialallcorr$PropConif5471, spatialallcorr$PropGrass5471, method="pearson")
cor.test(spatialallcorr$PropConif5471, spatialallcorr$PropShrub5471, method="pearson")
cor.test(spatialallcorr$PropConif5471, spatialallcorr$PropBare5471, method="pearson")
cor.test(spatialallcorr$PropWater5471, spatialallcorr$PropDev5471, method="pearson")
cor.test(spatialallcorr$PropWater5471, spatialallcorr$PropGrass5471, method="pearson")
cor.test(spatialallcorr$PropWater5471, spatialallcorr$PropShrub5471, method="pearson")
cor.test(spatialallcorr$PropWater5471, spatialallcorr$PropBare5471, method="pearson")
cor.test(spatialallcorr$PropDev5471, spatialallcorr$PropGrass5471, method="pearson")
cor.test(spatialallcorr$PropDev5471, spatialallcorr$PropShrub5471, method="pearson")
cor.test(spatialallcorr$PropDev5471, spatialallcorr$PropBare5471, method="pearson")
cor.test(spatialallcorr$PropGrass5471, spatialallcorr$PropShrub5471, method="pearson")
cor.test(spatialallcorr$PropGrass5471, spatialallcorr$PropBare5471, method="pearson")
cor.test(spatialallcorr$PropShrub5471, spatialallcorr$PropBare5471, method="pearson")

####################################################################################################################################################

## Full Dataset Run

spatialall<-read.table("E:/Spatial Analysis Work/Exported Data/spatialall.csv", header=T, sep=",")
print(spatialall)

par(mar = c(5, 4, 4, 2))
par(mfrow=c(1,1))

## Travel Corridor Based Models (Distance)
TravelDist1<-glm(Rand_MVC~DisFAR_m+ DisRW_m+ DisTR_m, family=binomial(link="logit"), data=spatialall)
summary(TravelDist1)
str(TravelDist1)
TravelDist1$deviance
TravelDist1$null.deviance
res1<-resid(TravelDist1)
fit1<-fitted(TravelDist1)
plot(fit1,res1,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n FAR & RW & TR", pch=16)
TravelDist2<-glm(Rand_MVC~DisFAR_m+ DisTL_m + DisTR_m, family=binomial(link="logit"), data=spatialall)
summary(TravelDist2)
res2<-resid(TravelDist2)
fit2<-fitted(TravelDist2)
plot(fit2,res2,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n FAR & TL & TR", pch=16)
TravelDist3<-glm(Rand_MVC~DisFAR_m + DisRW_m, family=binomial(link="logit"), data=spatialall)
summary(TravelDist3)
res3<-resid(TravelDist3)
fit3<-fitted(TravelDist3)
plot(fit3,res3,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n FAR & RW", pch=16)
TravelDist4<-glm(Rand_MVC~DisFAR_m + DisTL_m, family=binomial(link="logit"), data=spatialall)
summary(TravelDist4)
res4<-resid(TravelDist4)
fit4<-fitted(TravelDist4)
plot(fit4,res4,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n FAR & TL", pch=16)
TravelDist5<-glm(Rand_MVC~DisFAR_m + DisTR_m, family=binomial(link="logit"), data=spatialall)
summary(TravelDist5)
res5<-resid(TravelDist5)
fit5<-fitted(TravelDist5)
plot(fit5,res5,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n FAR & TR", pch=16)
TravelDist6<-glm(Rand_MVC~DisRW_m + DisTR_m, family=binomial(link="logit"), data=spatialall)
summary(TravelDist6)
res6<-resid(TravelDist6)
fit6<-fitted(TravelDist6)
plot(fit6,res6,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RW & TR", pch=16)
TravelDist7<-glm(Rand_MVC~DisTL_m + DisTR_m, family=binomial(link="logit"), data=spatialall)
summary(TravelDist7)
res7<-resid(TravelDist7)
fit7<-fitted(TravelDist7)
plot(fit7,res7,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n TL & TR", pch=16)
TravelDist8<-glm(Rand_MVC~DisFAR_m, family=binomial(link="logit"), data=spatialall)
summary(TravelDist8)
res8<-resid(TravelDist8)
fit8<-fitted(TravelDist8)
plot(fit8,res8,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n FAR", pch=16)
TravelDist9<-glm(Rand_MVC~DisRW_m, family=binomial(link="logit"), data=spatialall)
summary(TravelDist9)
res9<-resid(TravelDist9)
fit9<-fitted(TravelDist9)
plot(fit9,res9,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RW", pch=16)
TravelDist10<-glm(Rand_MVC~DisTL_m, family=binomial(link="logit"), data=spatialall)
summary(TravelDist10)
res10<-resid(TravelDist10)
fit10<-fitted(TravelDist10)
plot(fit10,res10,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n TL", pch=16)
TravelDist11<-glm(Rand_MVC~DisTR_m, family=binomial(link="logit"), data=spatialall)
summary(TravelDist11)
res11<-resid(TravelDist11)
fit11<-fitted(TravelDist11)
plot(fit11,res11,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n TR", pch=16)

library(AICcmodavg)
Cand.models <- list( )
Cand.models[[1]] <- glm(Rand_MVC~DisFAR_m+ DisRW_m+ DisTR_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[2]] <- glm(Rand_MVC~DisFAR_m+ DisTL_m + DisTR_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[3]] <- glm(Rand_MVC~DisFAR_m + DisRW_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[4]] <- glm(Rand_MVC~DisFAR_m + DisTL_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[5]] <- glm(Rand_MVC~DisFAR_m + DisTR_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[6]] <- glm(Rand_MVC~DisRW_m + DisTR_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[7]] <- glm(Rand_MVC~DisTL_m + DisTR_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[8]] <- glm(Rand_MVC~DisFAR_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[9]] <- glm(Rand_MVC~DisRW_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[10]] <- glm(Rand_MVC~DisTL_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[11]] <- glm(Rand_MVC~DisTR_m, family=binomial(link="logit"), data=spatialall)

##create a vector of names to trace back models in set
Modnames <- c("TravelDist1", "TravelDist2", "TravelDist3", "TravelDist4","TravelDist5", "TravelDist6", "TravelDist7", "TravelDist8", 
              "TravelDist9", "TravelDist10", "TravelDist11")

##generate AICc table
aictab(cand.set = Cand.models, modnames = Modnames, sort = TRUE)
##round to 4 digits after decimal point and give log-likelihood
print(aictab(cand.set = Cand.models, modnames = Modnames, sort = TRUE),
      digits = 4, LL = TRUE)

Modnames <- data.frame(Names=c("TravelDist1", "TravelDist2", "TravelDist3", "TravelDist4","TravelDist5", "TravelDist6", "TravelDist7", "TravelDist8", 
                               "TravelDist9", "TravelDist10", "TravelDist11"))

##for each model in Modnames run function NagelkerkeR2
library(fmsb)
Nag <- NULL
Nag <- rbind(Nag, data.frame(Nag=sapply(1:nrow(Modnames), function(i) {NagelkerkeR2(Cand.models[[i]])})))
Nag

##for each model in Modnames run deviance explained (null-resid)/null
library(fmsb)
Dev <- NULL
Dev <- rbind(Dev, data.frame(Dev=sapply(1:nrow(Modnames), function(i) {((Cand.models[[i]]$null.deviance-Cand.models[[i]]$deviance)/Cand.models[[i]]$null.deviance)})))
Dev

## Water Feature Based Models 
WaterFeat1<-glm(Rand_MVC~DisRiv_m + DisWet_m + DisOcn_m + DisLak_m, family=binomial(link="logit"), data=spatialall)
summary(WaterFeat1)
res1a<-resid(WaterFeat1)
fit1a<-fitted(WaterFeat1)
plot(fit1a,res1a,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DisRiv & DisWet & DisOcn & DisLak", pch=16)
WaterFeat2<-glm(Rand_MVC~DisRiv_m + DisWet_m + DisOcn_m, family=binomial(link="logit"), data=spatialall)
summary(WaterFeat2)
res2a<-resid(WaterFeat2)
fit2a<-fitted(WaterFeat2)
plot(fit2a,res2a,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DisRiv & DisWet & DisOcn", pch=16)
WaterFeat3<-glm(Rand_MVC~DisRiv_m + DisWet_m + DisLak_m, family=binomial(link="logit"), data=spatialall)
summary(WaterFeat3)
res3a<-resid(WaterFeat3)
fit3a<-fitted(WaterFeat3)
plot(fit3a,res3a,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DisRiv & DisWet & DisLak", pch=16)
WaterFeat4<-glm(Rand_MVC~DisRiv_m + DisOcn_m + DisLak_m, family=binomial(link="logit"), data=spatialall)
summary(WaterFeat4)
res4a<-resid(WaterFeat4)
fit4a<-fitted(WaterFeat4)
plot(fit4a,res4a,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DisRiv & DisOcn & DisLak", pch=16)
WaterFeat5<-glm(Rand_MVC~DisWet_m + DisOcn_m + DisLak_m, family=binomial(link="logit"), data=spatialall)
summary(WaterFeat5)
res5a<-resid(WaterFeat5)
fit5a<-fitted(WaterFeat5)
plot(fit5a,res5a,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DisWet & DisOcn & DisLak", pch=16)
WaterFeat6<-glm(Rand_MVC~DisRiv_m + DisWet_m, family=binomial(link="logit"), data=spatialall)
summary(WaterFeat6)
res6a<-resid(WaterFeat6)
fit6a<-fitted(WaterFeat6)
plot(fit6a,res6a,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DisRiv & DisWet", pch=16)
WaterFeat7<-glm(Rand_MVC~DisRiv_m + DisOcn_m, family=binomial(link="logit"), data=spatialall)
summary(WaterFeat7)
res7a<-resid(WaterFeat7)
fit7a<-fitted(WaterFeat7)
plot(fit7a,res7a,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DisRiv & DisOcn", pch=16)
WaterFeat8<-glm(Rand_MVC~DisRiv_m + DisLak_m, family=binomial(link="logit"), data=spatialall)
summary(WaterFeat8)
res8a<-resid(WaterFeat8)
fit8a<-fitted(WaterFeat8)
plot(fit8a,res8a,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DisRiv & DisLak", pch=16)
WaterFeat9<-glm(Rand_MVC~DisWet_m + DisOcn_m, family=binomial(link="logit"), data=spatialall)
summary(WaterFeat9)
res9a<-resid(WaterFeat9)
fit9a<-fitted(WaterFeat9)
plot(fit9a,res9a,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DisWet & DisOcn", pch=16)
WaterFeat10<-glm(Rand_MVC~DisWet_m + DisLak_m, family=binomial(link="logit"), data=spatialall)
summary(WaterFeat10)
res10a<-resid(WaterFeat10)
fit10a<-fitted(WaterFeat10)
plot(fit10a,res10a,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DisWet & DisLak", pch=16)
WaterFeat11<-glm(Rand_MVC~DisOcn_m + DisLak_m, family=binomial(link="logit"), data=spatialall)
summary(WaterFeat11)
res11a<-resid(WaterFeat11)
fit11a<-fitted(WaterFeat11)
plot(fit11a,res11a,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DisOcn & DisLak", pch=16)
WaterFeat12<-glm(Rand_MVC~DisRiv_m, family=binomial(link="logit"), data=spatialall)
summary(WaterFeat12)
res12a<-resid(WaterFeat12)
fit12a<-fitted(WaterFeat12)
plot(fit12a,res12a,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DisRiv", pch=16)
WaterFeat13<-glm(Rand_MVC~DisWet_m, family=binomial(link="logit"), data=spatialall)
summary(WaterFeat13)
res13a<-resid(WaterFeat13)
fit13a<-fitted(WaterFeat13)
plot(fit13a,res13a,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DisWet", pch=16)
WaterFeat14<-glm(Rand_MVC~DisOcn_m, family=binomial(link="logit"), data=spatialall)
summary(WaterFeat14)
res14a<-resid(WaterFeat14)
fit14a<-fitted(WaterFeat14)
plot(fit14a,res14a,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DisOcn", pch=16)
WaterFeat15<-glm(Rand_MVC~DisLak_m, family=binomial(link="logit"), data=spatialall)
summary(WaterFeat15)
res15a<-resid(WaterFeat15)
fit15a<-fitted(WaterFeat15)
plot(fit15a,res15a,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DisLak", pch=16)

library(AICcmodavg)
Cand.models <- list( )
Cand.models[[1]] <- glm(Rand_MVC~DisRiv_m + DisWet_m + DisOcn_m + DisLak_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[2]] <- glm(Rand_MVC~DisRiv_m + DisWet_m + DisOcn_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[3]] <- glm(Rand_MVC~DisRiv_m + DisWet_m + DisLak_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[4]] <- glm(Rand_MVC~DisRiv_m + DisOcn_m + DisLak_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[5]] <- glm(Rand_MVC~DisWet_m + DisOcn_m + DisLak_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[6]] <- glm(Rand_MVC~DisRiv_m + DisWet_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[7]] <- glm(Rand_MVC~DisRiv_m + DisOcn_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[8]] <- glm(Rand_MVC~DisRiv_m + DisLak_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[9]] <- glm(Rand_MVC~DisWet_m + DisOcn_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[10]] <- glm(Rand_MVC~DisWet_m + DisLak_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[11]] <- glm(Rand_MVC~DisOcn_m + DisLak_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[12]] <- glm(Rand_MVC~DisRiv_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[13]] <- glm(Rand_MVC~DisWet_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[14]] <- glm(Rand_MVC~DisOcn_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[15]] <- glm(Rand_MVC~DisLak_m, family=binomial(link="logit"), data=spatialall)

##create a vector of names to trace back models in set
Modnames <- c("WaterFeat1", "WaterFeat2", "WaterFeat3", "WaterFeat4","WaterFeat5", "WaterFeat6", "WaterFeat7", "WaterFeat8", 
              "WaterFeat9", "WaterFeat10", "WaterFeat11", "WaterFeat12", "WaterFeat13", "WaterFeat14", "WaterFeat15")

##generate AICc table
aictab(cand.set = Cand.models, modnames = Modnames, sort = TRUE)
##round to 4 digits after decimal point and give log-likelihood
print(aictab(cand.set = Cand.models, modnames = Modnames, sort = TRUE),
      digits = 4, LL = TRUE)

Modnames <- data.frame(Names=c("WaterFeat1", "WaterFeat2", "WaterFeat3", "WaterFeat4","WaterFeat5", "WaterFeat6", "WaterFeat7", "WaterFeat8", 
                               "WaterFeat9", "WaterFeat10", "WaterFeat11", "WaterFeat12", "WaterFeat13", "WaterFeat14", "WaterFeat15"))

##for each model in Modnames run function NagelkerkeR2
library(fmsb)
Nag <- NULL
Nag <- rbind(Nag, data.frame(Nag=sapply(1:nrow(Modnames), function(i) {NagelkerkeR2(Cand.models[[i]])})))
Nag

##for each model in Modnames run deviance explained (null-resid)/null
library(fmsb)
Dev <- NULL
Dev <- rbind(Dev, data.frame(Dev=sapply(1:nrow(Modnames), function(i) {((Cand.models[[i]]$null.deviance-Cand.models[[i]]$deviance)/Cand.models[[i]]$null.deviance)})))
Dev

## Terrain Based Models 
Terrain1<-glm(Rand_MVC~TerrRugg500 + Aspect, family=binomial(link="logit"), data=spatialall)
summary(Terrain1)
res1b<-resid(Terrain1)
fit1b<-fitted(Terrain1)
plot(fit1b,res1b,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n TerrRugg500 & Aspect", pch=16)
Terrain2<-glm(Rand_MVC~TerrRugg2736 + Aspect, family=binomial(link="logit"), data=spatialall)
summary(Terrain2)
res2b<-resid(Terrain2)
fit2b<-fitted(Terrain2)
plot(fit2b,res2b,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n TerrRugg2736 & Aspect", pch=16)
Terrain3<-glm(Rand_MVC~TerrRugg5471 + Aspect, family=binomial(link="logit"), data=spatialall)
summary(Terrain3)
res3b<-resid(Terrain3)
fit3b<-fitted(Terrain3)
plot(fit3b,res3b,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n TerrRugg5471 & Aspect", pch=16)
Terrain4<-glm(Rand_MVC~Slope_mean500 + Aspect, family=binomial(link="logit"), data=spatialall)
summary(Terrain4)
res4b<-resid(Terrain4)
fit4b<-fitted(Terrain4)
plot(fit4b,res4b,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n Slope_mean500 & Aspect", pch=16)
Terrain5<-glm(Rand_MVC~Slope_mean2736 + Aspect, family=binomial(link="logit"), data=spatialall)
summary(Terrain5)
res5b<-resid(Terrain5)
fit5b<-fitted(Terrain5)
plot(fit5b,res5b,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n Slope_mean2736 & Aspect", pch=16)
Terrain6<-glm(Rand_MVC~Slope_mean5471 + Aspect, family=binomial(link="logit"), data=spatialall)
summary(Terrain6)
res6b<-resid(Terrain6)
fit6b<-fitted(Terrain6)
plot(fit6b,res6b,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n Slope_mean5471 & Aspect", pch=16)
Terrain7<-glm(Rand_MVC~TerrRugg500, family=binomial(link="logit"), data=spatialall)
summary(Terrain7)
res7b<-resid(Terrain7)
fit7b<-fitted(Terrain7)
plot(fit7b,res7b,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n TerrRugg500", pch=16)
Terrain8<-glm(Rand_MVC~TerrRugg2736, family=binomial(link="logit"), data=spatialall)
summary(Terrain8)
res8b<-resid(Terrain8)
fit8b<-fitted(Terrain8)
plot(fit8b,res8b,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n TerrRugg2736", pch=16)
Terrain9<-glm(Rand_MVC~TerrRugg5471, family=binomial(link="logit"), data=spatialall)
summary(Terrain9)
res9b<-resid(Terrain9)
fit9b<-fitted(Terrain9)
plot(fit9b,res9b,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n TerrRugg5471", pch=16)
Terrain10<-glm(Rand_MVC~Aspect, family=binomial(link="logit"), data=spatialall)
summary(Terrain10)
res10b<-resid(Terrain10)
fit10b<-fitted(Terrain10)
plot(fit10b,res10b,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n Aspect", pch=16)
Terrain11<-glm(Rand_MVC~Slope_mean500, family=binomial(link="logit"), data=spatialall)
summary(Terrain11)
res11b<-resid(Terrain11)
fit11b<-fitted(Terrain11)
plot(fit11b,res11b,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n Slope_mean500", pch=16)
Terrain12<-glm(Rand_MVC~Slope_mean2736, family=binomial(link="logit"), data=spatialall)
summary(Terrain12)
res12b<-resid(Terrain12)
fit12b<-fitted(Terrain12)
plot(fit12b,res12b,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n Slope_mean2736", pch=16)
Terrain13<-glm(Rand_MVC~Slope_mean5471, family=binomial(link="logit"), data=spatialall)
summary(Terrain13)
res13b<-resid(Terrain13)
fit13b<-fitted(Terrain13)
plot(fit13b,res13b,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n Slope_mean5471", pch=16)

library(AICcmodavg)
Cand.models <- list( )
Cand.models[[1]] <- glm(Rand_MVC~TerrRugg500 + Aspect, family=binomial(link="logit"), data=spatialall)
Cand.models[[2]] <- glm(Rand_MVC~TerrRugg2736 + Aspect, family=binomial(link="logit"), data=spatialall)
Cand.models[[3]] <- glm(Rand_MVC~TerrRugg5471 + Aspect, family=binomial(link="logit"), data=spatialall)
Cand.models[[4]] <- glm(Rand_MVC~Slope_mean500 + Aspect, family=binomial(link="logit"), data=spatialall)
Cand.models[[5]] <- glm(Rand_MVC~Slope_mean2736 + Aspect, family=binomial(link="logit"), data=spatialall)
Cand.models[[6]] <- glm(Rand_MVC~Slope_mean5471 + Aspect, family=binomial(link="logit"), data=spatialall)
Cand.models[[7]] <- glm(Rand_MVC~TerrRugg500, family=binomial(link="logit"), data=spatialall)
Cand.models[[8]] <- glm(Rand_MVC~TerrRugg2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[9]] <- glm(Rand_MVC~TerrRugg5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[10]] <- glm(Rand_MVC~Aspect, family=binomial(link="logit"), data=spatialall)
Cand.models[[11]] <- glm(Rand_MVC~Slope_mean500, family=binomial(link="logit"), data=spatialall)
Cand.models[[12]] <- glm(Rand_MVC~Slope_mean2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[13]] <- glm(Rand_MVC~Slope_mean5471, family=binomial(link="logit"), data=spatialall)

##create a vector of names to trace back models in set
Modnames <- c("Terrain1", "Terrain2", "Terrain3", "Terrain4","Terrain5", "Terrain6", "Terrain7", "Terrain8", 
              "Terrain9", "Terrain10", "Terrain11", "Terrain12", "Terrain13")

##generate AICc table
aictab(cand.set = Cand.models, modnames = Modnames, sort = TRUE)
##round to 4 digits after decimal point and give log-likelihood
print(aictab(cand.set = Cand.models, modnames = Modnames, sort = TRUE),
      digits = 4, LL = TRUE)

Modnames <- data.frame(Names=c("Terrain1", "Terrain2", "Terrain3", "Terrain4","Terrain5", "Terrain6", "Terrain7", "Terrain8", 
                               "Terrain9", "Terrain10", "Terrain11", "Terrain12", "Terrain13"))

##for each model in Modnames run function NagelkerkeR2
library(fmsb)
Nag <- NULL
Nag <- rbind(Nag, data.frame(Nag=sapply(1:nrow(Modnames), function(i) {NagelkerkeR2(Cand.models[[i]])})))
Nag

##for each model in Modnames run deviance explained (null-resid)/null
library(fmsb)
Dev <- NULL
Dev <- rbind(Dev, data.frame(Dev=sapply(1:nrow(Modnames), function(i) {((Cand.models[[i]]$null.deviance-Cand.models[[i]]$deviance)/Cand.models[[i]]$null.deviance)})))
Dev

## Disturbance/ Road Based Models 
Road1<-glm(Rand_MVC~ RdClass + Sinuosity + DisMA_m + DisDevA_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
summary(Road1)
res1c<-resid(Road1)
fit1c<-fitted(Road1)
plot(fit1c,res1c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & Sinuosity & MA & DevA & DevS", pch=16)
Road2<-glm(Rand_MVC~ RdClass + Sinuosity + DisMA_m + DisDevL_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
summary(Road2)
res2c<-resid(Road2)
fit2c<-fitted(Road2)
plot(fit2c,res2c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & Sinuosity & MA & DevL & DevS", pch=16)
Road3<-glm(Rand_MVC~RdClass + Sinuosity + DisDevA_m + DisDevM_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
summary(Road3)
res3c<-resid(Road3)
fit3c<-fitted(Road3)
plot(fit3c,res3c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & Sinuosity & DevA & DevM & DevS", pch=16)
Road4<-glm(Rand_MVC~RdClass + Sinuosity + DisDevL_m + DisDevM_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
summary(Road4)
res4c<-resid(Road4)
fit4c<-fitted(Road4)
plot(fit4c,res4c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & Sinuosity & DevL & DevM & DevS", pch=16)
Road5<-glm(Rand_MVC~RdClass + Sinuosity + DisMA_m + DisDevA_m, family=binomial(link="logit"), data=spatialall)
summary(Road5)
res5c<-resid(Road5)
fit5c<-fitted(Road5)
plot(fit5c,res5c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & Sinuosity & MA & DevA", pch=16)
Road6<-glm(Rand_MVC~RdClass + Sinuosity + DisMA_m + DisDevL_m, family=binomial(link="logit"), data=spatialall)
summary(Road6)
res6c<-resid(Road6)
fit6c<-fitted(Road6)
plot(fit6c,res6c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & Sinuosity & MA & DevL", pch=16)
## 95% Conifdence Intervals
library(AICcmodavg)
library(lme4)

## Road 6 parameter estimates and confidence intervals
Cand.models <- list( )
Cand.models[[1]] <- glm(Rand_MVC~RdClass + Sinuosity + DisMA_m + DisDevL_m, family=binomial(link="logit"), data=spatialall)
##create a vector of names to trace back models in set
Modnames <- c("GLM_ROAD6")

## Road Classification - Secondary Roads
parm <- "RdClassSEC"
##generate AICc table
modavg(cand.set = Cand.models, parm, modnames = Modnames, second.ord=TRUE, uncond.se ="revised", conf.level = 0.95, warn=FALSE)

## Sinuosity
parm <- "Sinuosity"
##generate AICc table
modavg(cand.set = Cand.models, parm, modnames = Modnames, second.ord=TRUE, uncond.se ="revised", conf.level = 0.95, warn=FALSE)

## Distance to Mining Areas
parm <- "DisMA_m"
##generate AICc table
modavg(cand.set = Cand.models, parm, modnames = Modnames, second.ord=TRUE, uncond.se ="revised", conf.level = 0.95, warn=FALSE)

## Distance to Developed Areas (large)
parm <- "DisDevL_m"
##generate AICc table
modavg(cand.set = Cand.models, parm, modnames = Modnames, second.ord=TRUE, uncond.se ="revised", conf.level = 0.95, warn=FALSE)

Road7<-glm(Rand_MVC~RdClass + Sinuosity + DisMA_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
summary(Road7)
res7c<-resid(Road7)
fit7c<-fitted(Road7)
plot(fit7c,res7c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & Sinuosity & MA & DevS", pch=16)
Road8<-glm(Rand_MVC~RdClass + Sinuosity + DisDevA_m + DisDevM_m, family=binomial(link="logit"), data=spatialall)
summary(Road8)
res8c<-resid(Road8)
fit8c<-fitted(Road8)
plot(fit8c,res8c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & Sinuosity & DevA & DevM", pch=16)
Road9<-glm(Rand_MVC~RdClass + Sinuosity + DisDevA_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
summary(Road9)
res9c<-resid(Road9)
fit9c<-fitted(Road9)
plot(fit9c,res9c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & Sinuosity & DevA & DevS", pch=16)
Road10<-glm(Rand_MVC~RdClass + Sinuosity + DisDevL_m + DisDevM_m, family=binomial(link="logit"), data=spatialall)
summary(Road10)
res10c<-resid(Road10)
fit10c<-fitted(Road10)
plot(fit10c,res10c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & Sinuosity & DevL & DevM", pch=16)
Road11<-glm(Rand_MVC~RdClass + Sinuosity + DisDevL_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
summary(Road11)
res11c<-resid(Road11)
fit11c<-fitted(Road11)
plot(fit11c,res11c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & Sinuosity & DevL & DevS", pch=16)
Road12<-glm(Rand_MVC~RdClass + Sinuosity + DisDevM_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
summary(Road12)
res12c<-resid(Road12)
fit12c<-fitted(Road12)
plot(fit12c,res12c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & Sinuosity & DevM & DevS", pch=16)
Road13<-glm(Rand_MVC~RdClass + DisMA_m + DisDevA_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
summary(Road13)
res13c<-resid(Road13)
fit13c<-fitted(Road13)
plot(fit13c,res13c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & MA & DevA & DevS", pch=16)
Road14<-glm(Rand_MVC~RdClass + DisMA_m + DisDevL_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
summary(Road14)
res14c<-resid(Road14)
fit14c<-fitted(Road14)
plot(fit14c,res14c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & MA & DevL & DevS", pch=16)
Road15<-glm(Rand_MVC~RdClass + DisDevA_m + DisDevM_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
summary(Road15)
res15c<-resid(Road15)
fit15c<-fitted(Road15)
plot(fit15c,res15c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & DevA & DevM & DevS", pch=16)
Road16<-glm(Rand_MVC~RdClass + DisDevL_m + DisDevM_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
summary(Road16)
res16c<-resid(Road16)
fit16c<-fitted(Road16)
plot(fit16c,res16c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & DevL & DevM & DevS", pch=16)
Road17<-glm(Rand_MVC~Sinuosity + DisMA_m + DisDevA_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
summary(Road17)
res17c<-resid(Road17)
fit17c<-fitted(Road17)
plot(fit17c,res17c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n Sinuosity & MA & DevA & DevS", pch=16)
Road18<-glm(Rand_MVC~Sinuosity + DisMA_m + DisDevL_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
summary(Road18)
res18c<-resid(Road18)
fit18c<-fitted(Road18)
plot(fit18c,res18c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n Sinuosity & MA & DevL & DevS", pch=16)
Road19<-glm(Rand_MVC~Sinuosity + DisDevA_m + DisDevM_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
summary(Road19)
res19c<-resid(Road19)
fit19c<-fitted(Road19)
plot(fit19c,res19c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n Sinuosity & DevA & DevM & DevS", pch=16)
Road20<-glm(Rand_MVC~Sinuosity + DisDevL_m + DisDevM_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
summary(Road20)
res20c<-resid(Road20)
fit20c<-fitted(Road20)
plot(fit20c,res20c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n Sinuosity & DevL & DevM & DevS", pch=16)
Road21<-glm(Rand_MVC~RdClass + Sinuosity + DisMA_m, family=binomial(link="logit"), data=spatialall)
summary(Road21)
res21c<-resid(Road21)
fit21c<-fitted(Road21)
plot(fit21c,res21c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & Sinuosity & MA", pch=16)
Road22<-glm(Rand_MVC~RdClass + Sinuosity + DisDevA_m, family=binomial(link="logit"), data=spatialall)
summary(Road22)
res22c<-resid(Road22)
fit22c<-fitted(Road22)
plot(fit22c,res22c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & Sinuosity & DevA", pch=16)
Road23<-glm(Rand_MVC~RdClass + Sinuosity + DisDevL_m, family=binomial(link="logit"), data=spatialall)
summary(Road23)
res23c<-resid(Road23)
fit23c<-fitted(Road23)
plot(fit23c,res23c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & Sinuosity & DevL", pch=16)
Road24<-glm(Rand_MVC~RdClass + Sinuosity + DisDevM_m, family=binomial(link="logit"), data=spatialall)
summary(Road24)
res24c<-resid(Road24)
fit24c<-fitted(Road24)
plot(fit24c,res24c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & Sinuosity & DevM", pch=16)
Road25<-glm(Rand_MVC~RdClass + Sinuosity + DisDevS_m, family=binomial(link="logit"), data=spatialall)
summary(Road25)
res25c<-resid(Road25)
fit25c<-fitted(Road25)
plot(fit25c,res25c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & Sinuosity & DevS", pch=16)
Road26<-glm(Rand_MVC~RdClass + DisMA_m + DisDevA_m, family=binomial(link="logit"), data=spatialall)
summary(Road26)
res26c<-resid(Road26)
fit26c<-fitted(Road26)
plot(fit26c,res26c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & MA & DevA", pch=16)
Road27<-glm(Rand_MVC~RdClass + DisMA_m + DisDevL_m, family=binomial(link="logit"), data=spatialall)
summary(Road27)
res27c<-resid(Road27)
fit27c<-fitted(Road27)
plot(fit27c,res27c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & MA & DevL", pch=16)
Road28<-glm(Rand_MVC~RdClass + DisMA_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
summary(Road28)
res28c<-resid(Road28)
fit28c<-fitted(Road28)
plot(fit28c,res28c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & MA & DevS", pch=16)
Road29<-glm(Rand_MVC~RdClass + DisDevA_m + DisDevM_m, family=binomial(link="logit"), data=spatialall)
summary(Road29)
res29c<-resid(Road29)
fit29c<-fitted(Road29)
plot(fit29c,res29c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & DevA & DevM", pch=16)
Road30<-glm(Rand_MVC~RdClass + DisDevA_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
summary(Road30)
res30c<-resid(Road30)
fit30c<-fitted(Road30)
plot(fit30c,res30c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & DevA & DevS", pch=16)
Road31<-glm(Rand_MVC~RdClass + DisDevL_m + DisDevM_m, family=binomial(link="logit"), data=spatialall)
summary(Road31)
res31c<-resid(Road31)
fit31c<-fitted(Road31)
plot(fit31c,res31c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & DevL & DevM", pch=16)
Road32<-glm(Rand_MVC~RdClass + DisDevL_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
summary(Road32)
res32c<-resid(Road32)
fit32c<-fitted(Road32)
plot(fit32c,res32c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & DevL & DevS", pch=16)
Road33<-glm(Rand_MVC~RdClass + DisDevM_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
summary(Road33)
res33c<-resid(Road33)
fit33c<-fitted(Road33)
plot(fit33c,res33c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & DevM & DevS", pch=16)
Road34<-glm(Rand_MVC~Sinuosity + DisMA_m + DisDevA_m, family=binomial(link="logit"), data=spatialall)
summary(Road34)
res34c<-resid(Road34)
fit34c<-fitted(Road34)
plot(fit34c,res34c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n Sinuosity & MA & DevA", pch=16)
Road35<-glm(Rand_MVC~Sinuosity + DisMA_m + DisDevL_m, family=binomial(link="logit"), data=spatialall)
summary(Road35)
res35c<-resid(Road35)
fit35c<-fitted(Road35)
plot(fit35c,res35c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n Sinuosity & MA & DevL", pch=16)
Road36<-glm(Rand_MVC~Sinuosity + DisMA_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
summary(Road36)
res36c<-resid(Road36)
fit36c<-fitted(Road36)
plot(fit36c,res36c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n Sinuosity & MA & DevS", pch=16)
Road37<-glm(Rand_MVC~Sinuosity + DisDevA_m + DisDevM_m, family=binomial(link="logit"), data=spatialall)
summary(Road37)
res37c<-resid(Road37)
fit37c<-fitted(Road37)
plot(fit37c,res37c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n Sinuosity & DevA & DevM", pch=16)
Road38<-glm(Rand_MVC~Sinuosity + DisDevA_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
summary(Road38)
res38c<-resid(Road38)
fit38c<-fitted(Road38)
plot(fit38c,res38c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n Sinuosity & DevA & DevS", pch=16)
Road39<-glm(Rand_MVC~Sinuosity + DisDevL_m + DisDevM_m, family=binomial(link="logit"), data=spatialall)
summary(Road39)
res39c<-resid(Road39)
fit39c<-fitted(Road39)
plot(fit39c,res39c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n Sinuosity & DevL & DevM", pch=16)
Road40<-glm(Rand_MVC~Sinuosity + DisDevL_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
summary(Road40)
res40c<-resid(Road40)
fit40c<-fitted(Road40)
plot(fit40c,res40c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n Sinuosity & DevL & DevS", pch=16)
Road41<-glm(Rand_MVC~Sinuosity + DisDevM_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
summary(Road41)
res41c<-resid(Road41)
fit41c<-fitted(Road41)
plot(fit41c,res41c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n Sinuosity & DevM & DevS", pch=16)
Road42<-glm(Rand_MVC~DisMA_m + DisDevA_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
summary(Road42)
res42c<-resid(Road42)
fit42c<-fitted(Road42)
plot(fit42c,res42c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n MA & DevA & DevS", pch=16)
Road43<-glm(Rand_MVC~DisMA_m + DisDevL_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
summary(Road43)
res43c<-resid(Road43)
fit43c<-fitted(Road43)
plot(fit43c,res43c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n MA & DevL & DevS", pch=16)
Road44<-glm(Rand_MVC~DisDevA_m + DisDevM_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
summary(Road44)
res44c<-resid(Road44)
fit44c<-fitted(Road44)
plot(fit44c,res44c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DevA & DevM & DevS", pch=16)
Road45<-glm(Rand_MVC~DisDevL_m + DisDevM_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
summary(Road45)
res45c<-resid(Road45)
fit45c<-fitted(Road45)
plot(fit45c,res45c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DevL & DevM & DevS", pch=16)
Road46<-glm(Rand_MVC~RdClass + Sinuosity, family=binomial(link="logit"), data=spatialall)
summary(Road46)
res46c<-resid(Road46)
fit46c<-fitted(Road46)
plot(fit46c,res46c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & Sinuosity", pch=16)
Road47<-glm(Rand_MVC~RdClass + DisMA_m, family=binomial(link="logit"), data=spatialall)
summary(Road47)
res47c<-resid(Road47)
fit47c<-fitted(Road47)
plot(fit47c,res47c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & DisMA", pch=16)
Road48<-glm(Rand_MVC~RdClass + DisDevA_m, family=binomial(link="logit"), data=spatialall)
summary(Road48)
res48c<-resid(Road48)
fit48c<-fitted(Road48)
plot(fit48c,res48c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & DevA", pch=16)
Road49<-glm(Rand_MVC~RdClass + DisDevL_m, family=binomial(link="logit"), data=spatialall)
summary(Road49)
res49c<-resid(Road49)
fit49c<-fitted(Road49)
plot(fit49c,res49c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & DevL", pch=16)
Road50<-glm(Rand_MVC~RdClass + DisDevM_m, family=binomial(link="logit"), data=spatialall)
summary(Road50)
res50c<-resid(Road50)
fit50c<-fitted(Road50)
plot(fit50c,res50c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & DevM", pch=16)
Road51<-glm(Rand_MVC~RdClass + DisDevS_m, family=binomial(link="logit"), data=spatialall)
summary(Road51)
res51c<-resid(Road51)
fit51c<-fitted(Road51)
plot(fit51c,res51c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & DevS", pch=16)
Road52<-glm(Rand_MVC~Sinuosity + DisMA_m, family=binomial(link="logit"), data=spatialall)
summary(Road52)
res52c<-resid(Road52)
fit52c<-fitted(Road52)
plot(fit52c,res52c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & DevS", pch=16)
Road53<-glm(Rand_MVC~Sinuosity + DisDevA_m, family=binomial(link="logit"), data=spatialall)
summary(Road53)
res53c<-resid(Road53)
fit53c<-fitted(Road53)
plot(fit53c,res53c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n Sinuosity & DevA", pch=16)
Road54<-glm(Rand_MVC~Sinuosity + DisDevL_m, family=binomial(link="logit"), data=spatialall)
summary(Road54)
res54c<-resid(Road54)
fit54c<-fitted(Road54)
plot(fit54c,res54c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n Sinuosity & DevL", pch=16)
Road55<-glm(Rand_MVC~Sinuosity + DisDevM_m, family=binomial(link="logit"), data=spatialall)
summary(Road55)
res55c<-resid(Road55)
fit55c<-fitted(Road55)
plot(fit55c,res55c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n Sinuosity & DevM", pch=16)
Road56<-glm(Rand_MVC~Sinuosity + DisDevS_m, family=binomial(link="logit"), data=spatialall)
summary(Road56)
res56c<-resid(Road56)
fit56c<-fitted(Road56)
plot(fit56c,res56c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n Sinuosity & DevS", pch=16)
Road57<-glm(Rand_MVC~DisMA_m + DisDevA_m, family=binomial(link="logit"), data=spatialall)
summary(Road57)
res57c<-resid(Road57)
fit57c<-fitted(Road57)
plot(fit57c,res57c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DisMA & DevA", pch=16)
Road58<-glm(Rand_MVC~DisMA_m + DisDevL_m, family=binomial(link="logit"), data=spatialall)
summary(Road58)
res58c<-resid(Road58)
fit58c<-fitted(Road58)
plot(fit58c,res58c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DisMA & DevL", pch=16)
Road59<-glm(Rand_MVC~DisMA_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
summary(Road59)
res59c<-resid(Road59)
fit59c<-fitted(Road59)
plot(fit59c,res59c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DisMA & DevS", pch=16)
Road60<-glm(Rand_MVC~DisDevA_m + DisDevM_m, family=binomial(link="logit"), data=spatialall)
summary(Road60)
res60c<-resid(Road60)
fit60c<-fitted(Road60)
plot(fit60c,res60c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DevA & DevM", pch=16)
Road61<-glm(Rand_MVC~DisDevA_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
summary(Road61)
res61c<-resid(Road61)
fit61c<-fitted(Road61)
plot(fit61c,res61c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DevA & DevS", pch=16)
Road62<-glm(Rand_MVC~DisDevL_m + DisDevM_m, family=binomial(link="logit"), data=spatialall)
summary(Road62)
res62c<-resid(Road62)
fit62c<-fitted(Road62)
plot(fit62c,res62c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DevL & DevM", pch=16)
Road63<-glm(Rand_MVC~DisDevL_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
summary(Road63)
res63c<-resid(Road63)
fit63c<-fitted(Road63)
plot(fit63c,res63c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DevL & DevS", pch=16)
Road64<-glm(Rand_MVC~DisDevM_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
summary(Road64)
res64c<-resid(Road64)
fit64c<-fitted(Road64)
plot(fit64c,res64c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DevM & DevS", pch=16)
Road65<-glm(Rand_MVC~RdClass, family=binomial(link="logit"), data=spatialall)
summary(Road65)
res65c<-resid(Road65)
fit65c<-fitted(Road65)
plot(fit65c,res65c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DevM & DevS", pch=16)
Road66<-glm(Rand_MVC~Sinuosity, family=binomial(link="logit"), data=spatialall)
summary(Road66)
res66c<-resid(Road66)
fit66c<-fitted(Road66)
plot(fit66c,res66c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n Sinuosity", pch=16)
Road67<-glm(Rand_MVC~DisMA_m, family=binomial(link="logit"), data=spatialall)
summary(Road67)
res67c<-resid(Road67)
fit67c<-fitted(Road67)
plot(fit67c,res67c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n MA", pch=16)
Road68<-glm(Rand_MVC~DisDevA_m, family=binomial(link="logit"), data=spatialall)
summary(Road68)
res68c<-resid(Road68)
fit68c<-fitted(Road68)
plot(fit68c,res68c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DevA", pch=16)
Road69<-glm(Rand_MVC~DisDevL_m, family=binomial(link="logit"), data=spatialall)
summary(Road69)
res69c<-resid(Road69)
fit69c<-fitted(Road69)
plot(fit69c,res69c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DevL", pch=16)
Road70<-glm(Rand_MVC~DisDevM_m, family=binomial(link="logit"), data=spatialall)
summary(Road70)
res70c<-resid(Road70)
fit70c<-fitted(Road70)
plot(fit70c,res70c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DevM", pch=16)
Road71<-glm(Rand_MVC~DisDevS_m, family=binomial(link="logit"), data=spatialall)
summary(Road71)
res71c<-resid(Road71)
fit71c<-fitted(Road71)
plot(fit71c,res71c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DevS", pch=16)

library(AICcmodavg)
Cand.models <- list( )
Cand.models[[1]] <- glm(Rand_MVC~ RdClass + Sinuosity + DisMA_m + DisDevA_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[2]] <- glm(Rand_MVC~ RdClass + Sinuosity + DisMA_m + DisDevL_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[3]] <- glm(Rand_MVC~RdClass + Sinuosity + DisDevA_m + DisDevM_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[4]]<-glm(Rand_MVC~RdClass + Sinuosity + DisDevL_m + DisDevM_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[5]]<-glm(Rand_MVC~RdClass + Sinuosity + DisMA_m + DisDevA_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[6]]<-glm(Rand_MVC~RdClass + Sinuosity + DisMA_m + DisDevL_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[7]]<-glm(Rand_MVC~RdClass + Sinuosity + DisMA_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[8]]<-glm(Rand_MVC~RdClass + Sinuosity + DisDevA_m + DisDevM_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[9]]<-glm(Rand_MVC~RdClass + Sinuosity + DisDevA_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[10]]<-glm(Rand_MVC~RdClass + Sinuosity + DisDevL_m + DisDevM_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[11]]<-glm(Rand_MVC~RdClass + Sinuosity + DisDevL_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[12]]<-glm(Rand_MVC~RdClass + Sinuosity + DisDevM_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[13]]<-glm(Rand_MVC~RdClass + DisMA_m + DisDevA_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[14]]<-glm(Rand_MVC~RdClass + DisMA_m + DisDevL_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[15]]<-glm(Rand_MVC~RdClass + DisDevA_m + DisDevM_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[16]]<-glm(Rand_MVC~RdClass + DisDevL_m + DisDevM_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[17]]<-glm(Rand_MVC~Sinuosity + DisMA_m + DisDevA_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[18]]<-glm(Rand_MVC~Sinuosity + DisMA_m + DisDevL_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[19]]<-glm(Rand_MVC~Sinuosity + DisDevA_m + DisDevM_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[20]]<-glm(Rand_MVC~Sinuosity + DisDevL_m + DisDevM_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[21]]<-glm(Rand_MVC~RdClass + Sinuosity + DisMA_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[22]]<-glm(Rand_MVC~RdClass + Sinuosity + DisDevA_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[23]]<-glm(Rand_MVC~RdClass + Sinuosity + DisDevL_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[24]]<-glm(Rand_MVC~RdClass + Sinuosity + DisDevM_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[25]]<-glm(Rand_MVC~RdClass + Sinuosity + DisDevS_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[26]]<-glm(Rand_MVC~RdClass + DisMA_m + DisDevA_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[27]]<-glm(Rand_MVC~RdClass + DisMA_m + DisDevL_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[28]]<-glm(Rand_MVC~RdClass + DisMA_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[29]]<-glm(Rand_MVC~RdClass + DisDevA_m + DisDevM_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[30]]<-glm(Rand_MVC~RdClass + DisDevA_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[31]]<-glm(Rand_MVC~RdClass + DisDevL_m + DisDevM_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[32]]<-glm(Rand_MVC~RdClass + DisDevL_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[33]]<-glm(Rand_MVC~RdClass + DisDevM_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[34]]<-glm(Rand_MVC~Sinuosity + DisMA_m + DisDevA_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[35]]<-glm(Rand_MVC~Sinuosity + DisMA_m + DisDevL_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[36]]<-glm(Rand_MVC~Sinuosity + DisMA_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[37]]<-glm(Rand_MVC~Sinuosity + DisDevA_m + DisDevM_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[38]]<-glm(Rand_MVC~Sinuosity + DisDevA_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[39]]<-glm(Rand_MVC~Sinuosity + DisDevL_m + DisDevM_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[40]]<-glm(Rand_MVC~Sinuosity + DisDevL_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[41]]<-glm(Rand_MVC~Sinuosity + DisDevM_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[42]]<-glm(Rand_MVC~DisMA_m + DisDevA_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[43]]<-glm(Rand_MVC~DisMA_m + DisDevL_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[44]]<-glm(Rand_MVC~DisDevA_m + DisDevM_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[45]]<-glm(Rand_MVC~DisDevL_m + DisDevM_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[46]]<-glm(Rand_MVC~RdClass + Sinuosity, family=binomial(link="logit"), data=spatialall)
Cand.models[[47]]<-glm(Rand_MVC~RdClass + DisMA_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[48]]<-glm(Rand_MVC~RdClass + DisDevA_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[49]]<-glm(Rand_MVC~RdClass + DisDevL_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[50]]<-glm(Rand_MVC~RdClass + DisDevM_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[51]]<-glm(Rand_MVC~RdClass + DisDevS_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[52]]<-glm(Rand_MVC~Sinuosity + DisMA_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[53]]<-glm(Rand_MVC~Sinuosity + DisDevA_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[54]]<-glm(Rand_MVC~Sinuosity + DisDevL_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[55]]<-glm(Rand_MVC~Sinuosity + DisDevM_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[56]]<-glm(Rand_MVC~Sinuosity + DisDevS_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[57]]<-glm(Rand_MVC~DisMA_m + DisDevA_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[58]]<-glm(Rand_MVC~DisMA_m + DisDevL_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[59]]<-glm(Rand_MVC~DisMA_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[60]]<-glm(Rand_MVC~DisDevA_m + DisDevM_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[61]]<-glm(Rand_MVC~DisDevA_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[62]]<-glm(Rand_MVC~DisDevL_m + DisDevM_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[63]]<-glm(Rand_MVC~DisDevL_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[64]]<-glm(Rand_MVC~DisDevM_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[65]]<-glm(Rand_MVC~RdClass, family=binomial(link="logit"), data=spatialall)
Cand.models[[66]]<-glm(Rand_MVC~Sinuosity, family=binomial(link="logit"), data=spatialall)
Cand.models[[67]]<-glm(Rand_MVC~DisMA_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[68]]<-glm(Rand_MVC~DisDevA_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[69]]<-glm(Rand_MVC~DisDevL_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[70]]<-glm(Rand_MVC~DisDevM_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[71]]<-glm(Rand_MVC~DisDevS_m, family=binomial(link="logit"), data=spatialall)

##create a vector of names to trace back models in set
Modnames <- c("Road1", "Road2", "Road3", "Road4","Road5", "Road6", "Road7", "Road8", "Road9", "Road10", "Road11", "Road12", "Road13", "Road14", "Road15", "Road16", "Road17",
              "Road18", "Road19", "Road20", "Road21", "Road22", "Road23", "Road24", "Road25", "Road26", "Road27", "Road28", "Road29", "Road30", "Road31", "Road32", "Road33",
              "Road34", "Road35", "Road36", "Road37", "Road38", "Road39", "Road40", "Road41", "Road42", "Road43", "Road44", "Road45", "Road46", "Road47", "Road48", "Road49",
              "Road50", "Road51", "Road52", "Road53", "Road54", "Road55", "Road56", "Road57", "Road58", "Road59", "Road60", "Road61", "Road62", "Road63", "Road64", "Road65",
              "Road66", "Road67", "Road68", "Road69", "Road70", "Road71")

##generate AICc table
aictab(cand.set = Cand.models, modnames = Modnames, sort = TRUE)
##round to 4 digits after decimal point and give log-likelihood
print(aictab(cand.set = Cand.models, modnames = Modnames, sort = TRUE),
      digits = 4, LL = TRUE)

Modnames <- data.frame(Names=c("Road1", "Road2", "Road3", "Road4","Road5", "Road6", "Road7", "Road8", "Road9", "Road10", "Road11", "Road12", "Road13", "Road14", "Road15", "Road16", "Road17",
                               "Road18", "Road19", "Road20", "Road21", "Road22", "Road23", "Road24", "Road25", "Road26", "Road27", "Road28", "Road29", "Road30", "Road31", "Road32", "Road33",
                               "Road34", "Road35", "Road36", "Road37", "Road38", "Road39", "Road40", "Road41", "Road42", "Road43", "Road44", "Road45", "Road46", "Road47", "Road48", "Road49",
                               "Road50", "Road51", "Road52", "Road53", "Road54", "Road55", "Road56", "Road57", "Road58", "Road59", "Road60", "Road61", "Road62", "Road63", "Road64", "Road65",
                               "Road66", "Road67", "Road68", "Road69", "Road70", "Road71"))

##for each model in Modnames run function NagelkerkeR2
library(fmsb)
Nag <- NULL
Nag <- rbind(Nag, data.frame(Nag=sapply(1:nrow(Modnames), function(i) {NagelkerkeR2(Cand.models[[i]])})))
Nag

##for each model in Modnames run deviance explained (null-resid)/null
library(fmsb)
Dev <- NULL
Dev <- rbind(Dev, data.frame(Dev=sapply(1:nrow(Modnames), function(i) {((Cand.models[[i]]$null.deviance-Cand.models[[i]]$deviance)/Cand.models[[i]]$null.deviance)})))
Dev

## Mitigation Based Models
Mitigation1<-glm(Rand_MVC~VegCtLoc, family=binomial(link="logit"), data=spatialall)
summary(Mitigation1)
res1d<-resid(Mitigation1)
fit1d<-fitted(Mitigation1)
plot(fit1d,res1d,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n VegCtLoc", pch=16)

library(AICcmodavg)
Cand.models <- list( )
Cand.models[[1]] <- glm(Rand_MVC~VegCtLoc, family=binomial(link="logit"), data=spatialall)

##create a vector of names to trace back models in set
Modnames <- c("Mitigation1")

##generate AICc table
aictab(cand.set = Cand.models, modnames = Modnames, sort = TRUE)
##round to 4 digits after decimal point and give log-likelihood
print(aictab(cand.set = Cand.models, modnames = Modnames, sort = TRUE),
      digits = 4, LL = TRUE)

Modnames <- data.frame(Names=c("Mitigation1"))

##for each model in Modnames run function NagelkerkeR2
library(fmsb)
Nag <- NULL
Nag <- rbind(Nag, data.frame(Nag=sapply(1:nrow(Modnames), function(i) {NagelkerkeR2(Cand.models[[i]])})))
Nag

##for each model in Modnames run deviance explained (null-resid)/null
library(fmsb)
Dev <- NULL
Dev <- rbind(Dev, data.frame(Dev=sapply(1:nrow(Modnames), function(i) {((Cand.models[[i]]$null.deviance-Cand.models[[i]]$deviance)/Cand.models[[i]]$null.deviance)})))
Dev

## Moose Density Models 
MooseDensity1<-glm(Rand_MVC~MooseDen, family=binomial(link="logit"), data=spatialall)
summary(MooseDensity1)
res1e<-resid(MooseDensity1)
fit1e<-fitted(MooseDensity1)
plot(fit1e,res1e,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n MooseDen", pch=16)

library(AICcmodavg)
Cand.models <- list( )
Cand.models[[1]] <- glm(Rand_MVC~MooseDen, family=binomial(link="logit"), data=spatialall)

##create a vector of names to trace back models in set
Modnames <- c("MooseDensity1")

##generate AICc table
aictab(cand.set = Cand.models, modnames = Modnames, sort = TRUE)
##round to 4 digits after decimal point and give log-likelihood
print(aictab(cand.set = Cand.models, modnames = Modnames, sort = TRUE),
      digits = 4, LL = TRUE)

Modnames <- data.frame(Names=c("MooseDensity1"))

##for each model in Modnames run function NagelkerkeR2
library(fmsb)
Nag <- NULL
Nag <- rbind(Nag, data.frame(Nag=sapply(1:nrow(Modnames), function(i) {NagelkerkeR2(Cand.models[[i]])})))
Nag

##for each model in Modnames run deviance explained (null-resid)/null
library(fmsb)
Dev <- NULL
Dev <- rbind(Dev, data.frame(Dev=sapply(1:nrow(Modnames), function(i) {((Cand.models[[i]]$null.deviance-Cand.models[[i]]$deviance)/Cand.models[[i]]$null.deviance)})))
Dev

## Travel Corridor Based Models (Density)
TravelDen1<-glm(Rand_MVC~DenFAR500 + DenRW500 + DenTL500 + DenTR500, family=binomial(link="logit"), data=spatialall)
summary(TravelDen1)
res1f<-resid(TravelDen1)
fit1f<-fitted(TravelDen1)
plot(fit1f,res1f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n FAR & RW & TL & TR", pch=16)
TravelDen2<-glm(Rand_MVC~DenFAR2736 + DenRW2736 + DenTL2736 + DenTR2736, family=binomial(link="logit"), data=spatialall)
summary(TravelDen2)
res2f<-resid(TravelDen2)
fit2f<-fitted(TravelDen2)
plot(fit2f,res2f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenFAR2736 & DenRW2736 & DenTL2736 & DenTR2736", pch=16)
TravelDen3<-glm(Rand_MVC~DenFAR500 + DenRW500 + DenTL500, family=binomial(link="logit"), data=spatialall)
summary(TravelDen3)
res3f<-resid(TravelDen3)
fit3f<-fitted(TravelDen3)
plot(fit3f,res3f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenFAR500 & DenRW500 & DenTL500", pch=16)
TravelDen4<-glm(Rand_MVC~DenFAR500 + DenRW500 + DenTR500, family=binomial(link="logit"), data=spatialall)
summary(TravelDen4)
res4f<-resid(TravelDen4)
fit4f<-fitted(TravelDen4)
plot(fit4f,res4f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenFAR500 & DenRW500 & DenTR500", pch=16)
TravelDen5<-glm(Rand_MVC~DenFAR500 + DenTL500 + DenTR500, family=binomial(link="logit"), data=spatialall)
summary(TravelDen5)
res5f<-resid(TravelDen5)
fit5f<-fitted(TravelDen5)
plot(fit5f,res5f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenFAR500 & DenTL500 & DenTR500", pch=16)
TravelDen6<-glm(Rand_MVC~DenRW500 + DenTL500 + DenTR500, family=binomial(link="logit"), data=spatialall)
summary(TravelDen6)
res6f<-resid(TravelDen6)
fit6f<-fitted(TravelDen6)
plot(fit6f,res6f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenRW500 & DenTL500 & DenTR500", pch=16)
TravelDen7<-glm(Rand_MVC~DenFAR2736 + DenRW2736 + DenTL2736, family=binomial(link="logit"), data=spatialall)
summary(TravelDen7)
res7f<-resid(TravelDen7)
fit7f<-fitted(TravelDen7)
plot(fit7f,res7f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenFAR2736 & DenRW2736 & DenTL2736", pch=16)
TravelDen8<-glm(Rand_MVC~DenFAR2736 + DenRW2736 + DenTR2736, family=binomial(link="logit"), data=spatialall)
summary(TravelDen8)
res8f<-resid(TravelDen8)
fit8f<-fitted(TravelDen8)
plot(fit8f,res8f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenFAR2736 & DenRW2736 & DenTR2736", pch=16)
TravelDen9<-glm(Rand_MVC~DenFAR2736 + DenTL2736 + DenTR2736, family=binomial(link="logit"), data=spatialall)
summary(TravelDen9)
res9f<-resid(TravelDen9)
fit9f<-fitted(TravelDen9)
plot(fit9f,res9f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenFAR2736 & DenTL2736 & DenTR2736", pch=16)
TravelDen10<-glm(Rand_MVC~DenRW2736 + DenTL2736 + DenTR2736, family=binomial(link="logit"), data=spatialall)
summary(TravelDen10)
res10f<-resid(TravelDen10)
fit10f<-fitted(TravelDen10)
plot(fit10f,res10f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenRW2736 & DenTL2736 & DenTR2736", pch=16)
TravelDen11<-glm(Rand_MVC~DenFAR5471 + DenRW5471 + DenTR5471, family=binomial(link="logit"), data=spatialall)
summary(TravelDen11)
res11f<-resid(TravelDen11)
fit11f<-fitted(TravelDen11)
plot(fit11f,res11f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenFAR5471 & DenRW5471 & DenTR5471", pch=16)
TravelDen12<-glm(Rand_MVC~DenFAR5471 + DenTL5471 + DenTR5471, family=binomial(link="logit"), data=spatialall)
summary(TravelDen12)
res12f<-resid(TravelDen12)
fit12f<-fitted(TravelDen12)
plot(fit12f,res12f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenFAR5471 & DenTL5471 & DenTR5471", pch=16)
TravelDen13<-glm(Rand_MVC~DenFAR500 + DenRW500, family=binomial(link="logit"), data=spatialall)
summary(TravelDen13)
res13f<-resid(TravelDen13)
fit13f<-fitted(TravelDen13)
plot(fit13f,res13f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenFAR500 & DenRW500", pch=16)
TravelDen14<-glm(Rand_MVC~DenFAR500 + DenTL500, family=binomial(link="logit"), data=spatialall)
summary(TravelDen14)
res14f<-resid(TravelDen14)
fit14f<-fitted(TravelDen14)
plot(fit14f,res14f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenFAR500 & DenTL500", pch=16)
TravelDen15<-glm(Rand_MVC~DenFAR500 + DenTR500, family=binomial(link="logit"), data=spatialall)
summary(TravelDen15)
res15f<-resid(TravelDen15)
fit15f<-fitted(TravelDen15)
plot(fit15f,res15f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenFAR500 & DenTR500", pch=16)
TravelDen16<-glm(Rand_MVC~DenRW500 + DenTL500, family=binomial(link="logit"), data=spatialall)
summary(TravelDen16)
res16f<-resid(TravelDen16)
fit16f<-fitted(TravelDen16)
plot(fit16f,res16f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenRW500 & DenTL500", pch=16)
TravelDen17<-glm(Rand_MVC~DenRW500 + DenTR500, family=binomial(link="logit"), data=spatialall)
summary(TravelDen17)
res17f<-resid(TravelDen17)
fit17f<-fitted(TravelDen17)
plot(fit17f,res17f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenRW500 & DenTR500", pch=16)
TravelDen18<-glm(Rand_MVC~DenTL500 + DenTR500, family=binomial(link="logit"), data=spatialall)
summary(TravelDen18)
res18f<-resid(TravelDen18)
fit18f<-fitted(TravelDen18)
plot(fit18f,res18f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenTL500 & DenTR500", pch=16)
TravelDen19<-glm(Rand_MVC~DenFAR2736 + DenRW2736, family=binomial(link="logit"), data=spatialall)
summary(TravelDen19)
res19f<-resid(TravelDen19)
fit19f<-fitted(TravelDen19)
plot(fit19f,res19f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenFAR2736 & DenRW2736", pch=16)
TravelDen20<-glm(Rand_MVC~DenFAR2736 + DenTL2736, family=binomial(link="logit"), data=spatialall)
summary(TravelDen20)
res20f<-resid(TravelDen20)
fit20f<-fitted(TravelDen20)
plot(fit20f,res20f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenFAR2736 & DenTL2736", pch=16)
TravelDen21<-glm(Rand_MVC~DenFAR2736 + DenTR2736, family=binomial(link="logit"), data=spatialall)
summary(TravelDen21)
res21f<-resid(TravelDen21)
fit21f<-fitted(TravelDen21)
plot(fit21f,res21f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenFAR2736 & DenTR2736", pch=16)
TravelDen22<-glm(Rand_MVC~DenRW2736 + DenTL2736, family=binomial(link="logit"), data=spatialall)
summary(TravelDen22)
res22f<-resid(TravelDen22)
fit22f<-fitted(TravelDen22)
plot(fit22f,res22f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenRW2736 & DenTL2736", pch=16)
TravelDen23<-glm(Rand_MVC~DenRW2736 + DenTR2736, family=binomial(link="logit"), data=spatialall)
summary(TravelDen23)
res23f<-resid(TravelDen23)
fit23f<-fitted(TravelDen23)
plot(fit23f,res23f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenRW2736 & DenTR2736", pch=16)
TravelDen24<-glm(Rand_MVC~DenTL2736 + DenTR2736, family=binomial(link="logit"), data=spatialall)
summary(TravelDen24)
res24f<-resid(TravelDen24)
fit24f<-fitted(TravelDen24)
plot(fit24f,res24f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenTL2736 & DenTR2736", pch=16)
TravelDen25<-glm(Rand_MVC~DenFAR5471 + DenRW5471, family=binomial(link="logit"), data=spatialall)
summary(TravelDen25)
res25f<-resid(TravelDen25)
fit25f<-fitted(TravelDen25)
plot(fit25f,res25f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenFAR5471 & DenRW5471", pch=16)
TravelDen26<-glm(Rand_MVC~DenFAR5471 + DenTL5471, family=binomial(link="logit"), data=spatialall)
summary(TravelDen26)
res26f<-resid(TravelDen26)
fit26f<-fitted(TravelDen26)
plot(fit26f,res26f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenFAR5471 & DenTL5471", pch=16)
TravelDen27<-glm(Rand_MVC~DenFAR5471 + DenTR5471, family=binomial(link="logit"), data=spatialall)
summary(TravelDen27)
res27f<-resid(TravelDen27)
fit27f<-fitted(TravelDen27)
plot(fit27f,res27f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenFAR5471 & DenTR5471", pch=16)
TravelDen28<-glm(Rand_MVC~DenRW5471 + DenTR5471, family=binomial(link="logit"), data=spatialall)
summary(TravelDen28)
res28f<-resid(TravelDen28)
fit28f<-fitted(TravelDen28)
plot(fit28f,res28f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenRW5471 & DenTR5471", pch=16)
TravelDen29<-glm(Rand_MVC~DenTL5471 + DenTR5471, family=binomial(link="logit"), data=spatialall)
summary(TravelDen29)
res29f<-resid(TravelDen29)
fit29f<-fitted(TravelDen29)
plot(fit29f,res29f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenTL5471 & DenTR5471", pch=16)
TravelDen30<-glm(Rand_MVC~DenFAR500, family=binomial(link="logit"), data=spatialall)
summary(TravelDen30)
res30f<-resid(TravelDen30)
fit30f<-fitted(TravelDen30)
plot(fit30f,res30f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenFAR500", pch=16)
TravelDen31<-glm(Rand_MVC~DenRW500, family=binomial(link="logit"), data=spatialall)
summary(TravelDen31)
res31f<-resid(TravelDen31)
fit31f<-fitted(TravelDen31)
plot(fit31f,res31f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenRW500", pch=16)
TravelDen32<-glm(Rand_MVC~DenTL500, family=binomial(link="logit"), data=spatialall)
summary(TravelDen32)
res32f<-resid(TravelDen32)
fit32f<-fitted(TravelDen32)
plot(fit32f,res32f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenTL500", pch=16)
TravelDen33<-glm(Rand_MVC~DenTR500, family=binomial(link="logit"), data=spatialall)
summary(TravelDen33)
res33f<-resid(TravelDen33)
fit33f<-fitted(TravelDen33)
plot(fit33f,res33f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenTL500", pch=16)
TravelDen34<-glm(Rand_MVC~DenFAR2736, family=binomial(link="logit"), data=spatialall)
summary(TravelDen34)
res34f<-resid(TravelDen34)
fit34f<-fitted(TravelDen34)
plot(fit34f,res34f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenFAR2736", pch=16)
TravelDen35<-glm(Rand_MVC~DenRW2736, family=binomial(link="logit"), data=spatialall)
summary(TravelDen35)
res35f<-resid(TravelDen35)
fit35f<-fitted(TravelDen35)
plot(fit35f,res35f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenRW2736", pch=16)
TravelDen36<-glm(Rand_MVC~DenTL2736, family=binomial(link="logit"), data=spatialall)
summary(TravelDen36)
res36f<-resid(TravelDen36)
fit36f<-fitted(TravelDen36)
plot(fit36f,res36f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenTL2736", pch=16)
TravelDen37<-glm(Rand_MVC~DenTR2736, family=binomial(link="logit"), data=spatialall)
summary(TravelDen37)
res37f<-resid(TravelDen37)
fit37f<-fitted(TravelDen37)
plot(fit37f,res37f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenTR2736", pch=16)
TravelDen38<-glm(Rand_MVC~DenFAR5471, family=binomial(link="logit"), data=spatialall)
summary(TravelDen38)
res38f<-resid(TravelDen38)
fit38f<-fitted(TravelDen38)
plot(fit38f,res38f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenFAR5471", pch=16)
TravelDen39<-glm(Rand_MVC~DenRW5471, family=binomial(link="logit"), data=spatialall)
summary(TravelDen39)
res39f<-resid(TravelDen39)
fit39f<-fitted(TravelDen39)
plot(fit39f,res39f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenRW5471", pch=16)
TravelDen40<-glm(Rand_MVC~DenTL5471, family=binomial(link="logit"), data=spatialall)
summary(TravelDen40)
res40f<-resid(TravelDen40)
fit40f<-fitted(TravelDen40)
plot(fit40f,res40f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenTL5471", pch=16)
TravelDen41<-glm(Rand_MVC~DenTR5471, family=binomial(link="logit"), data=spatialall)
summary(TravelDen41)
res41f<-resid(TravelDen41)
fit41f<-fitted(TravelDen41)
plot(fit41f,res41f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenTR5471", pch=16)

library(AICcmodavg)
Cand.models <- list( )
Cand.models[[1]]<-glm(Rand_MVC~DenFAR500 + DenRW500 + DenTL500 + DenTR500, family=binomial(link="logit"), data=spatialall)
Cand.models[[2]]<-glm(Rand_MVC~DenFAR2736 + DenRW2736 + DenTL2736 + DenTR2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[3]]<-glm(Rand_MVC~DenFAR500 + DenRW500 + DenTL500, family=binomial(link="logit"), data=spatialall)
Cand.models[[4]]<-glm(Rand_MVC~DenFAR500 + DenRW500 + DenTR500, family=binomial(link="logit"), data=spatialall)
Cand.models[[5]]<-glm(Rand_MVC~DenFAR500 + DenTL500 + DenTR500, family=binomial(link="logit"), data=spatialall)
Cand.models[[6]]<-glm(Rand_MVC~DenRW500 + DenTL500 + DenTR500, family=binomial(link="logit"), data=spatialall)
Cand.models[[7]]<-glm(Rand_MVC~DenFAR2736 + DenRW2736 + DenTL2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[8]]<-glm(Rand_MVC~DenFAR2736 + DenRW2736 + DenTR2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[9]]<-glm(Rand_MVC~DenFAR2736 + DenTL2736 + DenTR2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[10]]<-glm(Rand_MVC~DenRW2736 + DenTL2736 + DenTR2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[11]]<-glm(Rand_MVC~DenFAR5471 + DenRW5471 + DenTR5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[12]]<-glm(Rand_MVC~DenFAR5471 + DenTL5471 + DenTR5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[13]]<-glm(Rand_MVC~DenFAR500 + DenRW500, family=binomial(link="logit"), data=spatialall)
Cand.models[[14]]<-glm(Rand_MVC~DenFAR500 + DenTL500, family=binomial(link="logit"), data=spatialall)
Cand.models[[15]]<-glm(Rand_MVC~DenFAR500 + DenTR500, family=binomial(link="logit"), data=spatialall)
Cand.models[[16]]<-glm(Rand_MVC~DenRW500 + DenTL500, family=binomial(link="logit"), data=spatialall)
Cand.models[[17]]<-glm(Rand_MVC~DenRW500 + DenTR500, family=binomial(link="logit"), data=spatialall)
Cand.models[[18]]<-glm(Rand_MVC~DenTL500 + DenTR500, family=binomial(link="logit"), data=spatialall)
Cand.models[[19]]<-glm(Rand_MVC~DenFAR2736 + DenRW2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[20]]<-glm(Rand_MVC~DenFAR2736 + DenTL2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[21]]<-glm(Rand_MVC~DenFAR2736 + DenTR2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[22]]<-glm(Rand_MVC~DenRW2736 + DenTL2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[23]]<-glm(Rand_MVC~DenRW2736 + DenTR2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[24]]<-glm(Rand_MVC~DenTL2736 + DenTR2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[25]]<-glm(Rand_MVC~DenFAR5471 + DenRW5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[26]]<-glm(Rand_MVC~DenFAR5471 + DenTL5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[27]]<-glm(Rand_MVC~DenFAR5471 + DenTR5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[28]]<-glm(Rand_MVC~DenRW5471 + DenTR5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[29]]<-glm(Rand_MVC~DenTL5471 + DenTR5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[30]]<-glm(Rand_MVC~DenFAR500, family=binomial(link="logit"), data=spatialall)
Cand.models[[31]]<-glm(Rand_MVC~DenRW500, family=binomial(link="logit"), data=spatialall)
Cand.models[[32]]<-glm(Rand_MVC~DenTL500, family=binomial(link="logit"), data=spatialall)
Cand.models[[33]]<-glm(Rand_MVC~DenTR500, family=binomial(link="logit"), data=spatialall)
Cand.models[[34]]<-glm(Rand_MVC~DenFAR2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[35]]<-glm(Rand_MVC~DenRW2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[36]]<-glm(Rand_MVC~DenTL2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[37]]<-glm(Rand_MVC~DenTR2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[38]]<-glm(Rand_MVC~DenFAR5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[39]]<-glm(Rand_MVC~DenRW5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[40]]<-glm(Rand_MVC~DenTL5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[41]]<-glm(Rand_MVC~DenTR5471, family=binomial(link="logit"), data=spatialall)

##create a vector of names to trace back models in set
Modnames <- c("TravelDen1", "TravelDen2", "TravelDen3", "TravelDen4","TravelDen5", "TravelDen6", "TravelDen7", "TravelDen8", "TravelDen9", "TravelDen10", "TravelDen11", 
              "TravelDen12", "TravelDen13", "TravelDen14", "TravelDen15", "TravelDen16", "TravelDen17", "TravelDen18", "TravelDen19", "TravelDen20", "TravelDen21", 
              "TravelDen22", "TravelDen23", "TravelDen24", "TravelDen25", "TravelDen26", "TravelDen27", "TravelDen28", "TravelDen29", "TravelDen30", "TravelDen31", 
              "TravelDen32", "TravelDen33", "TravelDen34", "TravelDen35", "TravelDen36", "TravelDen37", "TravelDen38", "TravelDen39", "TravelDen40", "TravelDen41")

##generate AICc table
aictab(cand.set = Cand.models, modnames = Modnames, sort = TRUE)
##round to 4 digits after decimal point and give log-likelihood
print(aictab(cand.set = Cand.models, modnames = Modnames, sort = TRUE),
      digits = 4, LL = TRUE)

Modnames <- data.frame(Names=c("TravelDen1", "TravelDen2", "TravelDen3", "TravelDen4","TravelDen5", "TravelDen6", "TravelDen7", "TravelDen8", "TravelDen9", "TravelDen10", "TravelDen11", 
                               "TravelDen12", "TravelDen13", "TravelDen14", "TravelDen15", "TravelDen16", "TravelDen17", "TravelDen18", "TravelDen19", "TravelDen20", "TravelDen21", 
                               "TravelDen22", "TravelDen23", "TravelDen24", "TravelDen25", "TravelDen26", "TravelDen27", "TravelDen28", "TravelDen29", "TravelDen30", "TravelDen31", 
                               "TravelDen32", "TravelDen33", "TravelDen34", "TravelDen35", "TravelDen36", "TravelDen37", "TravelDen38", "TravelDen39", "TravelDen40", "TravelDen41"))

##for each model in Modnames run function NagelkerkeR2
library(fmsb)
Nag <- NULL
Nag <- rbind(Nag, data.frame(Nag=sapply(1:nrow(Modnames), function(i) {NagelkerkeR2(Cand.models[[i]])})))
Nag

##for each model in Modnames run deviance explained (null-resid)/null
library(fmsb)
Dev <- NULL
Dev <- rbind(Dev, data.frame(Dev=sapply(1:nrow(Modnames), function(i) {((Cand.models[[i]]$null.deviance-Cand.models[[i]]$deviance)/Cand.models[[i]]$null.deviance)})))
Dev

## Composition Based Models - 500 Buffer 
Comp500A1<-glm(Rand_MVC~PropDecid500 + PropConif500 + PropWater500 + PropDev500 + PropGrass500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A1)
res1g<-resid(Comp500A1)
fit1g<-fitted(Comp500A1)
plot(fit1g,res1g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid500 & PropConif500 & PropWater500 & PropDev500 & PropGrass500 & PropShrub500", pch=16)
Comp500A2<-glm(Rand_MVC~PropConif500 + PropWater500 + PropDev500 + PropGrass500 + PropShrub500 + PropBare500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A2)
res2g<-resid(Comp500A2)
fit2g<-fitted(Comp500A2)
plot(fit2g,res2g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif500 & PropWater500 & PropDev500 & PropGrass500 & PropShrub500 & PropBare500", pch=16)
Comp500A3<-glm(Rand_MVC~PropDecid500 + PropConif500 + PropWater500 + PropDev500 + PropGrass500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A3)
res3g<-resid(Comp500A3)
fit3g<-fitted(Comp500A3)
plot(fit3g,res3g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid500 & PropConif500 & PropWater500 & PropDev500 & PropGrass500", pch=16)
Comp500A4<-glm(Rand_MVC~PropDecid500 + PropConif500 + PropWater500 + PropDev500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A4)
res4g<-resid(Comp500A4)
fit4g<-fitted(Comp500A4)
plot(fit4g,res4g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid500 & PropConif500 & PropWater500 & PropDev500 & PropShrub500", pch=16)
Comp500A5<-glm(Rand_MVC~PropDecid500 + PropConif500 + PropWater500 + PropGrass500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A5)
res5g<-resid(Comp500A5)
fit5g<-fitted(Comp500A5)
plot(fit5g,res5g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid500 & PropConif500 & PropWater500 & PropGrass500 & PropShrub500", pch=16)
Comp500A6<-glm(Rand_MVC~PropDecid500 + PropConif500 + PropDev500 + PropGrass500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A6)
res6g<-resid(Comp500A6)
fit6g<-fitted(Comp500A6)
plot(fit6g,res6g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid500 & PropConif500 & PropDev500 & PropGrass500 & PropShrub500", pch=16)
Comp500A7<-glm(Rand_MVC~PropDecid500 + PropWater500 + PropDev500 + PropGrass500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A7)
res7g<-resid(Comp500A7)
fit7g<-fitted(Comp500A7)
plot(fit7g,res7g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid500 & PropWater500 & PropDev500 & PropGrass500 & PropShrub500", pch=16)
Comp500A8<-glm(Rand_MVC~PropConif500 + PropWater500 + PropDev500 + PropGrass500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A8)
res8g<-resid(Comp500A8)
fit8g<-fitted(Comp500A8)
plot(fit8g,res8g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif500 & PropWater500 & PropDev500 & PropGrass500 & PropShrub500", pch=16)
Comp500A9<-glm(Rand_MVC~PropConif500 + PropWater500 + PropDev500 + PropGrass500 + PropBare500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A9)
res9g<-resid(Comp500A9)
fit9g<-fitted(Comp500A9)
plot(fit9g,res9g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif500 + PropWater500 + PropDev500 + PropGrass500 + PropBare500", pch=16)
Comp500A10<-glm(Rand_MVC~PropConif500 + PropWater500 + PropDev500 + PropShrub500 + PropBare500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A10)
res10g<-resid(Comp500A10)
fit10g<-fitted(Comp500A10)
plot(fit10g,res10g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif500 + PropWater500 + PropDev500 + PropShrub500 + PropBare500", pch=16)
Comp500A11<-glm(Rand_MVC~PropConif500 + PropWater500 + PropGrass500 + PropShrub500 + PropBare500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A11)
res11g<-resid(Comp500A11)
fit11g<-fitted(Comp500A11)
plot(fit11g,res11g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif500 + PropWater500 + PropDev500 + PropShrub500 + PropBare500", pch=16)
Comp500A12<-glm(Rand_MVC~PropConif500 + PropDev500 + PropGrass500 + PropShrub500 + PropBare500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A12)
res12g<-resid(Comp500A12)
fit12g<-fitted(Comp500A12)
plot(fit12g,res12g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif500 + PropDev500 + PropGrass500 + PropShrub500 + PropBare500", pch=16)
Comp500A13<-glm(Rand_MVC~PropWater500 + PropDev500 + PropGrass500 + PropShrub500 + PropBare500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A13)
res13g<-resid(Comp500A13)
fit13g<-fitted(Comp500A13)
plot(fit13g,res13g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater500 + PropDev500 + PropGrass500 + PropShrub500 + PropBare500", pch=16)
Comp500A14<-glm(Rand_MVC~PropDecid500 + PropConif500 + PropWater500 + PropDev500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A14)
res14g<-resid(Comp500A14)
fit14g<-fitted(Comp500A14)
plot(fit14g,res14g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid500 + PropConif500 + PropWater500 + PropDev500", pch=16)
Comp500A15<-glm(Rand_MVC~PropDecid500 + PropConif500 + PropWater500 + PropGrass500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A15)
res15g<-resid(Comp500A15)
fit15g<-fitted(Comp500A15)
plot(fit15g,res15g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid500 + PropConif500 + PropWater500 + PropGrass500", pch=16)
Comp500A16<-glm(Rand_MVC~PropDecid500 + PropConif500 + PropWater500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A16)
res16g<-resid(Comp500A16)
fit16g<-fitted(Comp500A16)
plot(fit16g,res16g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid500 + PropConif500 + PropWater500 + PropShrub500", pch=16)
Comp500A17<-glm(Rand_MVC~PropDecid500 + PropConif500 + PropDev500 + PropGrass500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A17)
res17g<-resid(Comp500A17)
fit17g<-fitted(Comp500A17)
plot(fit17g,res17g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid500 + PropConif500 + PropDev500 + PropGrass500", pch=16)
Comp500A18<-glm(Rand_MVC~PropDecid500 + PropConif500 + PropDev500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A18)
res18g<-resid(Comp500A18)
fit18g<-fitted(Comp500A18)
plot(fit18g,res18g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid500 + PropConif500 + PropDev500 + PropShrub500", pch=16)
Comp500A19<-glm(Rand_MVC~PropDecid500 + PropConif500 + PropGrass500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A19)
res19g<-resid(Comp500A19)
fit19g<-fitted(Comp500A19)
plot(fit19g,res19g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid500 + PropConif500 + PropGrass500 + PropShrub500", pch=16)
Comp500A20<-glm(Rand_MVC~PropDecid500 + PropWater500 + PropDev500 + PropGrass500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A20)
res20g<-resid(Comp500A20)
fit20g<-fitted(Comp500A20)
plot(fit20g,res20g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid500 + PropWater500 + PropDev500 + PropGrass500", pch=16)
Comp500A21<-glm(Rand_MVC~PropDecid500 + PropWater500 + PropDev500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A21)
res21g<-resid(Comp500A21)
fit21g<-fitted(Comp500A21)
plot(fit21g,res21g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid500 + PropWater500 + PropDev500 + PropShrub500", pch=16)
Comp500A22<-glm(Rand_MVC~PropDecid500 + PropWater500 + PropGrass500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A22)
res22g<-resid(Comp500A22)
fit22g<-fitted(Comp500A22)
plot(fit22g,res22g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid500 + PropWater500 + PropGrass500 + PropShrub500", pch=16)
Comp500A23<-glm(Rand_MVC~PropDecid500 + PropDev500 + PropGrass500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A23)
res23g<-resid(Comp500A23)
fit23g<-fitted(Comp500A23)
plot(fit23g,res23g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid500 + PropDev500 + PropGrass500 + PropShrub500", pch=16)
Comp500A24<-glm(Rand_MVC~PropConif500 + PropWater500 + PropDev500 + PropGrass500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A24)
res24g<-resid(Comp500A24)
fit24g<-fitted(Comp500A24)
plot(fit24g,res24g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif500 + PropWater500 + PropDev500 + PropGrass500", pch=16)
Comp500A25<-glm(Rand_MVC~PropConif500 + PropWater500 + PropDev500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A25)
res25g<-resid(Comp500A25)
fit25g<-fitted(Comp500A25)
plot(fit25g,res25g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif500 + PropWater500 + PropDev500 + PropShrub500", pch=16)
Comp500A26<-glm(Rand_MVC~PropConif500 + PropWater500 + PropDev500 + PropBare500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A26)
res26g<-resid(Comp500A26)
fit26g<-fitted(Comp500A26)
plot(fit26g,res26g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif500 + PropWater500 + PropDev500 + PropBare500", pch=16)
Comp500A27<-glm(Rand_MVC~PropConif500 + PropWater500 + PropGrass500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A27)
res27g<-resid(Comp500A27)
fit27g<-fitted(Comp500A27)
plot(fit27g,res27g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif500 + PropWater500 + PropGrass500 + PropShrub500", pch=16)
Comp500A28<-glm(Rand_MVC~PropConif500 + PropWater500 + PropGrass500 + PropBare500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A28)
res28g<-resid(Comp500A28)
fit28g<-fitted(Comp500A28)
plot(fit28g,res28g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif500 + PropWater500 + PropGrass500 + PropBare500", pch=16)
Comp500A29<-glm(Rand_MVC~PropConif500 + PropWater500 + PropShrub500 + PropBare500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A29)
res29g<-resid(Comp500A29)
fit29g<-fitted(Comp500A29)
plot(fit29g,res29g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif500 + PropWater500 + PropShrub500 + PropBare500", pch=16)
Comp500A30<-glm(Rand_MVC~PropConif500 + PropDev500 + PropGrass500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A30)
res30g<-resid(Comp500A30)
fit30g<-fitted(Comp500A30)
plot(fit30g,res30g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif500 + PropDev500 + PropGrass500 + PropShrub500", pch=16)
Comp500A31<-glm(Rand_MVC~PropConif500 + PropDev500 + PropGrass500 + PropBare500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A31)
res31g<-resid(Comp500A31)
fit31g<-fitted(Comp500A31)
plot(fit31g,res31g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif500 + PropDev500 + PropGrass500 + PropBare500", pch=16)
Comp500A32<-glm(Rand_MVC~PropConif500 + PropDev500 + PropShrub500 + PropBare500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A32)
res32g<-resid(Comp500A32)
fit32g<-fitted(Comp500A32)
plot(fit32g,res32g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif500 + PropDev500 + PropShrub500 + PropBare500", pch=16)
Comp500A33<-glm(Rand_MVC~PropConif500 + PropGrass500 + PropShrub500 + PropBare500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A33)
res33g<-resid(Comp500A33)
fit33g<-fitted(Comp500A33)
plot(fit33g,res34g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif500 + PropGrass500 + PropShrub500 + PropBare500", pch=16)
Comp500A34<-glm(Rand_MVC~PropWater500 + PropDev500 + PropGrass500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A34)
res34g<-resid(Comp500A34)
fit34g<-fitted(Comp500A34)
plot(fit34g,res34g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater500 + PropDev500 + PropGrass500 + PropShrub500", pch=16)
Comp500A35<-glm(Rand_MVC~PropWater500 + PropDev500 + PropGrass500 + PropBare500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A35)
res35g<-resid(Comp500A35)
fit35g<-fitted(Comp500A35)
plot(fit35g,res35g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater500 + PropDev500 + PropGrass500 + PropBare500", pch=16)
Comp500A36<-glm(Rand_MVC~PropWater500 + PropDev500 + PropShrub500 + PropBare500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A36)
res36g<-resid(Comp500A36)
fit36g<-fitted(Comp500A36)
plot(fit36g,res36g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater500 + PropDev500 + PropShrub500 + PropBare500", pch=16)
Comp500A37<-glm(Rand_MVC~PropWater500 + PropGrass500 + PropShrub500 + PropBare500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A37)
res37g<-resid(Comp500A37)
fit37g<-fitted(Comp500A37)
plot(fit37g,res37g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater500 + PropGrass500 + PropShrub500 + PropBare500", pch=16)
Comp500A38<-glm(Rand_MVC~PropDev500 + PropGrass500 + PropShrub500 + PropBare500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A38)
res38g<-resid(Comp500A38)
fit38g<-fitted(Comp500A38)
plot(fit38g,res38g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDev500 + PropGrass500 + PropShrub500 + PropBare500", pch=16)
Comp500A39<-glm(Rand_MVC~PropDecid500 + PropConif500 + PropWater500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A39)
res39g<-resid(Comp500A39)
fit39g<-fitted(Comp500A39)
plot(fit39g,res39g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid500 + PropConif500 + PropWater500", pch=16)
Comp500A40<-glm(Rand_MVC~PropDecid500 + PropConif500 + PropDev500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A40)
res40g<-resid(Comp500A40)
fit40g<-fitted(Comp500A40)
plot(fit40g,res40g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid500 + PropConif500 + PropDev500", pch=16)
Comp500A41<-glm(Rand_MVC~PropDecid500 + PropConif500 + PropGrass500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A41)
res41g<-resid(Comp500A41)
fit41g<-fitted(Comp500A41)
plot(fit41g,res41g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid500 + PropConif500 + PropGrass500", pch=16)
Comp500A42<-glm(Rand_MVC~PropDecid500 + PropConif500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A42)
res42g<-resid(Comp500A42)
fit42g<-fitted(Comp500A42)
plot(fit42g,res42g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid500 + PropConif500 + PropShrub500", pch=16)
Comp500A43<-glm(Rand_MVC~PropDecid500 + PropWater500 + PropDev500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A43)
res43g<-resid(Comp500A43)
fit43g<-fitted(Comp500A43)
plot(fit43g,res43g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid500 + PropWater500 + PropDev500", pch=16)
Comp500A44<-glm(Rand_MVC~PropDecid500 + PropWater500 + PropGrass500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A44)
res44g<-resid(Comp500A44)
fit44g<-fitted(Comp500A44)
plot(fit44g,res44g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid500 + PropWater500 + PropGrass500", pch=16)
Comp500A45<-glm(Rand_MVC~PropDecid500 + PropWater500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A45)
res45g<-resid(Comp500A45)
fit45g<-fitted(Comp500A45)
plot(fit45g,res45g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid500 + PropWater500 + PropShrub500", pch=16)
Comp500A46<-glm(Rand_MVC~PropDecid500 + PropDev500 + PropGrass500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A46)
res46g<-resid(Comp500A46)
fit46g<-fitted(Comp500A46)
plot(fit46g,res46g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid500 + PropDev500 + PropGrass500", pch=16)
Comp500A47<-glm(Rand_MVC~PropDecid500 + PropDev500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A47)
res47g<-resid(Comp500A47)
fit47g<-fitted(Comp500A47)
plot(fit47g,res47g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid500 + PropDev500 + PropShrub500", pch=16)
Comp500A48<-glm(Rand_MVC~PropDecid500 + PropGrass500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A48)
res48g<-resid(Comp500A48)
fit48g<-fitted(Comp500A48)
plot(fit48g,res48g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid500 + PropGrass500 + PropShrub500", pch=16)
Comp500A49<-glm(Rand_MVC~PropConif500 + PropWater500 + PropDev500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A49)
res49g<-resid(Comp500A49)
fit49g<-fitted(Comp500A49)
plot(fit49g,res49g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif500 + PropWater500 + PropDev500", pch=16)
Comp500A50<-glm(Rand_MVC~PropConif500 + PropWater500 + PropGrass500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A50)
res50g<-resid(Comp500A50)
fit50g<-fitted(Comp500A50)
plot(fit50g,res50g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif500 + PropWater500 + PropGrass500", pch=16)
Comp500A51<-glm(Rand_MVC~PropConif500 + PropWater500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A51)
res51g<-resid(Comp500A51)
fit51g<-fitted(Comp500A51)
plot(fit51g,res51g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif500 + PropWater500 + PropShrub500", pch=16)
Comp500A52<-glm(Rand_MVC~PropConif500 + PropWater500 + PropBare500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A52)
res52g<-resid(Comp500A52)
fit52g<-fitted(Comp500A52)
plot(fit52g,res52g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif500 + PropWater500 + PropBare500", pch=16)
Comp500A53<-glm(Rand_MVC~PropConif500 + PropDev500 + PropGrass500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A53)
res53g<-resid(Comp500A53)
fit53g<-fitted(Comp500A53)
plot(fit53g,res53g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif500 + PropDev500 + PropGrass500", pch=16)
Comp500A54<-glm(Rand_MVC~PropConif500 + PropDev500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A54)
res54g<-resid(Comp500A54)
fit54g<-fitted(Comp500A54)
plot(fit54g,res54g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif500 + PropDev500 + PropShrub500", pch=16)
Comp500A55<-glm(Rand_MVC~PropConif500 + PropDev500 + PropBare500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A55)
res55g<-resid(Comp500A55)
fit55g<-fitted(Comp500A55)
plot(fit55g,res55g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif500 + PropDev500 + PropBare500", pch=16)
Comp500A56<-glm(Rand_MVC~PropConif500 + PropGrass500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A56)
res56g<-resid(Comp500A56)
fit56g<-fitted(Comp500A56)
plot(fit56g,res56g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif500 + PropGrass500 + PropShrub500", pch=16)
Comp500A57<-glm(Rand_MVC~PropConif500 + PropGrass500 + PropBare500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A57)
res57g<-resid(Comp500A57)
fit57g<-fitted(Comp500A57)
plot(fit57g,res57g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif500 + PropGrass500 + PropBare500", pch=16)
Comp500A58<-glm(Rand_MVC~PropConif500 + PropShrub500 + PropBare500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A58)
res58g<-resid(Comp500A58)
fit58g<-fitted(Comp500A58)
plot(fit58g,res58g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif500 + PropShrub500 + PropBare500", pch=16)
Comp500A59<-glm(Rand_MVC~PropWater500 + PropDev500 + PropGrass500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A59)
res59g<-resid(Comp500A59)
fit59g<-fitted(Comp500A59)
plot(fit59g,res59g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater500 + PropDev500 + PropGrass500", pch=16)
Comp500A60<-glm(Rand_MVC~PropWater500 + PropDev500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A60)
res60g<-resid(Comp500A60)
fit60g<-fitted(Comp500A60)
plot(fit60g,res60g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater500 + PropDev500 + PropShrub500", pch=16)
Comp500A61<-glm(Rand_MVC~PropWater500 + PropDev500 + PropBare500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A61)
res61g<-resid(Comp500A61)
fit61g<-fitted(Comp500A61)
plot(fit61g,res61g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater500 + PropDev500 + PropBare500", pch=16)
Comp500A62<-glm(Rand_MVC~PropWater500 + PropGrass500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A62)
res62g<-resid(Comp500A62)
fit62g<-fitted(Comp500A62)
plot(fit62g,res62g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater500 + PropGrass500 + PropShrub500", pch=16)
Comp500A63<-glm(Rand_MVC~PropWater500 + PropGrass500 + PropBare500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A63)
res63g<-resid(Comp500A63)
fit63g<-fitted(Comp500A63)
plot(fit63g,res63g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater500 + PropGrass500 + PropBare500", pch=16)
Comp500A64<-glm(Rand_MVC~PropWater500 + PropShrub500 + PropBare500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A64)
res64g<-resid(Comp500A64)
fit64g<-fitted(Comp500A64)
plot(fit64g,res64g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater500 + PropShrub500 + PropBare500", pch=16)
Comp500A65<-glm(Rand_MVC~PropDev500 + PropGrass500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A65)
res65g<-resid(Comp500A65)
fit65g<-fitted(Comp500A65)
plot(fit65g,res65g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDev500 + PropGrass500 + PropShrub500", pch=16)
Comp500A66<-glm(Rand_MVC~PropDev500 + PropGrass500 + PropBare500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A66)
res66g<-resid(Comp500A66)
fit66g<-fitted(Comp500A66)
plot(fit66g,res66g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDev500 + PropGrass500 + PropBare500", pch=16)
Comp500A67<-glm(Rand_MVC~PropDev500 + PropShrub500 + PropBare500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A67)
res67g<-resid(Comp500A67)
fit67g<-fitted(Comp500A67)
plot(fit67g,res67g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDev500 + PropShrub500 + PropBare500", pch=16)
Comp500A68<-glm(Rand_MVC~PropGrass500 + PropShrub500 + PropBare500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A68)
res68g<-resid(Comp500A68)
fit68g<-fitted(Comp500A68)
plot(fit68g,res68g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropGrass500 + PropShrub500 + PropBare500", pch=16)
Comp500A69<-glm(Rand_MVC~PropDecid500 + PropConif500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A69)
res69g<-resid(Comp500A69)
fit69g<-fitted(Comp500A69)
plot(fit69g,res69g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid500 + PropConif500", pch=16)
Comp500A70<-glm(Rand_MVC~PropDecid500 + PropWater500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A70)
res70g<-resid(Comp500A70)
fit70g<-fitted(Comp500A70)
plot(fit70g,res70g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid500 + PropWater500", pch=16)
Comp500A71<-glm(Rand_MVC~PropDecid500 + PropDev500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A71)
res71g<-resid(Comp500A71)
fit71g<-fitted(Comp500A71)
plot(fit71g,res71g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid500 + PropDev500", pch=16)
Comp500A72<-glm(Rand_MVC~PropDecid500 + PropGrass500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A72)
res72g<-resid(Comp500A72)
fit72g<-fitted(Comp500A72)
plot(fit72g,res72g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid500 + PropGrass500", pch=16)
Comp500A73<-glm(Rand_MVC~PropDecid500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A73)
res73g<-resid(Comp500A73)
fit73g<-fitted(Comp500A73)
plot(fit73g,res73g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid500 + PropShrub500", pch=16)
Comp500A74<-glm(Rand_MVC~PropConif500 + PropWater500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A74)
res74g<-resid(Comp500A74)
fit74g<-fitted(Comp500A74)
plot(fit74g,res74g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif500 + PropWater500", pch=16)
Comp500A75<-glm(Rand_MVC~PropConif500 + PropDev500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A75)
res75g<-resid(Comp500A75)
fit75g<-fitted(Comp500A75)
plot(fit75g,res75g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif500 + PropDev500", pch=16)
Comp500A76<-glm(Rand_MVC~PropConif500 + PropGrass500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A76)
res76g<-resid(Comp500A76)
fit76g<-fitted(Comp500A76)
plot(fit76g,res76g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif500 + PropGrass500", pch=16)
Comp500A77<-glm(Rand_MVC~PropConif500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A77)
res77g<-resid(Comp500A77)
fit77g<-fitted(Comp500A77)
plot(fit77g,res77g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif500 + PropShrub500", pch=16)
Comp500A78<-glm(Rand_MVC~PropConif500 + PropBare500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A78)
res78g<-resid(Comp500A78)
fit78g<-fitted(Comp500A78)
plot(fit78g,res78g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif500 + PropBare500", pch=16)
Comp500A79<-glm(Rand_MVC~PropWater500 + PropDev500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A79)
res79g<-resid(Comp500A79)
fit79g<-fitted(Comp500A79)
plot(fit79g,res79g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater500 + PropDev500", pch=16)
Comp500A80<-glm(Rand_MVC~PropWater500 + PropGrass500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A80)
res80g<-resid(Comp500A80)
fit80g<-fitted(Comp500A80)
plot(fit80g,res80g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater500 + PropGrass500", pch=16)
Comp500A81<-glm(Rand_MVC~PropWater500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A81)
res81g<-resid(Comp500A81)
fit81g<-fitted(Comp500A81)
plot(fit81g,res81g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater500 + PropShrub500", pch=16)
Comp500A82<-glm(Rand_MVC~PropWater500 + PropBare500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A82)
res82g<-resid(Comp500A82)
fit82g<-fitted(Comp500A82)
plot(fit82g,res82g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater500 + PropBare500", pch=16)
Comp500A83<-glm(Rand_MVC~PropDev500 + PropGrass500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A83)
res83g<-resid(Comp500A83)
fit83g<-fitted(Comp500A83)
plot(fit83g,res83g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDev500 + PropGrass500", pch=16)
Comp500A84<-glm(Rand_MVC~PropDev500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A84)
res84g<-resid(Comp500A84)
fit84g<-fitted(Comp500A84)
plot(fit84g,res84g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDev500 + PropShrub500", pch=16)
Comp500A85<-glm(Rand_MVC~PropDev500 + PropBare500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A85)
res85g<-resid(Comp500A85)
fit85g<-fitted(Comp500A85)
plot(fit85g,res85g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDev500 + PropBare500", pch=16)
Comp500A86<-glm(Rand_MVC~PropGrass500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A86)
res86g<-resid(Comp500A86)
fit86g<-fitted(Comp500A86)
plot(fit86g,res86g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropGrass500 + PropShrub500", pch=16)
Comp500A87<-glm(Rand_MVC~PropGrass500 + PropBare500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A87)
res87g<-resid(Comp500A87)
fit87g<-fitted(Comp500A87)
plot(fit87g,res87g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropGrass500 + PropBare500", pch=16)
Comp500A88<-glm(Rand_MVC~PropShrub500 + PropBare500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A88)
res88g<-resid(Comp500A88)
fit88g<-fitted(Comp500A88)
plot(fit88g,res88g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropShrub500 + PropBare500", pch=16)
Comp500A89<-glm(Rand_MVC~PropDecid500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A89)
res89g<-resid(Comp500A89)
fit89g<-fitted(Comp500A89)
plot(fit89g,res89g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid500", pch=16)
Comp500A90<-glm(Rand_MVC~PropConif500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A90)
res90g<-resid(Comp500A90)
fit90g<-fitted(Comp500A90)
plot(fit90g,res90g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif500", pch=16)
Comp500A91<-glm(Rand_MVC~PropWater500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A91)
res91g<-resid(Comp500A91)
fit91g<-fitted(Comp500A91)
plot(fit91g,res91g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater500", pch=16)
Comp500A92<-glm(Rand_MVC~PropDev500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A92)
res92g<-resid(Comp500A92)
fit92g<-fitted(Comp500A92)
plot(fit92g,res92g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDev500", pch=16)
Comp500A93<-glm(Rand_MVC~PropGrass500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A93)
res93g<-resid(Comp500A93)
fit93g<-fitted(Comp500A93)
plot(fit93g,res93g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropGrass500", pch=16)
Comp500A94<-glm(Rand_MVC~PropShrub500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A94)
res94g<-resid(Comp500A94)
fit94g<-fitted(Comp500A94)
plot(fit94g,res94g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropShrub500", pch=16)
Comp500A95<-glm(Rand_MVC~PropBare500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A95)
res95g<-resid(Comp500A95)
fit95g<-fitted(Comp500A95)
plot(fit95g,res95g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropBare500", pch=16)

library(AICcmodavg)
Cand.models <- list( )
Cand.models[[1]]<-glm(Rand_MVC~PropDecid500 + PropConif500 + PropWater500 + PropDev500 + PropGrass500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
Cand.models[[2]]<-glm(Rand_MVC~PropConif500 + PropWater500 + PropDev500 + PropGrass500 + PropShrub500 + PropBare500, family=binomial(link="logit"), data=spatialall)
Cand.models[[3]]<-glm(Rand_MVC~PropDecid500 + PropConif500 + PropWater500 + PropDev500 + PropGrass500, family=binomial(link="logit"), data=spatialall)
Cand.models[[4]]<-glm(Rand_MVC~PropDecid500 + PropConif500 + PropWater500 + PropDev500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
Cand.models[[5]]<-glm(Rand_MVC~PropDecid500 + PropConif500 + PropWater500 + PropGrass500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
Cand.models[[6]]<-glm(Rand_MVC~PropDecid500 + PropConif500 + PropDev500 + PropGrass500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
Cand.models[[7]]<-glm(Rand_MVC~PropDecid500 + PropWater500 + PropDev500 + PropGrass500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
Cand.models[[8]]<-glm(Rand_MVC~PropConif500 + PropWater500 + PropDev500 + PropGrass500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
Cand.models[[9]]<-glm(Rand_MVC~PropConif500 + PropWater500 + PropDev500 + PropGrass500 + PropBare500, family=binomial(link="logit"), data=spatialall)
Cand.models[[10]]<-glm(Rand_MVC~PropConif500 + PropWater500 + PropDev500 + PropShrub500 + PropBare500, family=binomial(link="logit"), data=spatialall)
Cand.models[[11]]<-glm(Rand_MVC~PropConif500 + PropWater500 + PropGrass500 + PropShrub500 + PropBare500, family=binomial(link="logit"), data=spatialall)
Cand.models[[12]]<-glm(Rand_MVC~PropConif500 + PropDev500 + PropGrass500 + PropShrub500 + PropBare500, family=binomial(link="logit"), data=spatialall)
Cand.models[[13]]<-glm(Rand_MVC~PropWater500 + PropDev500 + PropGrass500 + PropShrub500 + PropBare500, family=binomial(link="logit"), data=spatialall)
Cand.models[[14]]<-glm(Rand_MVC~PropDecid500 + PropConif500 + PropWater500 + PropDev500, family=binomial(link="logit"), data=spatialall)
Cand.models[[15]]<-glm(Rand_MVC~PropDecid500 + PropConif500 + PropWater500 + PropGrass500, family=binomial(link="logit"), data=spatialall)
Cand.models[[16]]<-glm(Rand_MVC~PropDecid500 + PropConif500 + PropWater500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
Cand.models[[17]]<-glm(Rand_MVC~PropDecid500 + PropConif500 + PropDev500 + PropGrass500, family=binomial(link="logit"), data=spatialall)
Cand.models[[18]]<-glm(Rand_MVC~PropDecid500 + PropConif500 + PropDev500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
Cand.models[[19]]<-glm(Rand_MVC~PropDecid500 + PropConif500 + PropGrass500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
Cand.models[[20]]<-glm(Rand_MVC~PropDecid500 + PropWater500 + PropDev500 + PropGrass500, family=binomial(link="logit"), data=spatialall)
Cand.models[[21]]<-glm(Rand_MVC~PropDecid500 + PropWater500 + PropDev500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
Cand.models[[22]]<-glm(Rand_MVC~PropDecid500 + PropWater500 + PropGrass500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
Cand.models[[23]]<-glm(Rand_MVC~PropDecid500 + PropDev500 + PropGrass500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
Cand.models[[24]]<-glm(Rand_MVC~PropConif500 + PropWater500 + PropDev500 + PropGrass500, family=binomial(link="logit"), data=spatialall)
Cand.models[[25]]<-glm(Rand_MVC~PropConif500 + PropWater500 + PropDev500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
Cand.models[[26]]<-glm(Rand_MVC~PropConif500 + PropWater500 + PropDev500 + PropBare500, family=binomial(link="logit"), data=spatialall)
Cand.models[[27]]<-glm(Rand_MVC~PropConif500 + PropWater500 + PropGrass500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
Cand.models[[28]]<-glm(Rand_MVC~PropConif500 + PropWater500 + PropGrass500 + PropBare500, family=binomial(link="logit"), data=spatialall)
Cand.models[[29]]<-glm(Rand_MVC~PropConif500 + PropWater500 + PropShrub500 + PropBare500, family=binomial(link="logit"), data=spatialall)
Cand.models[[30]]<-glm(Rand_MVC~PropConif500 + PropDev500 + PropGrass500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
Cand.models[[31]]<-glm(Rand_MVC~PropConif500 + PropDev500 + PropGrass500 + PropBare500, family=binomial(link="logit"), data=spatialall)
Cand.models[[32]]<-glm(Rand_MVC~PropConif500 + PropDev500 + PropShrub500 + PropBare500, family=binomial(link="logit"), data=spatialall)
Cand.models[[33]]<-glm(Rand_MVC~PropConif500 + PropGrass500 + PropShrub500 + PropBare500, family=binomial(link="logit"), data=spatialall)
Cand.models[[34]]<-glm(Rand_MVC~PropWater500 + PropDev500 + PropGrass500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
Cand.models[[35]]<-glm(Rand_MVC~PropWater500 + PropDev500 + PropGrass500 + PropBare500, family=binomial(link="logit"), data=spatialall)
Cand.models[[36]]<-glm(Rand_MVC~PropWater500 + PropDev500 + PropShrub500 + PropBare500, family=binomial(link="logit"), data=spatialall)
Cand.models[[37]]<-glm(Rand_MVC~PropWater500 + PropGrass500 + PropShrub500 + PropBare500, family=binomial(link="logit"), data=spatialall)
Cand.models[[38]]<-glm(Rand_MVC~PropDev500 + PropGrass500 + PropShrub500 + PropBare500, family=binomial(link="logit"), data=spatialall)
Cand.models[[39]]<-glm(Rand_MVC~PropDecid500 + PropConif500 + PropWater500, family=binomial(link="logit"), data=spatialall)
Cand.models[[40]]<-glm(Rand_MVC~PropDecid500 + PropConif500 + PropDev500, family=binomial(link="logit"), data=spatialall)
Cand.models[[41]]<-glm(Rand_MVC~PropDecid500 + PropConif500 + PropGrass500, family=binomial(link="logit"), data=spatialall)
Cand.models[[42]]<-glm(Rand_MVC~PropDecid500 + PropConif500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
Cand.models[[43]]<-glm(Rand_MVC~PropDecid500 + PropWater500 + PropDev500, family=binomial(link="logit"), data=spatialall)
Cand.models[[44]]<-glm(Rand_MVC~PropDecid500 + PropWater500 + PropGrass500, family=binomial(link="logit"), data=spatialall)
Cand.models[[45]]<-glm(Rand_MVC~PropDecid500 + PropWater500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
Cand.models[[46]]<-glm(Rand_MVC~PropDecid500 + PropDev500 + PropGrass500, family=binomial(link="logit"), data=spatialall)
Cand.models[[47]]<-glm(Rand_MVC~PropDecid500 + PropDev500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
Cand.models[[48]]<-glm(Rand_MVC~PropDecid500 + PropGrass500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
Cand.models[[49]]<-glm(Rand_MVC~PropConif500 + PropWater500 + PropDev500, family=binomial(link="logit"), data=spatialall)
Cand.models[[50]]<-glm(Rand_MVC~PropConif500 + PropWater500 + PropGrass500, family=binomial(link="logit"), data=spatialall)
Cand.models[[51]]<-glm(Rand_MVC~PropConif500 + PropWater500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
Cand.models[[52]]<-glm(Rand_MVC~PropConif500 + PropWater500 + PropBare500, family=binomial(link="logit"), data=spatialall)
Cand.models[[53]]<-glm(Rand_MVC~PropConif500 + PropDev500 + PropGrass500, family=binomial(link="logit"), data=spatialall)
Cand.models[[54]]<-glm(Rand_MVC~PropConif500 + PropDev500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
Cand.models[[55]]<-glm(Rand_MVC~PropConif500 + PropDev500 + PropBare500, family=binomial(link="logit"), data=spatialall)
Cand.models[[56]]<-glm(Rand_MVC~PropConif500 + PropGrass500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
Cand.models[[57]]<-glm(Rand_MVC~PropConif500 + PropGrass500 + PropBare500, family=binomial(link="logit"), data=spatialall)
Cand.models[[58]]<-glm(Rand_MVC~PropConif500 + PropShrub500 + PropBare500, family=binomial(link="logit"), data=spatialall)
Cand.models[[59]]<-glm(Rand_MVC~PropWater500 + PropDev500 + PropGrass500, family=binomial(link="logit"), data=spatialall)
Cand.models[[60]]<-glm(Rand_MVC~PropWater500 + PropDev500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
Cand.models[[61]]<-glm(Rand_MVC~PropWater500 + PropDev500 + PropBare500, family=binomial(link="logit"), data=spatialall)
Cand.models[[62]]<-glm(Rand_MVC~PropWater500 + PropGrass500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
Cand.models[[63]]<-glm(Rand_MVC~PropWater500 + PropGrass500 + PropBare500, family=binomial(link="logit"), data=spatialall)
Cand.models[[64]]<-glm(Rand_MVC~PropWater500 + PropShrub500 + PropBare500, family=binomial(link="logit"), data=spatialall)
Cand.models[[65]]<-glm(Rand_MVC~PropDev500 + PropGrass500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
Cand.models[[66]]<-glm(Rand_MVC~PropDev500 + PropGrass500 + PropBare500, family=binomial(link="logit"), data=spatialall)
Cand.models[[67]]<-glm(Rand_MVC~PropDev500 + PropShrub500 + PropBare500, family=binomial(link="logit"), data=spatialall)
Cand.models[[68]]<-glm(Rand_MVC~PropGrass500 + PropShrub500 + PropBare500, family=binomial(link="logit"), data=spatialall)
Cand.models[[69]]<-glm(Rand_MVC~PropDecid500 + PropConif500, family=binomial(link="logit"), data=spatialall)
Cand.models[[70]]<-glm(Rand_MVC~PropDecid500 + PropWater500, family=binomial(link="logit"), data=spatialall)
Cand.models[[71]]<-glm(Rand_MVC~PropDecid500 + PropDev500, family=binomial(link="logit"), data=spatialall)
Cand.models[[72]]<-glm(Rand_MVC~PropDecid500 + PropGrass500, family=binomial(link="logit"), data=spatialall)
Cand.models[[73]]<-glm(Rand_MVC~PropDecid500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
Cand.models[[74]]<-glm(Rand_MVC~PropConif500 + PropWater500, family=binomial(link="logit"), data=spatialall)
Cand.models[[75]]<-glm(Rand_MVC~PropConif500 + PropDev500, family=binomial(link="logit"), data=spatialall)
Cand.models[[76]]<-glm(Rand_MVC~PropConif500 + PropGrass500, family=binomial(link="logit"), data=spatialall)
Cand.models[[77]]<-glm(Rand_MVC~PropConif500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
Cand.models[[78]]<-glm(Rand_MVC~PropConif500 + PropBare500, family=binomial(link="logit"), data=spatialall)
Cand.models[[79]]<-glm(Rand_MVC~PropWater500 + PropDev500, family=binomial(link="logit"), data=spatialall)
Cand.models[[80]]<-glm(Rand_MVC~PropWater500 + PropGrass500, family=binomial(link="logit"), data=spatialall)
Cand.models[[81]]<-glm(Rand_MVC~PropWater500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
Cand.models[[82]]<-glm(Rand_MVC~PropWater500 + PropBare500, family=binomial(link="logit"), data=spatialall)
Cand.models[[83]]<-glm(Rand_MVC~PropDev500 + PropGrass500, family=binomial(link="logit"), data=spatialall)
Cand.models[[84]]<-glm(Rand_MVC~PropDev500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
Cand.models[[85]]<-glm(Rand_MVC~PropDev500 + PropBare500, family=binomial(link="logit"), data=spatialall)
Cand.models[[86]]<-glm(Rand_MVC~PropGrass500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
Cand.models[[87]]<-glm(Rand_MVC~PropGrass500 + PropBare500, family=binomial(link="logit"), data=spatialall)
Cand.models[[88]]<-glm(Rand_MVC~PropShrub500 + PropBare500, family=binomial(link="logit"), data=spatialall)
Cand.models[[89]]<-glm(Rand_MVC~PropDecid500, family=binomial(link="logit"), data=spatialall)
Cand.models[[90]]<-glm(Rand_MVC~PropConif500, family=binomial(link="logit"), data=spatialall)
Cand.models[[91]]<-glm(Rand_MVC~PropWater500, family=binomial(link="logit"), data=spatialall)
Cand.models[[92]]<-glm(Rand_MVC~PropDev500, family=binomial(link="logit"), data=spatialall)
Cand.models[[93]]<-glm(Rand_MVC~PropGrass500, family=binomial(link="logit"), data=spatialall)
Cand.models[[94]]<-glm(Rand_MVC~PropShrub500, family=binomial(link="logit"), data=spatialall)
Cand.models[[95]]<-glm(Rand_MVC~PropBare500, family=binomial(link="logit"), data=spatialall)

##create a vector of names to trace back models in set
Modnames <- c("Comp500A1", "Comp500A2", "Comp500A3", "Comp500A4","Comp500A5", "Comp500A6", "Comp500A7", "Comp500A8", "Comp500A9", "Comp500A10", "Comp500A11", "Comp500A12", 
              "Comp500A13", "Comp500A14", "Comp500A15", "Comp500A16", "Comp500A17","Comp500A18", "Comp500A19", "Comp500A20", "Comp500A21", "Comp500A22", "Comp500A23", 
              "Comp500A24", "Comp500A25", "Comp500A26", "Comp500A27", "Comp500A28", "Comp500A29", "Comp500A30", "Comp500A31", "Comp500A32", "Comp500A33", "Comp500A34", 
              "Comp500A35", "Comp500A36", "Comp500A37", "Comp500A38", "Comp500A39", "Comp500A40", "Comp500A41", "Comp500A42", "Comp500A43", "Comp500A44", "Comp500A45", 
              "Comp500A46", "Comp500A47", "Comp500A48", "Comp500A49","Comp500A50", "Comp500A51", "Comp500A52", "Comp500A53", "Comp500A54", "Comp500A55", "Comp500A56", 
              "Comp500A57", "Comp500A58", "Comp500A59", "Comp500A60", "Comp500A61", "Comp500A62", "Comp500A63", "Comp500A64", "Comp500A65", "Comp500A66", "Comp500A67", 
              "Comp500A68", "Comp500A69", "Comp500A70", "Comp500A71", "Comp500A72", "Comp500A73", "Comp500A74", "Comp500A75", "Comp500A76", "Comp500A77", "Comp500A78",
              "Comp500A79", "Comp500A80", "Comp500A81", "Comp500A82", "Comp500A83", "Comp500A84", "Comp500A85", "Comp500A86", "Comp500A87", "Comp500A88", "Comp500A89", 
              "Comp500A90", "Comp500A91", "Comp500A92", "Comp500A93", "Comp500A94", "Comp500A95")

##generate AICc table
aictab(cand.set = Cand.models, modnames = Modnames, sort = TRUE)
##round to 4 digits after decimal point and give log-likelihood
print(aictab(cand.set = Cand.models, modnames = Modnames, sort = TRUE),
      digits = 4, LL = TRUE)

Modnames <- data.frame(Names=c("Comp500A1", "Comp500A2", "Comp500A3", "Comp500A4","Comp500A5", "Comp500A6", "Comp500A7", "Comp500A8", "Comp500A9", "Comp500A10", "Comp500A11", "Comp500A12", 
                               "Comp500A13", "Comp500A14", "Comp500A15", "Comp500A16", "Comp500A17","Comp500A18", "Comp500A19", "Comp500A20", "Comp500A21", "Comp500A22", "Comp500A23", 
                               "Comp500A24", "Comp500A25", "Comp500A26", "Comp500A27", "Comp500A28", "Comp500A29", "Comp500A30", "Comp500A31", "Comp500A32", "Comp500A33", "Comp500A34", 
                               "Comp500A35", "Comp500A36", "Comp500A37", "Comp500A38", "Comp500A39", "Comp500A40", "Comp500A41", "Comp500A42", "Comp500A43", "Comp500A44", "Comp500A45", 
                               "Comp500A46", "Comp500A47", "Comp500A48", "Comp500A49","Comp500A50", "Comp500A51", "Comp500A52", "Comp500A53", "Comp500A54", "Comp500A55", "Comp500A56", 
                               "Comp500A57", "Comp500A58", "Comp500A59", "Comp500A60", "Comp500A61", "Comp500A62", "Comp500A63", "Comp500A64", "Comp500A65", "Comp500A66", "Comp500A67", 
                               "Comp500A68", "Comp500A69", "Comp500A70", "Comp500A71", "Comp500A72", "Comp500A73", "Comp500A74", "Comp500A75", "Comp500A76", "Comp500A77", "Comp500A78",
                               "Comp500A79", "Comp500A80", "Comp500A81", "Comp500A82", "Comp500A83", "Comp500A84", "Comp500A85", "Comp500A86", "Comp500A87", "Comp500A88", "Comp500A89", 
                               "Comp500A90", "Comp500A91", "Comp500A92", "Comp500A93", "Comp500A94", "Comp500A95"))

##for each model in Modnames run function NagelkerkeR2
library(fmsb)
Nag <- NULL
Nag <- rbind(Nag, data.frame(Nag=sapply(1:nrow(Modnames), function(i) {NagelkerkeR2(Cand.models[[i]])})))
Nag

##for each model in Modnames run deviance explained (null-resid)/null
library(fmsb)
Dev <- NULL
Dev <- rbind(Dev, data.frame(Dev=sapply(1:nrow(Modnames), function(i) {((Cand.models[[i]]$null.deviance-Cand.models[[i]]$deviance)/Cand.models[[i]]$null.deviance)})))
Dev

## Composition Based Models - 2736 Buffer 
Comp2736A1<-glm(Rand_MVC~PropDecid2736 + PropConif2736 + PropWater2736 + PropDev2736 + PropGrass2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A1)
res1h<-resid(Comp2736A1)
fit1h<-fitted(Comp2736A1)
plot(fit1h,res1h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid2736 & PropConif2736 & PropWater2736 & PropDev2736 & PropGrass2736 & PropShrub2736", pch=16)
Comp2736A2<-glm(Rand_MVC~PropConif2736 + PropWater2736 + PropDev2736 + PropGrass2736 + PropShrub2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A2)
res2h<-resid(Comp2736A2)
fit2h<-fitted(Comp2736A2)
plot(fit2h,res2h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif2736 & PropWater2736 & PropDev2736 & PropGrass2736 & PropShrub2736 & PropBare2736", pch=16)
Comp2736A3<-glm(Rand_MVC~PropDecid2736 + PropConif2736 + PropWater2736 + PropDev2736 + PropGrass2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A3)
res3h<-resid(Comp2736A3)
fit3h<-fitted(Comp2736A3)
plot(fit3h,res3h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid2736 & PropConif2736 & PropWater2736 & PropDev2736 & PropGrass2736", pch=16)
Comp2736A4<-glm(Rand_MVC~PropDecid2736 + PropConif2736 + PropWater2736 + PropDev2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A4)
res4h<-resid(Comp2736A4)
fit4h<-fitted(Comp2736A4)
plot(fit4h,res4h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid2736 & PropConif2736 & PropWater2736 & PropDev2736 & PropShrub2736", pch=16)
Comp2736A5<-glm(Rand_MVC~PropDecid2736 + PropConif2736 + PropWater2736 + PropGrass2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A5)
res5h<-resid(Comp2736A5)
fit5h<-fitted(Comp2736A5)
plot(fit5h,res5h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid2736 & PropConif2736 & PropWater2736 & PropGrass2736 & PropShrub2736", pch=16)
Comp2736A6<-glm(Rand_MVC~PropDecid2736 + PropConif2736 + PropDev2736 + PropGrass2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A6)
res6h<-resid(Comp2736A6)
fit6h<-fitted(Comp2736A6)
plot(fit6h,res6h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid2736 & PropConif2736 & PropDev2736 & PropGrass2736 & PropShrub2736", pch=16)
Comp2736A7<-glm(Rand_MVC~PropDecid2736 + PropWater2736 + PropDev2736 + PropGrass2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A7)
res7h<-resid(Comp2736A7)
fit7h<-fitted(Comp2736A7)
plot(fit7h,res7h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid2736 & PropWater2736 & PropDev2736 & PropGrass2736 & PropShrub2736", pch=16)
Comp2736A8<-glm(Rand_MVC~PropConif2736 + PropWater2736 + PropDev2736 + PropGrass2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A8)
res8h<-resid(Comp2736A8)
fit8h<-fitted(Comp2736A8)
plot(fit8h,res8h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif2736 & PropWater2736 & PropDev2736 & PropGrass2736 & PropShrub2736", pch=16)
Comp2736A9<-glm(Rand_MVC~PropConif2736 + PropWater2736 + PropDev2736 + PropGrass2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A9)
res9h<-resid(Comp2736A9)
fit9h<-fitted(Comp2736A9)
plot(fit9h,res9h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif2736 + PropWater2736 + PropDev2736 + PropGrass2736 + PropBare2736", pch=16)
Comp2736A10<-glm(Rand_MVC~PropConif2736 + PropWater2736 + PropDev2736 + PropShrub2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A10)
res10h<-resid(Comp2736A10)
fit10h<-fitted(Comp2736A10)
plot(fit10h,res10h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif2736 + PropWater2736 + PropDev2736 + PropShrub2736 + PropBare2736", pch=16)
Comp2736A11<-glm(Rand_MVC~PropConif2736 + PropWater2736 + PropGrass2736 + PropShrub2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A11)
res11h<-resid(Comp2736A11)
fit11h<-fitted(Comp2736A11)
plot(fit11h,res11h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif2736 + PropWater2736 + PropDev2736 + PropShrub2736 + PropBare2736", pch=16)
Comp2736A12<-glm(Rand_MVC~PropConif2736 + PropDev2736 + PropGrass2736 + PropShrub2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A12)
res12h<-resid(Comp2736A12)
fit12h<-fitted(Comp2736A12)
plot(fit12h,res12h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif2736 + PropDev2736 + PropGrass2736 + PropShrub2736 + PropBare2736", pch=16)
Comp2736A13<-glm(Rand_MVC~PropWater2736 + PropDev2736 + PropGrass2736 + PropShrub2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A13)
res13h<-resid(Comp2736A13)
fit13h<-fitted(Comp2736A13)
plot(fit13h,res13h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater2736 + PropDev2736 + PropGrass2736 + PropShrub2736 + PropBare2736", pch=16)
Comp2736A14<-glm(Rand_MVC~PropDecid2736 + PropConif2736 + PropWater2736 + PropDev2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A14)
res14h<-resid(Comp2736A14)
fit14h<-fitted(Comp2736A14)
plot(fit14h,res14h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid2736 + PropConif2736 + PropWater2736 + PropDev2736", pch=16)
Comp2736A15<-glm(Rand_MVC~PropDecid2736 + PropConif2736 + PropWater2736 + PropGrass2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A15)
res15h<-resid(Comp2736A15)
fit15h<-fitted(Comp2736A15)
plot(fit15h,res15h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid2736 + PropConif2736 + PropWater2736 + PropGrass2736", pch=16)
Comp2736A16<-glm(Rand_MVC~PropDecid2736 + PropConif2736 + PropWater2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A16)
res16h<-resid(Comp2736A16)
fit16h<-fitted(Comp2736A16)
plot(fit16h,res16h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid2736 + PropConif2736 + PropWater2736 + PropShrub2736", pch=16)
Comp2736A17<-glm(Rand_MVC~PropDecid2736 + PropConif2736 + PropDev2736 + PropGrass2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A17)
res17h<-resid(Comp2736A17)
fit17h<-fitted(Comp2736A17)
plot(fit17h,res17h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid2736 + PropConif2736 + PropDev2736 + PropGrass2736", pch=16)
Comp2736A18<-glm(Rand_MVC~PropDecid2736 + PropConif2736 + PropDev2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A18)
res18h<-resid(Comp2736A18)
fit18h<-fitted(Comp2736A18)
plot(fit18h,res18h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid2736 + PropConif2736 + PropDev2736 + PropShrub2736", pch=16)
Comp2736A19<-glm(Rand_MVC~PropDecid2736 + PropConif2736 + PropGrass2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A19)
res19h<-resid(Comp2736A19)
fit19h<-fitted(Comp2736A19)
plot(fit19h,res19h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid2736 + PropConif2736 + PropGrass2736 + PropShrub2736", pch=16)
Comp2736A20<-glm(Rand_MVC~PropDecid2736 + PropWater2736 + PropDev2736 + PropGrass2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A20)
res20h<-resid(Comp2736A20)
fit20h<-fitted(Comp2736A20)
plot(fit20h,res20h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid2736 + PropWater2736 + PropDev2736 + PropGrass2736", pch=16)
Comp2736A21<-glm(Rand_MVC~PropDecid2736 + PropWater2736 + PropDev2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A21)
res21h<-resid(Comp2736A21)
fit21h<-fitted(Comp2736A21)
plot(fit21h,res21h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid2736 + PropWater2736 + PropDev2736 + PropShrub2736", pch=16)
Comp2736A22<-glm(Rand_MVC~PropDecid2736 + PropWater2736 + PropGrass2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A22)
res22h<-resid(Comp2736A22)
fit22h<-fitted(Comp2736A22)
plot(fit22h,res22h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid2736 + PropWater2736 + PropGrass2736 + PropShrub2736", pch=16)
Comp2736A23<-glm(Rand_MVC~PropDecid2736 + PropDev2736 + PropGrass2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A23)
res23h<-resid(Comp2736A23)
fit23h<-fitted(Comp2736A23)
plot(fit23h,res23h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid2736 + PropDev2736 + PropGrass2736 + PropShrub2736", pch=16)
Comp2736A24<-glm(Rand_MVC~PropConif2736 + PropWater2736 + PropDev2736 + PropGrass2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A24)
res24h<-resid(Comp2736A24)
fit24h<-fitted(Comp2736A24)
plot(fit24h,res24h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif2736 + PropWater2736 + PropDev2736 + PropGrass2736", pch=16)
Comp2736A25<-glm(Rand_MVC~PropConif2736 + PropWater2736 + PropDev2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A25)
res25h<-resid(Comp2736A25)
fit25h<-fitted(Comp2736A25)
plot(fit25h,res25h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif2736 + PropWater2736 + PropDev2736 + PropShrub2736", pch=16)
Comp2736A26<-glm(Rand_MVC~PropConif2736 + PropWater2736 + PropDev2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A26)
res26h<-resid(Comp2736A26)
fit26h<-fitted(Comp2736A26)
plot(fit26h,res26h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif2736 + PropWater2736 + PropDev2736 + PropBare2736", pch=16)
Comp2736A27<-glm(Rand_MVC~PropConif2736 + PropWater2736 + PropGrass2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A27)
res27h<-resid(Comp2736A27)
fit27h<-fitted(Comp2736A27)
plot(fit27h,res27h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif2736 + PropWater2736 + PropGrass2736 + PropShrub2736", pch=16)
Comp2736A28<-glm(Rand_MVC~PropConif2736 + PropWater2736 + PropGrass2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A28)
res28h<-resid(Comp2736A28)
fit28h<-fitted(Comp2736A28)
plot(fit28h,res28h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif2736 + PropWater2736 + PropGrass2736 + PropBare2736", pch=16)
Comp2736A29<-glm(Rand_MVC~PropConif2736 + PropWater2736 + PropShrub2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A29)
res29h<-resid(Comp2736A29)
fit29h<-fitted(Comp2736A29)
plot(fit29h,res29h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif2736 + PropWater2736 + PropShrub2736 + PropBare2736", pch=16)
Comp2736A30<-glm(Rand_MVC~PropConif2736 + PropDev2736 + PropGrass2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A30)
res30h<-resid(Comp2736A30)
fit30h<-fitted(Comp2736A30)
plot(fit30h,res30h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif2736 + PropDev2736 + PropGrass2736 + PropShrub2736", pch=16)
Comp2736A31<-glm(Rand_MVC~PropConif2736 + PropDev2736 + PropGrass2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A31)
res31h<-resid(Comp2736A31)
fit31h<-fitted(Comp2736A31)
plot(fit31h,res32h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif2736 + PropDev2736 + PropGrass2736 + PropBare2736", pch=16)
Comp2736A32<-glm(Rand_MVC~PropConif2736 + PropDev2736 + PropShrub2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A32)
res32h<-resid(Comp2736A32)
fit32h<-fitted(Comp2736A32)
plot(fit32h,res32h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif2736 + PropDev2736 + PropShrub2736 + PropBare2736", pch=16)
Comp2736A33<-glm(Rand_MVC~PropConif2736 + PropGrass2736 + PropShrub2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A33)
res33h<-resid(Comp2736A33)
fit33h<-fitted(Comp2736A33)
plot(fit33h,res34h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif2736 + PropGrass2736 + PropShrub2736 + PropBare2736", pch=16)
Comp2736A34<-glm(Rand_MVC~PropWater2736 + PropDev2736 + PropGrass2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A34)
res34h<-resid(Comp2736A34)
fit34h<-fitted(Comp2736A34)
plot(fit34h,res34h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater2736 + PropDev2736 + PropGrass2736 + PropShrub2736", pch=16)
Comp2736A35<-glm(Rand_MVC~PropWater2736 + PropDev2736 + PropGrass2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A35)
res35h<-resid(Comp2736A35)
fit35h<-fitted(Comp2736A35)
plot(fit35h,res35h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater2736 + PropDev2736 + PropGrass2736 + PropBare2736", pch=16)
Comp2736A36<-glm(Rand_MVC~PropWater2736 + PropDev2736 + PropShrub2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A36)
res36h<-resid(Comp2736A36)
fit36h<-fitted(Comp2736A36)
plot(fit36h,res36h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater2736 + PropDev2736 + PropShrub2736 + PropBare2736", pch=16)
Comp2736A37<-glm(Rand_MVC~PropWater2736 + PropGrass2736 + PropShrub2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A37)
res37h<-resid(Comp2736A37)
fit37h<-fitted(Comp2736A37)
plot(fit37h,res37h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater2736 + PropGrass2736 + PropShrub2736 + PropBare2736", pch=16)
Comp2736A38<-glm(Rand_MVC~PropDev2736 + PropGrass2736 + PropShrub2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A38)
res38h<-resid(Comp2736A38)
fit38h<-fitted(Comp2736A38)
plot(fit38h,res38h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDev2736 + PropGrass2736 + PropShrub2736 + PropBare2736", pch=16)
Comp2736A39<-glm(Rand_MVC~PropDecid2736 + PropConif2736 + PropWater2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A39)
res39h<-resid(Comp2736A39)
fit39h<-fitted(Comp2736A39)
plot(fit39h,res39h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid2736 + PropConif2736 + PropWater2736", pch=16)
Comp2736A40<-glm(Rand_MVC~PropDecid2736 + PropConif2736 + PropDev2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A40)
res40h<-resid(Comp2736A40)
fit40h<-fitted(Comp2736A40)
plot(fit40h,res40h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid2736 + PropConif2736 + PropDev2736", pch=16)
Comp2736A41<-glm(Rand_MVC~PropDecid2736 + PropConif2736 + PropGrass2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A41)
res41h<-resid(Comp2736A41)
fit41h<-fitted(Comp2736A41)
plot(fit41h,res41h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid2736 + PropConif2736 + PropGrass2736", pch=16)
Comp2736A42<-glm(Rand_MVC~PropDecid2736 + PropConif2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A42)
res42h<-resid(Comp2736A42)
fit42h<-fitted(Comp2736A42)
plot(fit42h,res42h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid2736 + PropConif2736 + PropShrub2736", pch=16)
Comp2736A43<-glm(Rand_MVC~PropDecid2736 + PropWater2736 + PropDev2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A43)
res43h<-resid(Comp2736A43)
fit43h<-fitted(Comp2736A43)
plot(fit43h,res43h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid2736 + PropWater2736 + PropDev2736", pch=16)
Comp2736A44<-glm(Rand_MVC~PropDecid2736 + PropWater2736 + PropGrass2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A44)
res44h<-resid(Comp2736A44)
fit44h<-fitted(Comp2736A44)
plot(fit44h,res44h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid2736 + PropWater2736 + PropGrass2736", pch=16)
Comp2736A45<-glm(Rand_MVC~PropDecid2736 + PropWater2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A45)
res45h<-resid(Comp2736A45)
fit45h<-fitted(Comp2736A45)
plot(fit45h,res45h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid2736 + PropWater2736 + PropShrub2736", pch=16)
Comp2736A46<-glm(Rand_MVC~PropDecid2736 + PropDev2736 + PropGrass2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A46)
res46h<-resid(Comp2736A46)
fit46h<-fitted(Comp2736A46)
plot(fit46h,res46h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid2736 + PropDev2736 + PropGrass2736", pch=16)
Comp2736A47<-glm(Rand_MVC~PropDecid2736 + PropDev2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A47)
res47h<-resid(Comp2736A47)
fit47h<-fitted(Comp2736A47)
plot(fit47h,res47h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid2736 + PropDev2736 + PropShrub2736", pch=16)
Comp2736A48<-glm(Rand_MVC~PropDecid2736 + PropGrass2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A48)
res48h<-resid(Comp2736A48)
fit48h<-fitted(Comp2736A48)
plot(fit48h,res48h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid2736 + PropGrass2736 + PropShrub2736", pch=16)
Comp2736A49<-glm(Rand_MVC~PropConif2736 + PropWater2736 + PropDev2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A49)
res49h<-resid(Comp2736A49)
fit49h<-fitted(Comp2736A49)
plot(fit49h,res49h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif2736 + PropWater2736 + PropDev2736", pch=16)
Comp2736A50<-glm(Rand_MVC~PropConif2736 + PropWater2736 + PropGrass2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A50)
res50h<-resid(Comp2736A50)
fit50h<-fitted(Comp2736A50)
plot(fit50h,res50h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif2736 + PropWater2736 + PropGrass2736", pch=16)
Comp2736A51<-glm(Rand_MVC~PropConif2736 + PropWater2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A51)
res51h<-resid(Comp2736A51)
fit51h<-fitted(Comp2736A51)
plot(fit51h,res51h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif2736 + PropWater2736 + PropShrub2736", pch=16)
Comp2736A52<-glm(Rand_MVC~PropConif2736 + PropWater2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A52)
res52h<-resid(Comp2736A52)
fit52h<-fitted(Comp2736A52)
plot(fit52h,res52h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif2736 + PropWater2736 + PropBare2736", pch=16)
Comp2736A53<-glm(Rand_MVC~PropConif2736 + PropDev2736 + PropGrass2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A53)
res53h<-resid(Comp2736A53)
fit53h<-fitted(Comp2736A53)
plot(fit53h,res53h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif2736 + PropDev2736 + PropGrass2736", pch=16)
Comp2736A54<-glm(Rand_MVC~PropConif2736 + PropDev2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A54)
res54h<-resid(Comp2736A54)
fit54h<-fitted(Comp2736A54)
plot(fit54h,res54h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif2736 + PropDev2736 + PropShrub2736", pch=16)
Comp2736A55<-glm(Rand_MVC~PropConif2736 + PropDev2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A55)
res55h<-resid(Comp2736A55)
fit55h<-fitted(Comp2736A55)
plot(fit55h,res55h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif2736 + PropDev2736 + PropBare2736", pch=16)
Comp2736A56<-glm(Rand_MVC~PropConif2736 + PropGrass2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A56)
res56h<-resid(Comp2736A56)
fit56h<-fitted(Comp2736A56)
plot(fit56h,res56h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif2736 + PropGrass2736 + PropShrub2736", pch=16)
Comp2736A57<-glm(Rand_MVC~PropConif2736 + PropGrass2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A57)
res57h<-resid(Comp2736A57)
fit57h<-fitted(Comp2736A57)
plot(fit57h,res57h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif2736 + PropGrass2736 + PropBare2736", pch=16)
Comp2736A58<-glm(Rand_MVC~PropConif2736 + PropShrub2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A58)
res58h<-resid(Comp2736A58)
fit58h<-fitted(Comp2736A58)
plot(fit58h,res58h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif2736 + PropShrub2736 + PropBare2736", pch=16)
Comp2736A59<-glm(Rand_MVC~PropWater2736 + PropDev2736 + PropGrass2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A59)
res59h<-resid(Comp2736A59)
fit59h<-fitted(Comp2736A59)
plot(fit59h,res59h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater2736 + PropDev2736 + PropGrass2736", pch=16)
Comp2736A60<-glm(Rand_MVC~PropWater2736 + PropDev2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A60)
res60h<-resid(Comp2736A60)
fit60h<-fitted(Comp2736A60)
plot(fit60h,res60h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater2736 + PropDev2736 + PropShrub2736", pch=16)
Comp2736A61<-glm(Rand_MVC~PropWater2736 + PropDev2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A61)
res61h<-resid(Comp2736A61)
fit61h<-fitted(Comp2736A61)
plot(fit61h,res61h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater2736 + PropDev2736 + PropBare2736", pch=16)
Comp2736A62<-glm(Rand_MVC~PropWater2736 + PropGrass2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A62)
res62h<-resid(Comp2736A62)
fit62h<-fitted(Comp2736A62)
plot(fit62h,res62h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater2736 + PropGrass2736 + PropShrub2736", pch=16)
Comp2736A63<-glm(Rand_MVC~PropWater2736 + PropGrass2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A63)
res63h<-resid(Comp2736A63)
fit63h<-fitted(Comp2736A63)
plot(fit63h,res63h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater2736 + PropGrass2736 + PropBare2736", pch=16)
Comp2736A64<-glm(Rand_MVC~PropWater2736 + PropShrub2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A64)
res64h<-resid(Comp2736A64)
fit64h<-fitted(Comp2736A64)
plot(fit64h,res64h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater2736 + PropShrub2736 + PropBare2736", pch=16)
Comp2736A65<-glm(Rand_MVC~PropDev2736 + PropGrass2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A65)
res65h<-resid(Comp2736A65)
fit65h<-fitted(Comp2736A65)
plot(fit65h,res65h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDev2736 + PropGrass2736 + PropShrub2736", pch=16)
Comp2736A66<-glm(Rand_MVC~PropDev2736 + PropGrass2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A66)
res66h<-resid(Comp2736A66)
fit66h<-fitted(Comp2736A66)
plot(fit66h,res66h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDev2736 + PropGrass2736 + PropBare2736", pch=16)
Comp2736A67<-glm(Rand_MVC~PropDev2736 + PropShrub2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A67)
res67h<-resid(Comp2736A67)
fit67h<-fitted(Comp2736A67)
plot(fit67h,res67h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDev2736 + PropShrub2736 + PropBare2736", pch=16)
Comp2736A68<-glm(Rand_MVC~PropGrass2736 + PropShrub2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A68)
res68h<-resid(Comp2736A68)
fit68h<-fitted(Comp2736A68)
plot(fit68h,res68h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropGrass2736 + PropShrub2736 + PropBare2736", pch=16)
Comp2736A69<-glm(Rand_MVC~PropDecid2736 + PropConif2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A69)
res69h<-resid(Comp2736A69)
fit69h<-fitted(Comp2736A69)
plot(fit69h,res69h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid2736 + PropConif2736", pch=16)
Comp2736A70<-glm(Rand_MVC~PropDecid2736 + PropWater2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A70)
res70h<-resid(Comp2736A70)
fit70h<-fitted(Comp2736A70)
plot(fit70h,res70h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid2736 + PropWater2736", pch=16)
Comp2736A71<-glm(Rand_MVC~PropDecid2736 + PropDev2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A71)
res71h<-resid(Comp2736A71)
fit71h<-fitted(Comp2736A71)
plot(fit71h,res71h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid2736 + PropDev2736", pch=16)
Comp2736A72<-glm(Rand_MVC~PropDecid2736 + PropGrass2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A72)
res72h<-resid(Comp2736A72)
fit72h<-fitted(Comp2736A72)
plot(fit72h,res72h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid2736 + PropGrass2736", pch=16)
Comp2736A73<-glm(Rand_MVC~PropDecid2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A73)
res73h<-resid(Comp2736A73)
fit73h<-fitted(Comp2736A73)
plot(fit73h,res73h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid2736 + PropShrub2736", pch=16)
Comp2736A74<-glm(Rand_MVC~PropConif2736 + PropWater2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A74)
res74h<-resid(Comp2736A74)
fit74h<-fitted(Comp2736A74)
plot(fit74h,res74h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif2736 + PropWater2736", pch=16)
Comp2736A75<-glm(Rand_MVC~PropConif2736 + PropDev2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A75)
res75h<-resid(Comp2736A75)
fit75h<-fitted(Comp2736A75)
plot(fit75h,res75h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif2736 + PropDev2736", pch=16)
Comp2736A76<-glm(Rand_MVC~PropConif2736 + PropGrass2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A76)
res76h<-resid(Comp2736A76)
fit76h<-fitted(Comp2736A76)
plot(fit76h,res76h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif2736 + PropGrass2736", pch=16)
Comp2736A77<-glm(Rand_MVC~PropConif2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A77)
res77h<-resid(Comp2736A77)
fit77h<-fitted(Comp2736A77)
plot(fit77h,res77h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif2736 + PropShrub2736", pch=16)
Comp2736A78<-glm(Rand_MVC~PropConif2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A78)
res78h<-resid(Comp2736A78)
fit78h<-fitted(Comp2736A78)
plot(fit78h,res78h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif2736 + PropBare2736", pch=16)
Comp2736A79<-glm(Rand_MVC~PropWater2736 + PropDev2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A79)
res79h<-resid(Comp2736A79)
fit79h<-fitted(Comp2736A79)
plot(fit79h,res79h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater2736 + PropDev2736", pch=16)
Comp2736A80<-glm(Rand_MVC~PropWater2736 + PropGrass2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A80)
res80h<-resid(Comp2736A80)
fit80h<-fitted(Comp2736A80)
plot(fit80h,res80h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater2736 + PropGrass2736", pch=16)
Comp2736A81<-glm(Rand_MVC~PropWater2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A81)
res81h<-resid(Comp2736A81)
fit81h<-fitted(Comp2736A81)
plot(fit81h,res81h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater2736 + PropShrub2736", pch=16)
Comp2736A82<-glm(Rand_MVC~PropWater2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A82)
res82h<-resid(Comp2736A82)
fit82h<-fitted(Comp2736A82)
plot(fit82h,res82h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater2736 + PropBare2736", pch=16)
Comp2736A83<-glm(Rand_MVC~PropDev2736 + PropGrass2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A83)
res83h<-resid(Comp2736A83)
fit83h<-fitted(Comp2736A83)
plot(fit83h,res83h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDev2736 + PropGrass2736", pch=16)
Comp2736A84<-glm(Rand_MVC~PropDev2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A84)
res84h<-resid(Comp2736A84)
fit84h<-fitted(Comp2736A84)
plot(fit84h,res84h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDev2736 + PropShrub2736", pch=16)
Comp2736A85<-glm(Rand_MVC~PropDev2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A85)
res85h<-resid(Comp2736A85)
fit85h<-fitted(Comp2736A85)
plot(fit85h,res85h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDev2736 + PropBare2736", pch=16)
Comp2736A86<-glm(Rand_MVC~PropGrass2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A86)
res86h<-resid(Comp2736A86)
fit86h<-fitted(Comp2736A86)
plot(fit86h,res86h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropGrass2736 + PropShrub2736", pch=16)
Comp2736A87<-glm(Rand_MVC~PropGrass2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A87)
res87h<-resid(Comp2736A87)
fit87h<-fitted(Comp2736A87)
plot(fit87h,res87h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropGrass2736 + PropBare2736", pch=16)
Comp2736A88<-glm(Rand_MVC~PropShrub2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A88)
res88h<-resid(Comp2736A88)
fit88h<-fitted(Comp2736A88)
plot(fit88h,res88h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropShrub2736 + PropBare2736", pch=16)
Comp2736A89<-glm(Rand_MVC~PropDecid2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A89)
res89h<-resid(Comp2736A89)
fit89h<-fitted(Comp2736A89)
plot(fit89h,res89h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid2736", pch=16)
Comp2736A90<-glm(Rand_MVC~PropConif2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A90)
res90h<-resid(Comp2736A90)
fit90h<-fitted(Comp2736A90)
plot(fit90h,res90h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif2736", pch=16)
Comp2736A91<-glm(Rand_MVC~PropWater2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A91)
res91h<-resid(Comp2736A91)
fit91h<-fitted(Comp2736A91)
plot(fit91h,res91h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater2736", pch=16)
Comp2736A92<-glm(Rand_MVC~PropDev2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A92)
res92h<-resid(Comp2736A92)
fit92h<-fitted(Comp2736A92)
plot(fit92h,res92h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDev2736", pch=16)
Comp2736A93<-glm(Rand_MVC~PropGrass2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A93)
res93h<-resid(Comp2736A93)
fit93h<-fitted(Comp2736A93)
plot(fit93h,res93h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropGrass2736", pch=16)
Comp2736A94<-glm(Rand_MVC~PropShrub2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A94)
res94h<-resid(Comp2736A94)
fit94h<-fitted(Comp2736A94)
plot(fit94h,res94h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropShrub2736", pch=16)
Comp2736A95<-glm(Rand_MVC~PropBare2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A95)
res95h<-resid(Comp2736A95)
fit95h<-fitted(Comp2736A95)
plot(fit95h,res95h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropBare2736", pch=16)

library(AICcmodavg)
Cand.models <- list( )
Cand.models[[1]]<-glm(Rand_MVC~PropDecid2736 + PropConif2736 + PropWater2736 + PropDev2736 + PropGrass2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[2]]<-glm(Rand_MVC~PropConif2736 + PropWater2736 + PropDev2736 + PropGrass2736 + PropShrub2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[3]]<-glm(Rand_MVC~PropDecid2736 + PropConif2736 + PropWater2736 + PropDev2736 + PropGrass2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[4]]<-glm(Rand_MVC~PropDecid2736 + PropConif2736 + PropWater2736 + PropDev2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[5]]<-glm(Rand_MVC~PropDecid2736 + PropConif2736 + PropWater2736 + PropGrass2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[6]]<-glm(Rand_MVC~PropDecid2736 + PropConif2736 + PropDev2736 + PropGrass2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[7]]<-glm(Rand_MVC~PropDecid2736 + PropWater2736 + PropDev2736 + PropGrass2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[8]]<-glm(Rand_MVC~PropConif2736 + PropWater2736 + PropDev2736 + PropGrass2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[9]]<-glm(Rand_MVC~PropConif2736 + PropWater2736 + PropDev2736 + PropGrass2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[10]]<-glm(Rand_MVC~PropConif2736 + PropWater2736 + PropDev2736 + PropShrub2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[11]]<-glm(Rand_MVC~PropConif2736 + PropWater2736 + PropGrass2736 + PropShrub2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[12]]<-glm(Rand_MVC~PropConif2736 + PropDev2736 + PropGrass2736 + PropShrub2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[13]]<-glm(Rand_MVC~PropWater2736 + PropDev2736 + PropGrass2736 + PropShrub2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[14]]<-glm(Rand_MVC~PropDecid2736 + PropConif2736 + PropWater2736 + PropDev2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[15]]<-glm(Rand_MVC~PropDecid2736 + PropConif2736 + PropWater2736 + PropGrass2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[16]]<-glm(Rand_MVC~PropDecid2736 + PropConif2736 + PropWater2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[17]]<-glm(Rand_MVC~PropDecid2736 + PropConif2736 + PropDev2736 + PropGrass2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[18]]<-glm(Rand_MVC~PropDecid2736 + PropConif2736 + PropDev2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[19]]<-glm(Rand_MVC~PropDecid2736 + PropConif2736 + PropGrass2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[20]]<-glm(Rand_MVC~PropDecid2736 + PropWater2736 + PropDev2736 + PropGrass2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[21]]<-glm(Rand_MVC~PropDecid2736 + PropWater2736 + PropDev2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[22]]<-glm(Rand_MVC~PropDecid2736 + PropWater2736 + PropGrass2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[23]]<-glm(Rand_MVC~PropDecid2736 + PropDev2736 + PropGrass2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[24]]<-glm(Rand_MVC~PropConif2736 + PropWater2736 + PropDev2736 + PropGrass2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[25]]<-glm(Rand_MVC~PropConif2736 + PropWater2736 + PropDev2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[26]]<-glm(Rand_MVC~PropConif2736 + PropWater2736 + PropDev2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[27]]<-glm(Rand_MVC~PropConif2736 + PropWater2736 + PropGrass2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[28]]<-glm(Rand_MVC~PropConif2736 + PropWater2736 + PropGrass2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[29]]<-glm(Rand_MVC~PropConif2736 + PropWater2736 + PropShrub2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[30]]<-glm(Rand_MVC~PropConif2736 + PropDev2736 + PropGrass2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[31]]<-glm(Rand_MVC~PropConif2736 + PropDev2736 + PropGrass2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[32]]<-glm(Rand_MVC~PropConif2736 + PropDev2736 + PropShrub2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[33]]<-glm(Rand_MVC~PropConif2736 + PropGrass2736 + PropShrub2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[34]]<-glm(Rand_MVC~PropWater2736 + PropDev2736 + PropGrass2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[35]]<-glm(Rand_MVC~PropWater2736 + PropDev2736 + PropGrass2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[36]]<-glm(Rand_MVC~PropWater2736 + PropDev2736 + PropShrub2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[37]]<-glm(Rand_MVC~PropWater2736 + PropGrass2736 + PropShrub2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[38]]<-glm(Rand_MVC~PropDev2736 + PropGrass2736 + PropShrub2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[39]]<-glm(Rand_MVC~PropDecid2736 + PropConif2736 + PropWater2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[40]]<-glm(Rand_MVC~PropDecid2736 + PropConif2736 + PropDev2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[41]]<-glm(Rand_MVC~PropDecid2736 + PropConif2736 + PropGrass2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[42]]<-glm(Rand_MVC~PropDecid2736 + PropConif2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[43]]<-glm(Rand_MVC~PropDecid2736 + PropWater2736 + PropDev2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[44]]<-glm(Rand_MVC~PropDecid2736 + PropWater2736 + PropGrass2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[45]]<-glm(Rand_MVC~PropDecid2736 + PropWater2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[46]]<-glm(Rand_MVC~PropDecid2736 + PropDev2736 + PropGrass2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[47]]<-glm(Rand_MVC~PropDecid2736 + PropDev2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[48]]<-glm(Rand_MVC~PropDecid2736 + PropGrass2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[49]]<-glm(Rand_MVC~PropConif2736 + PropWater2736 + PropDev2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[50]]<-glm(Rand_MVC~PropConif2736 + PropWater2736 + PropGrass2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[51]]<-glm(Rand_MVC~PropConif2736 + PropWater2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[52]]<-glm(Rand_MVC~PropConif2736 + PropWater2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[53]]<-glm(Rand_MVC~PropConif2736 + PropDev2736 + PropGrass2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[54]]<-glm(Rand_MVC~PropConif2736 + PropDev2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[55]]<-glm(Rand_MVC~PropConif2736 + PropDev2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[56]]<-glm(Rand_MVC~PropConif2736 + PropGrass2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[57]]<-glm(Rand_MVC~PropConif2736 + PropGrass2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[58]]<-glm(Rand_MVC~PropConif2736 + PropShrub2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[59]]<-glm(Rand_MVC~PropWater2736 + PropDev2736 + PropGrass2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[60]]<-glm(Rand_MVC~PropWater2736 + PropDev2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[61]]<-glm(Rand_MVC~PropWater2736 + PropDev2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[62]]<-glm(Rand_MVC~PropWater2736 + PropGrass2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[63]]<-glm(Rand_MVC~PropWater2736 + PropGrass2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[64]]<-glm(Rand_MVC~PropWater2736 + PropShrub2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[65]]<-glm(Rand_MVC~PropDev2736 + PropGrass2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[66]]<-glm(Rand_MVC~PropDev2736 + PropGrass2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[67]]<-glm(Rand_MVC~PropDev2736 + PropShrub2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[68]]<-glm(Rand_MVC~PropGrass2736 + PropShrub2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[69]]<-glm(Rand_MVC~PropDecid2736 + PropConif2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[70]]<-glm(Rand_MVC~PropDecid2736 + PropWater2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[71]]<-glm(Rand_MVC~PropDecid2736 + PropDev2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[72]]<-glm(Rand_MVC~PropDecid2736 + PropGrass2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[73]]<-glm(Rand_MVC~PropDecid2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[74]]<-glm(Rand_MVC~PropConif2736 + PropWater2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[75]]<-glm(Rand_MVC~PropConif2736 + PropDev2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[76]]<-glm(Rand_MVC~PropConif2736 + PropGrass2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[77]]<-glm(Rand_MVC~PropConif2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[78]]<-glm(Rand_MVC~PropConif2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[79]]<-glm(Rand_MVC~PropWater2736 + PropDev2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[80]]<-glm(Rand_MVC~PropWater2736 + PropGrass2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[81]]<-glm(Rand_MVC~PropWater2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[82]]<-glm(Rand_MVC~PropWater2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[83]]<-glm(Rand_MVC~PropDev2736 + PropGrass2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[84]]<-glm(Rand_MVC~PropDev2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[85]]<-glm(Rand_MVC~PropDev2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[86]]<-glm(Rand_MVC~PropGrass2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[87]]<-glm(Rand_MVC~PropGrass2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[88]]<-glm(Rand_MVC~PropShrub2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[89]]<-glm(Rand_MVC~PropDecid2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[90]]<-glm(Rand_MVC~PropConif2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[91]]<-glm(Rand_MVC~PropWater2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[92]]<-glm(Rand_MVC~PropDev2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[93]]<-glm(Rand_MVC~PropGrass2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[94]]<-glm(Rand_MVC~PropShrub2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[95]]<-glm(Rand_MVC~PropBare2736, family=binomial(link="logit"), data=spatialall)

##create a vector of names to trace back models in set
Modnames <- c("Comp2736A1", "Comp2736A2", "Comp2736A3", "Comp2736A4","Comp2736A5", "Comp2736A6", "Comp2736A7", "Comp2736A8", "Comp2736A9", "Comp2736A10", "Comp2736A11", "Comp2736A12", 
              "Comp2736A13", "Comp2736A14", "Comp2736A15", "Comp2736A16", "Comp2736A17","Comp2736A18", "Comp2736A19", "Comp2736A20", "Comp2736A21", "Comp2736A22", "Comp2736A23", 
              "Comp2736A24", "Comp2736A25", "Comp2736A26", "Comp2736A27", "Comp2736A28", "Comp2736A29", "Comp2736A30", "Comp2736A31", "Comp2736A32", "Comp2736A33", "Comp2736A34", 
              "Comp2736A35", "Comp2736A36", "Comp2736A37", "Comp2736A38", "Comp2736A39", "Comp2736A40", "Comp2736A41", "Comp2736A42", "Comp2736A43", "Comp2736A44", "Comp2736A45", 
              "Comp2736A46", "Comp2736A47", "Comp2736A48", "Comp2736A49","Comp2736A50", "Comp2736A51", "Comp2736A52", "Comp2736A53", "Comp2736A54", "Comp2736A55", "Comp2736A56", 
              "Comp2736A57", "Comp2736A58", "Comp2736A59", "Comp2736A60", "Comp2736A61", "Comp2736A62", "Comp2736A63", "Comp2736A64", "Comp2736A65", "Comp2736A66", "Comp2736A67", 
              "Comp2736A68", "Comp2736A69", "Comp2736A70", "Comp2736A71", "Comp2736A72", "Comp2736A73", "Comp2736A74", "Comp2736A75", "Comp2736A76", "Comp2736A77", "Comp2736A78",
              "Comp2736A79", "Comp2736A80", "Comp2736A81", "Comp2736A82", "Comp2736A83", "Comp2736A84", "Comp2736A85", "Comp2736A86", "Comp2736A87", "Comp2736A88", "Comp2736A89", 
              "Comp2736A90", "Comp2736A91", "Comp2736A92", "Comp2736A93", "Comp2736A94", "Comp2736A95")

##generate AICc table
aictab(cand.set = Cand.models, modnames = Modnames, sort = TRUE)
##round to 4 digits after decimal point and give log-likelihood
print(aictab(cand.set = Cand.models, modnames = Modnames, sort = TRUE),
      digits = 4, LL = TRUE)

Modnames <- data.frame(Names=c("Comp2736A1", "Comp2736A2", "Comp2736A3", "Comp2736A4","Comp2736A5", "Comp2736A6", "Comp2736A7", "Comp2736A8", "Comp2736A9", "Comp2736A10", "Comp2736A11", "Comp2736A12", 
                               "Comp2736A13", "Comp2736A14", "Comp2736A15", "Comp2736A16", "Comp2736A17","Comp2736A18", "Comp2736A19", "Comp2736A20", "Comp2736A21", "Comp2736A22", "Comp2736A23", 
                               "Comp2736A24", "Comp2736A25", "Comp2736A26", "Comp2736A27", "Comp2736A28", "Comp2736A29", "Comp2736A30", "Comp2736A31", "Comp2736A32", "Comp2736A33", "Comp2736A34", 
                               "Comp2736A35", "Comp2736A36", "Comp2736A37", "Comp2736A38", "Comp2736A39", "Comp2736A40", "Comp2736A41", "Comp2736A42", "Comp2736A43", "Comp2736A44", "Comp2736A45", 
                               "Comp2736A46", "Comp2736A47", "Comp2736A48", "Comp2736A49","Comp2736A50", "Comp2736A51", "Comp2736A52", "Comp2736A53", "Comp2736A54", "Comp2736A55", "Comp2736A56", 
                               "Comp2736A57", "Comp2736A58", "Comp2736A59", "Comp2736A60", "Comp2736A61", "Comp2736A62", "Comp2736A63", "Comp2736A64", "Comp2736A65", "Comp2736A66", "Comp2736A67", 
                               "Comp2736A68", "Comp2736A69", "Comp2736A70", "Comp2736A71", "Comp2736A72", "Comp2736A73", "Comp2736A74", "Comp2736A75", "Comp2736A76", "Comp2736A77", "Comp2736A78",
                               "Comp2736A79", "Comp2736A80", "Comp2736A81", "Comp2736A82", "Comp2736A83", "Comp2736A84", "Comp2736A85", "Comp2736A86", "Comp2736A87", "Comp2736A88", "Comp2736A89", 
                               "Comp2736A90", "Comp2736A91", "Comp2736A92", "Comp2736A93", "Comp2736A94", "Comp2736A95"))

##for each model in Modnames run function NagelkerkeR2
library(fmsb)
Nag <- NULL
Nag <- rbind(Nag, data.frame(Nag=sapply(1:nrow(Modnames), function(i) {NagelkerkeR2(Cand.models[[i]])})))
Nag

##for each model in Modnames run deviance explained (null-resid)/null
library(fmsb)
Dev <- NULL
Dev <- rbind(Dev, data.frame(Dev=sapply(1:nrow(Modnames), function(i) {((Cand.models[[i]]$null.deviance-Cand.models[[i]]$deviance)/Cand.models[[i]]$null.deviance)})))
Dev

## Composition Based Models - 5471 Buffer 
Comp5471A1<-glm(Rand_MVC~PropDecid5471 + PropConif5471 + PropWater5471 + PropDev5471 + PropGrass5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A1)
res1i<-resid(Comp5471A1)
fit1i<-fitted(Comp5471A1)
plot(fit1i,res1i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid5471 & PropConif5471 & PropWater5471 & PropDev5471 & PropGrass5471 & PropShrub5471", pch=16)
Comp5471A2<-glm(Rand_MVC~PropConif5471 + PropWater5471 + PropDev5471 + PropGrass5471 + PropShrub5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A2)
res2i<-resid(Comp5471A2)
fit2i<-fitted(Comp5471A2)
plot(fit2i,res2i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif5471 & PropWater5471 & PropDev5471 & PropGrass5471 & PropShrub5471 & PropBare5471", pch=16)
Comp5471A3<-glm(Rand_MVC~PropDecid5471 + PropConif5471 + PropWater5471 + PropDev5471 + PropGrass5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A3)
res3i<-resid(Comp5471A3)
fit3i<-fitted(Comp5471A3)
plot(fit3i,res3i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid5471 & PropConif5471 & PropWater5471 & PropDev5471 & PropGrass5471", pch=16)
Comp5471A4<-glm(Rand_MVC~PropDecid5471 + PropConif5471 + PropWater5471 + PropDev5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A4)
res4i<-resid(Comp5471A4)
fit4i<-fitted(Comp5471A4)
plot(fit4i,res4i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid5471 & PropConif5471 & PropWater5471 & PropDev5471 & PropShrub5471", pch=16)
Comp5471A5<-glm(Rand_MVC~PropDecid5471 + PropConif5471 + PropWater5471 + PropGrass5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A5)
res5i<-resid(Comp5471A5)
fit5i<-fitted(Comp5471A5)
plot(fit5i,res5i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid5471 & PropConif5471 & PropWater5471 & PropGrass5471 & PropShrub5471", pch=16)
Comp5471A6<-glm(Rand_MVC~PropDecid5471 + PropConif5471 + PropDev5471 + PropGrass5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A6)
res6i<-resid(Comp5471A6)
fit6i<-fitted(Comp5471A6)
plot(fit6i,res6i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid5471 & PropConif5471 & PropDev5471 & PropGrass5471 & PropShrub5471", pch=16)
Comp5471A7<-glm(Rand_MVC~PropDecid5471 + PropWater5471 + PropDev5471 + PropGrass5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A7)
res7i<-resid(Comp5471A7)
fit7i<-fitted(Comp5471A7)
plot(fit7i,res7i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid5471 & PropWater5471 & PropDev5471 & PropGrass5471 & PropShrub5471", pch=16)
Comp5471A8<-glm(Rand_MVC~PropConif5471 + PropWater5471 + PropDev5471 + PropGrass5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A8)
res8i<-resid(Comp5471A8)
fit8i<-fitted(Comp5471A8)
plot(fit8i,res8i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif5471 & PropWater5471 & PropDev5471 & PropGrass5471 & PropShrub5471", pch=16)
Comp5471A9<-glm(Rand_MVC~PropConif5471 + PropWater5471 + PropDev5471 + PropGrass5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A9)
res9i<-resid(Comp5471A9)
fit9i<-fitted(Comp5471A9)
plot(fit9i,res9i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif5471 + PropWater5471 + PropDev5471 + PropGrass5471 + PropBare5471", pch=16)
Comp5471A10<-glm(Rand_MVC~PropConif5471 + PropWater5471 + PropDev5471 + PropShrub5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A10)
res10i<-resid(Comp5471A10)
fit10i<-fitted(Comp5471A10)
plot(fit10i,res10i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif5471 + PropWater5471 + PropDev5471 + PropShrub5471 + PropBare5471", pch=16)
Comp5471A11<-glm(Rand_MVC~PropConif5471 + PropWater5471 + PropGrass5471 + PropShrub5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A11)
res11i<-resid(Comp5471A11)
fit11i<-fitted(Comp5471A11)
plot(fit11i,res11i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif5471 + PropWater5471 + PropDev5471 + PropShrub5471 + PropBare5471", pch=16)
Comp5471A12<-glm(Rand_MVC~PropConif5471 + PropDev5471 + PropGrass5471 + PropShrub5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A12)
res12i<-resid(Comp5471A12)
fit12i<-fitted(Comp5471A12)
plot(fit12i,res12i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif5471 + PropDev5471 + PropGrass5471 + PropShrub5471 + PropBare5471", pch=16)
Comp5471A13<-glm(Rand_MVC~PropWater5471 + PropDev5471 + PropGrass5471 + PropShrub5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A13)
res13i<-resid(Comp5471A13)
fit13i<-fitted(Comp5471A13)
plot(fit13i,res13i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater5471 + PropDev5471 + PropGrass5471 + PropShrub5471 + PropBare5471", pch=16)
Comp5471A14<-glm(Rand_MVC~PropDecid5471 + PropConif5471 + PropWater5471 + PropDev5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A14)
res14i<-resid(Comp5471A14)
fit14i<-fitted(Comp5471A14)
plot(fit14i,res14i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid5471 + PropConif5471 + PropWater5471 + PropDev5471", pch=16)
Comp5471A15<-glm(Rand_MVC~PropDecid5471 + PropConif5471 + PropWater5471 + PropGrass5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A15)
res15i<-resid(Comp5471A15)
fit15i<-fitted(Comp5471A15)
plot(fit15i,res15i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid5471 + PropConif5471 + PropWater5471 + PropGrass5471", pch=16)
Comp5471A16<-glm(Rand_MVC~PropDecid5471 + PropConif5471 + PropWater5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A16)
res16i<-resid(Comp5471A16)
fit16i<-fitted(Comp5471A16)
plot(fit16i,res16i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid5471 + PropConif5471 + PropWater5471 + PropShrub5471", pch=16)
Comp5471A17<-glm(Rand_MVC~PropDecid5471 + PropConif5471 + PropDev5471 + PropGrass5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A17)
res17i<-resid(Comp5471A17)
fit17i<-fitted(Comp5471A17)
plot(fit17i,res17i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid5471 + PropConif5471 + PropDev5471 + PropGrass5471", pch=16)
Comp5471A18<-glm(Rand_MVC~PropDecid5471 + PropConif5471 + PropDev5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A18)
res18i<-resid(Comp5471A18)
fit18i<-fitted(Comp5471A18)
plot(fit18i,res18i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid5471 + PropConif5471 + PropDev5471 + PropShrub5471", pch=16)
Comp5471A19<-glm(Rand_MVC~PropDecid5471 + PropConif5471 + PropGrass5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A19)
res19i<-resid(Comp5471A19)
fit19i<-fitted(Comp5471A19)
plot(fit19i,res19i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid5471 + PropConif5471 + PropGrass5471 + PropShrub5471", pch=16)
Comp5471A20<-glm(Rand_MVC~PropDecid5471 + PropWater5471 + PropDev5471 + PropGrass5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A20)
res20i<-resid(Comp5471A20)
fit20i<-fitted(Comp5471A20)
plot(fit20i,res20i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid5471 + PropWater5471 + PropDev5471 + PropGrass5471", pch=16)
Comp5471A21<-glm(Rand_MVC~PropDecid5471 + PropWater5471 + PropDev5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A21)
res21i<-resid(Comp5471A21)
fit21i<-fitted(Comp5471A21)
plot(fit21i,res21i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid5471 + PropWater5471 + PropDev5471 + PropShrub5471", pch=16)
Comp5471A22<-glm(Rand_MVC~PropDecid5471 + PropWater5471 + PropGrass5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A22)
res22i<-resid(Comp5471A22)
fit22i<-fitted(Comp5471A22)
plot(fit22i,res22i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid5471 + PropWater5471 + PropGrass5471 + PropShrub5471", pch=16)
Comp5471A23<-glm(Rand_MVC~PropDecid5471 + PropDev5471 + PropGrass5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A23)
res23i<-resid(Comp5471A23)
fit23i<-fitted(Comp5471A23)
plot(fit23i,res23i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid5471 + PropDev5471 + PropGrass5471 + PropShrub5471", pch=16)
Comp5471A24<-glm(Rand_MVC~PropConif5471 + PropWater5471 + PropDev5471 + PropGrass5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A24)
res24i<-resid(Comp5471A24)
fit24i<-fitted(Comp5471A24)
plot(fit24i,res24i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif5471 + PropWater5471 + PropDev5471 + PropGrass5471", pch=16)
Comp5471A25<-glm(Rand_MVC~PropConif5471 + PropWater5471 + PropDev5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A25)
res25i<-resid(Comp5471A25)
fit25i<-fitted(Comp5471A25)
plot(fit25i,res25i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif5471 + PropWater5471 + PropDev5471 + PropShrub5471", pch=16)
Comp5471A26<-glm(Rand_MVC~PropConif5471 + PropWater5471 + PropDev5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A26)
res26i<-resid(Comp5471A26)
fit26i<-fitted(Comp5471A26)
plot(fit26i,res26i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif5471 + PropWater5471 + PropDev5471 + PropBare5471", pch=16)
Comp5471A27<-glm(Rand_MVC~PropConif5471 + PropWater5471 + PropGrass5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A27)
res27i<-resid(Comp5471A27)
fit27i<-fitted(Comp5471A27)
plot(fit27i,res27i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif5471 + PropWater5471 + PropGrass5471 + PropShrub5471", pch=16)
Comp5471A28<-glm(Rand_MVC~PropConif5471 + PropWater5471 + PropGrass5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A28)
res28i<-resid(Comp5471A28)
fit28i<-fitted(Comp5471A28)
plot(fit28i,res28i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif5471 + PropWater5471 + PropGrass5471 + PropBare5471", pch=16)
Comp5471A29<-glm(Rand_MVC~PropConif5471 + PropWater5471 + PropShrub5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A29)
res29i<-resid(Comp5471A29)
fit29i<-fitted(Comp5471A29)
plot(fit29i,res29i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif5471 + PropWater5471 + PropShrub5471 + PropBare5471", pch=16)
Comp5471A30<-glm(Rand_MVC~PropConif5471 + PropDev5471 + PropGrass5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A30)
res30i<-resid(Comp5471A30)
fit30i<-fitted(Comp5471A30)
plot(fit30i,res30i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif5471 + PropDev5471 + PropGrass5471 + PropShrub5471", pch=16)
Comp5471A31<-glm(Rand_MVC~PropConif5471 + PropDev5471 + PropGrass5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A31)
res31i<-resid(Comp5471A31)
fit31i<-fitted(Comp5471A31)
plot(fit31i,res32i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif5471 + PropDev5471 + PropGrass5471 + PropBare5471", pch=16)
Comp5471A32<-glm(Rand_MVC~PropConif5471 + PropDev5471 + PropShrub5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A32)
res32i<-resid(Comp5471A32)
fit32i<-fitted(Comp5471A32)
plot(fit32i,res32i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif5471 + PropDev5471 + PropShrub5471 + PropBare5471", pch=16)
Comp5471A33<-glm(Rand_MVC~PropConif5471 + PropGrass5471 + PropShrub5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A33)
res33i<-resid(Comp5471A33)
fit33i<-fitted(Comp5471A33)
plot(fit33i,res34i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif5471 + PropGrass5471 + PropShrub5471 + PropBare5471", pch=16)
Comp5471A34<-glm(Rand_MVC~PropWater5471 + PropDev5471 + PropGrass5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A34)
res34i<-resid(Comp5471A34)
fit34i<-fitted(Comp5471A34)
plot(fit34i,res34i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater5471 + PropDev5471 + PropGrass5471 + PropShrub5471", pch=16)
Comp5471A35<-glm(Rand_MVC~PropWater5471 + PropDev5471 + PropGrass5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A35)
res35i<-resid(Comp5471A35)
fit35i<-fitted(Comp5471A35)
plot(fit35i,res35i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater5471 + PropDev5471 + PropGrass5471 + PropBare5471", pch=16)
Comp5471A36<-glm(Rand_MVC~PropWater5471 + PropDev5471 + PropShrub5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A36)
res36i<-resid(Comp5471A36)
fit36i<-fitted(Comp5471A36)
plot(fit36i,res36i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater5471 + PropDev5471 + PropShrub5471 + PropBare5471", pch=16)
Comp5471A37<-glm(Rand_MVC~PropWater5471 + PropGrass5471 + PropShrub5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A37)
res37i<-resid(Comp5471A37)
fit37i<-fitted(Comp5471A37)
plot(fit37i,res37i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater5471 + PropGrass5471 + PropShrub5471 + PropBare5471", pch=16)
Comp5471A38<-glm(Rand_MVC~PropDev5471 + PropGrass5471 + PropShrub5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A38)
res38i<-resid(Comp5471A38)
fit38i<-fitted(Comp5471A38)
plot(fit38i,res38i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDev5471 + PropGrass5471 + PropShrub5471 + PropBare5471", pch=16)
Comp5471A39<-glm(Rand_MVC~PropDecid5471 + PropConif5471 + PropWater5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A39)
res39i<-resid(Comp5471A39)
fit39i<-fitted(Comp5471A39)
plot(fit39i,res39i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid5471 + PropConif5471 + PropWater5471", pch=16)
Comp5471A40<-glm(Rand_MVC~PropDecid5471 + PropConif5471 + PropDev5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A40)
res40i<-resid(Comp5471A40)
fit40i<-fitted(Comp5471A40)
plot(fit40i,res40i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid5471 + PropConif5471 + PropDev5471", pch=16)
Comp5471A41<-glm(Rand_MVC~PropDecid5471 + PropConif5471 + PropGrass5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A41)
res41i<-resid(Comp5471A41)
fit41i<-fitted(Comp5471A41)
plot(fit41i,res41i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid5471 + PropConif5471 + PropGrass5471", pch=16)
Comp5471A42<-glm(Rand_MVC~PropDecid5471 + PropConif5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A42)
res42i<-resid(Comp5471A42)
fit42i<-fitted(Comp5471A42)
plot(fit42i,res42i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid5471 + PropConif5471 + PropShrub5471", pch=16)
Comp5471A43<-glm(Rand_MVC~PropDecid5471 + PropWater5471 + PropDev5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A43)
res43i<-resid(Comp5471A43)
fit43i<-fitted(Comp5471A43)
plot(fit43i,res43i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid5471 + PropWater5471 + PropDev5471", pch=16)
Comp5471A44<-glm(Rand_MVC~PropDecid5471 + PropWater5471 + PropGrass5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A44)
res44i<-resid(Comp5471A44)
fit44i<-fitted(Comp5471A44)
plot(fit44i,res44i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid5471 + PropWater5471 + PropGrass5471", pch=16)
Comp5471A45<-glm(Rand_MVC~PropDecid5471 + PropWater5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A45)
res45i<-resid(Comp5471A45)
fit45i<-fitted(Comp5471A45)
plot(fit45i,res45i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid5471 + PropWater5471 + PropShrub5471", pch=16)
Comp5471A46<-glm(Rand_MVC~PropDecid5471 + PropDev5471 + PropGrass5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A46)
res46i<-resid(Comp5471A46)
fit46i<-fitted(Comp5471A46)
plot(fit46i,res46i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid5471 + PropDev5471 + PropGrass5471", pch=16)
Comp5471A47<-glm(Rand_MVC~PropDecid5471 + PropDev5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A47)
res47i<-resid(Comp5471A47)
fit47i<-fitted(Comp5471A47)
plot(fit47i,res47i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid5471 + PropDev5471 + PropShrub5471", pch=16)
Comp5471A48<-glm(Rand_MVC~PropDecid5471 + PropGrass5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A48)
res48i<-resid(Comp5471A48)
fit48i<-fitted(Comp5471A48)
plot(fit48i,res48i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid5471 + PropGrass5471 + PropShrub5471", pch=16)
Comp5471A49<-glm(Rand_MVC~PropConif5471 + PropWater5471 + PropDev5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A49)
res49i<-resid(Comp5471A49)
fit49i<-fitted(Comp5471A49)
plot(fit49i,res49i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif5471 + PropWater5471 + PropDev5471", pch=16)
Comp5471A50<-glm(Rand_MVC~PropConif5471 + PropWater5471 + PropGrass5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A50)
res50i<-resid(Comp5471A50)
fit50i<-fitted(Comp5471A50)
plot(fit50i,res50i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif5471 + PropWater5471 + PropGrass5471", pch=16)
Comp5471A51<-glm(Rand_MVC~PropConif5471 + PropWater5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A51)
res51i<-resid(Comp5471A51)
fit51i<-fitted(Comp5471A51)
plot(fit51i,res51i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif5471 + PropWater5471 + PropShrub5471", pch=16)
Comp5471A52<-glm(Rand_MVC~PropConif5471 + PropWater5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A52)
res52i<-resid(Comp5471A52)
fit52i<-fitted(Comp5471A52)
plot(fit52i,res52i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif5471 + PropWater5471 + PropBare5471", pch=16)
Comp5471A53<-glm(Rand_MVC~PropConif5471 + PropDev5471 + PropGrass5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A53)
res53i<-resid(Comp5471A53)
fit53i<-fitted(Comp5471A53)
plot(fit53i,res53i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif5471 + PropDev5471 + PropGrass5471", pch=16)
Comp5471A54<-glm(Rand_MVC~PropConif5471 + PropDev5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A54)
res54i<-resid(Comp5471A54)
fit54i<-fitted(Comp5471A54)
plot(fit54i,res54i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif5471 + PropDev5471 + PropShrub5471", pch=16)
Comp5471A55<-glm(Rand_MVC~PropConif5471 + PropDev5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A55)
res55i<-resid(Comp5471A55)
fit55i<-fitted(Comp5471A55)
plot(fit55i,res55i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif5471 + PropDev5471 + PropBare5471", pch=16)
Comp5471A56<-glm(Rand_MVC~PropConif5471 + PropGrass5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A56)
res56i<-resid(Comp5471A56)
fit56i<-fitted(Comp5471A56)
plot(fit56i,res56i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif5471 + PropGrass5471 + PropShrub5471", pch=16)
Comp5471A57<-glm(Rand_MVC~PropConif5471 + PropGrass5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A57)
res57i<-resid(Comp5471A57)
fit57i<-fitted(Comp5471A57)
plot(fit57i,res57i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif5471 + PropGrass5471 + PropBare5471", pch=16)
Comp5471A58<-glm(Rand_MVC~PropConif5471 + PropShrub5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A58)
res58i<-resid(Comp5471A58)
fit58i<-fitted(Comp5471A58)
plot(fit58i,res58i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif5471 + PropShrub5471 + PropBare5471", pch=16)
Comp5471A59<-glm(Rand_MVC~PropWater5471 + PropDev5471 + PropGrass5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A59)
res59i<-resid(Comp5471A59)
fit59i<-fitted(Comp5471A59)
plot(fit59i,res59i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater5471 + PropDev5471 + PropGrass5471", pch=16)
Comp5471A60<-glm(Rand_MVC~PropWater5471 + PropDev5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A60)
res60i<-resid(Comp5471A60)
fit60i<-fitted(Comp5471A60)
plot(fit60i,res60i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater5471 + PropDev5471 + PropShrub5471", pch=16)
Comp5471A61<-glm(Rand_MVC~PropWater5471 + PropDev5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A61)
res61i<-resid(Comp5471A61)
fit61i<-fitted(Comp5471A61)
plot(fit61i,res61i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater5471 + PropDev5471 + PropBare5471", pch=16)
Comp5471A62<-glm(Rand_MVC~PropWater5471 + PropGrass5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A62)
res62i<-resid(Comp5471A62)
fit62i<-fitted(Comp5471A62)
plot(fit62i,res62i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater5471 + PropGrass5471 + PropShrub5471", pch=16)
Comp5471A63<-glm(Rand_MVC~PropWater5471 + PropGrass5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A63)
res63i<-resid(Comp5471A63)
fit63i<-fitted(Comp5471A63)
plot(fit63i,res63i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater5471 + PropGrass5471 + PropBare5471", pch=16)
Comp5471A64<-glm(Rand_MVC~PropWater5471 + PropShrub5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A64)
res64i<-resid(Comp5471A64)
fit64i<-fitted(Comp5471A64)
plot(fit64i,res64i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater5471 + PropShrub5471 + PropBare5471", pch=16)
Comp5471A65<-glm(Rand_MVC~PropDev5471 + PropGrass5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A65)
res65i<-resid(Comp5471A65)
fit65i<-fitted(Comp5471A65)
plot(fit65i,res65i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDev5471 + PropGrass5471 + PropShrub5471", pch=16)
Comp5471A66<-glm(Rand_MVC~PropDev5471 + PropGrass5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A66)
res66i<-resid(Comp5471A66)
fit66i<-fitted(Comp5471A66)
plot(fit66i,res66i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDev5471 + PropGrass5471 + PropBare5471", pch=16)
Comp5471A67<-glm(Rand_MVC~PropDev5471 + PropShrub5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A67)
res67i<-resid(Comp5471A67)
fit67i<-fitted(Comp5471A67)
plot(fit67i,res67i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDev5471 + PropShrub5471 + PropBare5471", pch=16)
Comp5471A68<-glm(Rand_MVC~PropGrass5471 + PropShrub5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A68)
res68i<-resid(Comp5471A68)
fit68i<-fitted(Comp5471A68)
plot(fit68i,res68i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropGrass5471 + PropShrub5471 + PropBare5471", pch=16)
Comp5471A69<-glm(Rand_MVC~PropDecid5471 + PropConif5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A69)
res69i<-resid(Comp5471A69)
fit69i<-fitted(Comp5471A69)
plot(fit69i,res69i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid5471 + PropConif5471", pch=16)
Comp5471A70<-glm(Rand_MVC~PropDecid5471 + PropWater5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A70)
res70i<-resid(Comp5471A70)
fit70i<-fitted(Comp5471A70)
plot(fit70i,res70i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid5471 + PropWater5471", pch=16)
Comp5471A71<-glm(Rand_MVC~PropDecid5471 + PropDev5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A71)
res71i<-resid(Comp5471A71)
fit71i<-fitted(Comp5471A71)
plot(fit71i,res71i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid5471 + PropDev5471", pch=16)
Comp5471A72<-glm(Rand_MVC~PropDecid5471 + PropGrass5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A72)
res72i<-resid(Comp5471A72)
fit72i<-fitted(Comp5471A72)
plot(fit72i,res72i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid5471 + PropGrass5471", pch=16)
Comp5471A73<-glm(Rand_MVC~PropDecid5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A73)
res73i<-resid(Comp5471A73)
fit73i<-fitted(Comp5471A73)
plot(fit73i,res73i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid5471 + PropShrub5471", pch=16)
Comp5471A74<-glm(Rand_MVC~PropConif5471 + PropWater5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A74)
res74i<-resid(Comp5471A74)
fit74i<-fitted(Comp5471A74)
plot(fit74i,res74i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif5471 + PropWater5471", pch=16)
Comp5471A75<-glm(Rand_MVC~PropConif5471 + PropDev5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A75)
res75i<-resid(Comp5471A75)
fit75i<-fitted(Comp5471A75)
plot(fit75i,res75i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif5471 + PropDev5471", pch=16)
Comp5471A76<-glm(Rand_MVC~PropConif5471 + PropGrass5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A76)
res76i<-resid(Comp5471A76)
fit76i<-fitted(Comp5471A76)
plot(fit76i,res76i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif5471 + PropGrass5471", pch=16)
Comp5471A77<-glm(Rand_MVC~PropConif5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A77)
res77i<-resid(Comp5471A77)
fit77i<-fitted(Comp5471A77)
plot(fit77i,res77i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif5471 + PropShrub5471", pch=16)
Comp5471A78<-glm(Rand_MVC~PropConif5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A78)
res78i<-resid(Comp5471A78)
fit78i<-fitted(Comp5471A78)
plot(fit78i,res78i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif5471 + PropBare5471", pch=16)
Comp5471A79<-glm(Rand_MVC~PropWater5471 + PropDev5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A79)
res79i<-resid(Comp5471A79)
fit79i<-fitted(Comp5471A79)
plot(fit79i,res79i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater5471 + PropDev5471", pch=16)
Comp5471A80<-glm(Rand_MVC~PropWater5471 + PropGrass5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A80)
res80i<-resid(Comp5471A80)
fit80i<-fitted(Comp5471A80)
plot(fit80i,res80i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater5471 + PropGrass5471", pch=16)
Comp5471A81<-glm(Rand_MVC~PropWater5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A81)
res81i<-resid(Comp5471A81)
fit81i<-fitted(Comp5471A81)
plot(fit81i,res81i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater5471 + PropShrub5471", pch=16)
Comp5471A82<-glm(Rand_MVC~PropWater5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A82)
res82i<-resid(Comp5471A82)
fit82i<-fitted(Comp5471A82)
plot(fit82i,res82i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater5471 + PropBare5471", pch=16)
Comp5471A83<-glm(Rand_MVC~PropDev5471 + PropGrass5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A83)
res83i<-resid(Comp5471A83)
fit83i<-fitted(Comp5471A83)
plot(fit83i,res83i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDev5471 + PropGrass5471", pch=16)
Comp5471A84<-glm(Rand_MVC~PropDev5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A84)
res84i<-resid(Comp5471A84)
fit84i<-fitted(Comp5471A84)
plot(fit84i,res84i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDev5471 + PropShrub5471", pch=16)
Comp5471A85<-glm(Rand_MVC~PropDev5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A85)
res85i<-resid(Comp5471A85)
fit85i<-fitted(Comp5471A85)
plot(fit85i,res85i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDev5471 + PropBare5471", pch=16)
Comp5471A86<-glm(Rand_MVC~PropGrass5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A86)
res86i<-resid(Comp5471A86)
fit86i<-fitted(Comp5471A86)
plot(fit86i,res86i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropGrass5471 + PropShrub5471", pch=16)
Comp5471A87<-glm(Rand_MVC~PropGrass5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A87)
res87i<-resid(Comp5471A87)
fit87i<-fitted(Comp5471A87)
plot(fit87i,res87i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropGrass5471 + PropBare5471", pch=16)
Comp5471A88<-glm(Rand_MVC~PropShrub5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A88)
res88i<-resid(Comp5471A88)
fit88i<-fitted(Comp5471A88)
plot(fit88i,res88i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropShrub5471 + PropBare5471", pch=16)
Comp5471A89<-glm(Rand_MVC~PropDecid5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A89)
res89i<-resid(Comp5471A89)
fit89i<-fitted(Comp5471A89)
plot(fit89i,res89i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid5471", pch=16)
Comp5471A90<-glm(Rand_MVC~PropConif5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A90)
res90i<-resid(Comp5471A90)
fit90i<-fitted(Comp5471A90)
plot(fit90i,res90i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif5471", pch=16)
Comp5471A91<-glm(Rand_MVC~PropWater5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A91)
res91i<-resid(Comp5471A91)
fit91i<-fitted(Comp5471A91)
plot(fit91i,res91i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater5471", pch=16)
Comp5471A92<-glm(Rand_MVC~PropDev5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A92)
res92i<-resid(Comp5471A92)
fit92i<-fitted(Comp5471A92)
plot(fit92i,res92i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDev5471", pch=16)
Comp5471A93<-glm(Rand_MVC~PropGrass5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A93)
res93i<-resid(Comp5471A93)
fit93i<-fitted(Comp5471A93)
plot(fit93i,res93i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropGrass5471", pch=16)
Comp5471A94<-glm(Rand_MVC~PropShrub5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A94)
res94i<-resid(Comp5471A94)
fit94i<-fitted(Comp5471A94)
plot(fit94i,res94i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropShrub5471", pch=16)
Comp5471A95<-glm(Rand_MVC~PropBare5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A95)
res95i<-resid(Comp5471A95)
fit95i<-fitted(Comp5471A95)
plot(fit95i,res95i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropBare5471", pch=16)

library(AICcmodavg)
Cand.models <- list( )
Cand.models[[1]]<-glm(Rand_MVC~PropDecid5471 + PropConif5471 + PropWater5471 + PropDev5471 + PropGrass5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[2]]<-glm(Rand_MVC~PropConif5471 + PropWater5471 + PropDev5471 + PropGrass5471 + PropShrub5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[3]]<-glm(Rand_MVC~PropDecid5471 + PropConif5471 + PropWater5471 + PropDev5471 + PropGrass5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[4]]<-glm(Rand_MVC~PropDecid5471 + PropConif5471 + PropWater5471 + PropDev5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[5]]<-glm(Rand_MVC~PropDecid5471 + PropConif5471 + PropWater5471 + PropGrass5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[6]]<-glm(Rand_MVC~PropDecid5471 + PropConif5471 + PropDev5471 + PropGrass5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[7]]<-glm(Rand_MVC~PropDecid5471 + PropWater5471 + PropDev5471 + PropGrass5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[8]]<-glm(Rand_MVC~PropConif5471 + PropWater5471 + PropDev5471 + PropGrass5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[9]]<-glm(Rand_MVC~PropConif5471 + PropWater5471 + PropDev5471 + PropGrass5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[10]]<-glm(Rand_MVC~PropConif5471 + PropWater5471 + PropDev5471 + PropShrub5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[11]]<-glm(Rand_MVC~PropConif5471 + PropWater5471 + PropGrass5471 + PropShrub5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[12]]<-glm(Rand_MVC~PropConif5471 + PropDev5471 + PropGrass5471 + PropShrub5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[13]]<-glm(Rand_MVC~PropWater5471 + PropDev5471 + PropGrass5471 + PropShrub5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[14]]<-glm(Rand_MVC~PropDecid5471 + PropConif5471 + PropWater5471 + PropDev5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[15]]<-glm(Rand_MVC~PropDecid5471 + PropConif5471 + PropWater5471 + PropGrass5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[16]]<-glm(Rand_MVC~PropDecid5471 + PropConif5471 + PropWater5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[17]]<-glm(Rand_MVC~PropDecid5471 + PropConif5471 + PropDev5471 + PropGrass5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[18]]<-glm(Rand_MVC~PropDecid5471 + PropConif5471 + PropDev5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[19]]<-glm(Rand_MVC~PropDecid5471 + PropConif5471 + PropGrass5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[20]]<-glm(Rand_MVC~PropDecid5471 + PropWater5471 + PropDev5471 + PropGrass5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[21]]<-glm(Rand_MVC~PropDecid5471 + PropWater5471 + PropDev5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[22]]<-glm(Rand_MVC~PropDecid5471 + PropWater5471 + PropGrass5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[23]]<-glm(Rand_MVC~PropDecid5471 + PropDev5471 + PropGrass5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[24]]<-glm(Rand_MVC~PropConif5471 + PropWater5471 + PropDev5471 + PropGrass5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[25]]<-glm(Rand_MVC~PropConif5471 + PropWater5471 + PropDev5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[26]]<-glm(Rand_MVC~PropConif5471 + PropWater5471 + PropDev5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[27]]<-glm(Rand_MVC~PropConif5471 + PropWater5471 + PropGrass5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[28]]<-glm(Rand_MVC~PropConif5471 + PropWater5471 + PropGrass5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[29]]<-glm(Rand_MVC~PropConif5471 + PropWater5471 + PropShrub5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[30]]<-glm(Rand_MVC~PropConif5471 + PropDev5471 + PropGrass5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[31]]<-glm(Rand_MVC~PropConif5471 + PropDev5471 + PropGrass5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[32]]<-glm(Rand_MVC~PropConif5471 + PropDev5471 + PropShrub5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[33]]<-glm(Rand_MVC~PropConif5471 + PropGrass5471 + PropShrub5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[34]]<-glm(Rand_MVC~PropWater5471 + PropDev5471 + PropGrass5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[35]]<-glm(Rand_MVC~PropWater5471 + PropDev5471 + PropGrass5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[36]]<-glm(Rand_MVC~PropWater5471 + PropDev5471 + PropShrub5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[37]]<-glm(Rand_MVC~PropWater5471 + PropGrass5471 + PropShrub5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[38]]<-glm(Rand_MVC~PropDev5471 + PropGrass5471 + PropShrub5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[39]]<-glm(Rand_MVC~PropDecid5471 + PropConif5471 + PropWater5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[40]]<-glm(Rand_MVC~PropDecid5471 + PropConif5471 + PropDev5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[41]]<-glm(Rand_MVC~PropDecid5471 + PropConif5471 + PropGrass5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[42]]<-glm(Rand_MVC~PropDecid5471 + PropConif5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[43]]<-glm(Rand_MVC~PropDecid5471 + PropWater5471 + PropDev5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[44]]<-glm(Rand_MVC~PropDecid5471 + PropWater5471 + PropGrass5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[45]]<-glm(Rand_MVC~PropDecid5471 + PropWater5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[46]]<-glm(Rand_MVC~PropDecid5471 + PropDev5471 + PropGrass5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[47]]<-glm(Rand_MVC~PropDecid5471 + PropDev5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[48]]<-glm(Rand_MVC~PropDecid5471 + PropGrass5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[49]]<-glm(Rand_MVC~PropConif5471 + PropWater5471 + PropDev5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[50]]<-glm(Rand_MVC~PropConif5471 + PropWater5471 + PropGrass5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[51]]<-glm(Rand_MVC~PropConif5471 + PropWater5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[52]]<-glm(Rand_MVC~PropConif5471 + PropWater5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[53]]<-glm(Rand_MVC~PropConif5471 + PropDev5471 + PropGrass5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[54]]<-glm(Rand_MVC~PropConif5471 + PropDev5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[55]]<-glm(Rand_MVC~PropConif5471 + PropDev5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[56]]<-glm(Rand_MVC~PropConif5471 + PropGrass5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[57]]<-glm(Rand_MVC~PropConif5471 + PropGrass5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[58]]<-glm(Rand_MVC~PropConif5471 + PropShrub5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[59]]<-glm(Rand_MVC~PropWater5471 + PropDev5471 + PropGrass5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[60]]<-glm(Rand_MVC~PropWater5471 + PropDev5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[61]]<-glm(Rand_MVC~PropWater5471 + PropDev5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[62]]<-glm(Rand_MVC~PropWater5471 + PropGrass5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[63]]<-glm(Rand_MVC~PropWater5471 + PropGrass5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[64]]<-glm(Rand_MVC~PropWater5471 + PropShrub5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[65]]<-glm(Rand_MVC~PropDev5471 + PropGrass5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[66]]<-glm(Rand_MVC~PropDev5471 + PropGrass5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[67]]<-glm(Rand_MVC~PropDev5471 + PropShrub5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[68]]<-glm(Rand_MVC~PropGrass5471 + PropShrub5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[69]]<-glm(Rand_MVC~PropDecid5471 + PropConif5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[70]]<-glm(Rand_MVC~PropDecid5471 + PropWater5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[71]]<-glm(Rand_MVC~PropDecid5471 + PropDev5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[72]]<-glm(Rand_MVC~PropDecid5471 + PropGrass5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[73]]<-glm(Rand_MVC~PropDecid5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[74]]<-glm(Rand_MVC~PropConif5471 + PropWater5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[75]]<-glm(Rand_MVC~PropConif5471 + PropDev5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[76]]<-glm(Rand_MVC~PropConif5471 + PropGrass5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[77]]<-glm(Rand_MVC~PropConif5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[78]]<-glm(Rand_MVC~PropConif5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[79]]<-glm(Rand_MVC~PropWater5471 + PropDev5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[80]]<-glm(Rand_MVC~PropWater5471 + PropGrass5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[81]]<-glm(Rand_MVC~PropWater5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[82]]<-glm(Rand_MVC~PropWater5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[83]]<-glm(Rand_MVC~PropDev5471 + PropGrass5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[84]]<-glm(Rand_MVC~PropDev5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[85]]<-glm(Rand_MVC~PropDev5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[86]]<-glm(Rand_MVC~PropGrass5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[87]]<-glm(Rand_MVC~PropGrass5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[88]]<-glm(Rand_MVC~PropShrub5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[89]]<-glm(Rand_MVC~PropDecid5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[90]]<-glm(Rand_MVC~PropConif5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[91]]<-glm(Rand_MVC~PropWater5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[92]]<-glm(Rand_MVC~PropDev5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[93]]<-glm(Rand_MVC~PropGrass5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[94]]<-glm(Rand_MVC~PropShrub5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[95]]<-glm(Rand_MVC~PropBare5471, family=binomial(link="logit"), data=spatialall)

##create a vector of names to trace back models in set
Modnames <- c("Comp5471A1", "Comp5471A2", "Comp5471A3", "Comp5471A4","Comp5471A5", "Comp5471A6", "Comp5471A7", "Comp5471A8", "Comp5471A9", "Comp5471A10", "Comp5471A11", "Comp5471A12", 
              "Comp5471A13", "Comp5471A14", "Comp5471A15", "Comp5471A16", "Comp5471A17","Comp5471A18", "Comp5471A19", "Comp5471A20", "Comp5471A21", "Comp5471A22", "Comp5471A23", 
              "Comp5471A24", "Comp5471A25", "Comp5471A26", "Comp5471A27", "Comp5471A28", "Comp5471A29", "Comp5471A30", "Comp5471A31", "Comp5471A32", "Comp5471A33", "Comp5471A34", 
              "Comp5471A35", "Comp5471A36", "Comp5471A37", "Comp5471A38", "Comp5471A39", "Comp5471A40", "Comp5471A41", "Comp5471A42", "Comp5471A43", "Comp5471A44", "Comp5471A45", 
              "Comp5471A46", "Comp5471A47", "Comp5471A48", "Comp5471A49","Comp5471A50", "Comp5471A51", "Comp5471A52", "Comp5471A53", "Comp5471A54", "Comp5471A55", "Comp5471A56", 
              "Comp5471A57", "Comp5471A58", "Comp5471A59", "Comp5471A60", "Comp5471A61", "Comp5471A62", "Comp5471A63", "Comp5471A64", "Comp5471A65", "Comp5471A66", "Comp5471A67", 
              "Comp5471A68", "Comp5471A69", "Comp5471A70", "Comp5471A71", "Comp5471A72", "Comp5471A73", "Comp5471A74", "Comp5471A75", "Comp5471A76", "Comp5471A77", "Comp5471A78",
              "Comp5471A79", "Comp5471A80", "Comp5471A81", "Comp5471A82", "Comp5471A83", "Comp5471A84", "Comp5471A85", "Comp5471A86", "Comp5471A87", "Comp5471A88", "Comp5471A89", 
              "Comp5471A90", "Comp5471A91", "Comp5471A92", "Comp5471A93", "Comp5471A94", "Comp5471A95")

##generate AICc table
aictab(cand.set = Cand.models, modnames = Modnames, sort = TRUE)
##round to 4 digits after decimal point and give log-likelihood
print(aictab(cand.set = Cand.models, modnames = Modnames, sort = TRUE),
      digits = 4, LL = TRUE)

Modnames <- data.frame(Names=c("Comp5471A1", "Comp5471A2", "Comp5471A3", "Comp5471A4","Comp5471A5", "Comp5471A6", "Comp5471A7", "Comp5471A8", "Comp5471A9", "Comp5471A10", "Comp5471A11", "Comp5471A12", 
                               "Comp5471A13", "Comp5471A14", "Comp5471A15", "Comp5471A16", "Comp5471A17","Comp5471A18", "Comp5471A19", "Comp5471A20", "Comp5471A21", "Comp5471A22", "Comp5471A23", 
                               "Comp5471A24", "Comp5471A25", "Comp5471A26", "Comp5471A27", "Comp5471A28", "Comp5471A29", "Comp5471A30", "Comp5471A31", "Comp5471A32", "Comp5471A33", "Comp5471A34", 
                               "Comp5471A35", "Comp5471A36", "Comp5471A37", "Comp5471A38", "Comp5471A39", "Comp5471A40", "Comp5471A41", "Comp5471A42", "Comp5471A43", "Comp5471A44", "Comp5471A45", 
                               "Comp5471A46", "Comp5471A47", "Comp5471A48", "Comp5471A49","Comp5471A50", "Comp5471A51", "Comp5471A52", "Comp5471A53", "Comp5471A54", "Comp5471A55", "Comp5471A56", 
                               "Comp5471A57", "Comp5471A58", "Comp5471A59", "Comp5471A60", "Comp5471A61", "Comp5471A62", "Comp5471A63", "Comp5471A64", "Comp5471A65", "Comp5471A66", "Comp5471A67", 
                               "Comp5471A68", "Comp5471A69", "Comp5471A70", "Comp5471A71", "Comp5471A72", "Comp5471A73", "Comp5471A74", "Comp5471A75", "Comp5471A76", "Comp5471A77", "Comp5471A78",
                               "Comp5471A79", "Comp5471A80", "Comp5471A81", "Comp5471A82", "Comp5471A83", "Comp5471A84", "Comp5471A85", "Comp5471A86", "Comp5471A87", "Comp5471A88", "Comp5471A89", 
                               "Comp5471A90", "Comp5471A91", "Comp5471A92", "Comp5471A93", "Comp5471A94", "Comp5471A95"))

##for each model in Modnames run function NagelkerkeR2
library(fmsb)
Nag <- NULL
Nag <- rbind(Nag, data.frame(Nag=sapply(1:nrow(Modnames), function(i) {NagelkerkeR2(Cand.models[[i]])})))
Nag

##for each model in Modnames run deviance explained (null-resid)/null
library(fmsb)
Dev <- NULL
Dev <- rbind(Dev, data.frame(Dev=sapply(1:nrow(Modnames), function(i) {((Cand.models[[i]]$null.deviance-Cand.models[[i]]$deviance)/Cand.models[[i]]$null.deviance)})))
Dev

####################################################################################################################################################

## Reduced model set
## Dataset is the data after the correlated variables and pretending varaibles were removed: pretending variable if the delta AIC value is ~ 2, 
## when adding the variable the deviance doesn't change, parameter estimates ~0 with large confidence intervals. 
## For more information: https://theartofmodelling.wordpress.com/2012/04/01/getting-the-most-information-from-your-models-6-keys-to-model-selection/
## All summary tables within the manuscript only contain the models within each group with a delta AIC value of <2, while the code contains all models within each group

## Running all of the models within each group to determine which models have delta AICc values of less than 2 within their group, 
## these models will then be used in an all encompassing analysis
## Models are: glm with a binomial error stucture and logit link

## Travel Corridor Based Models (Distance)
TravelDist1<-glm(Rand_MVC~DisFAR_m+ DisRW_m+ DisTR_m, family=binomial(link="logit"), data=spatialall)
summary(TravelDist1)
res1<-resid(TravelDist1)
fit1<-fitted(TravelDist1)
plot(fit1,res1,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n FAR & RW & TR", pch=16)
TravelDist2<-glm(Rand_MVC~DisFAR_m+ DisTL_m + DisTR_m, family=binomial(link="logit"), data=spatialall)
summary(TravelDist2)
res2<-resid(TravelDist2)
fit2<-fitted(TravelDist2)
plot(fit2,res2,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n FAR & TL & TR", pch=16)
TravelDist3<-glm(Rand_MVC~DisFAR_m + DisRW_m, family=binomial(link="logit"), data=spatialall)
summary(TravelDist3)
res3<-resid(TravelDist3)
fit3<-fitted(TravelDist3)
plot(fit3,res3,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n FAR & RW", pch=16)
TravelDist6<-glm(Rand_MVC~DisRW_m + DisTR_m, family=binomial(link="logit"), data=spatialall)
summary(TravelDist6)
res6<-resid(TravelDist6)
fit6<-fitted(TravelDist6)
plot(fit6,res6,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RW & TR", pch=16)
TravelDist7<-glm(Rand_MVC~DisTL_m + DisTR_m, family=binomial(link="logit"), data=spatialall)
summary(TravelDist7)
res7<-resid(TravelDist7)
fit7<-fitted(TravelDist7)
plot(fit7,res7,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n TL & TR", pch=16)
TravelDist8<-glm(Rand_MVC~DisFAR_m, family=binomial(link="logit"), data=spatialall)
summary(TravelDist8)
res8<-resid(TravelDist8)
fit8<-fitted(TravelDist8)
plot(fit8,res8,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n FAR", pch=16)
TravelDist9<-glm(Rand_MVC~DisRW_m, family=binomial(link="logit"), data=spatialall)
summary(TravelDist9)
res9<-resid(TravelDist9)
fit9<-fitted(TravelDist9)
plot(fit9,res9,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RW", pch=16)
TravelDist10<-glm(Rand_MVC~DisTL_m, family=binomial(link="logit"), data=spatialall)
summary(TravelDist10)
res10<-resid(TravelDist10)
fit10<-fitted(TravelDist10)
plot(fit10,res10,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n TL", pch=16)
TravelDist11<-glm(Rand_MVC~DisTR_m, family=binomial(link="logit"), data=spatialall)
summary(TravelDist11)
res11<-resid(TravelDist11)
fit11<-fitted(TravelDist11)
plot(fit11,res11,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n TR", pch=16)

## Used to create Table S10
library(AICcmodavg)
Cand.models <- list( )
Cand.models[[1]] <- glm(Rand_MVC~DisFAR_m+ DisRW_m+ DisTR_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[2]] <- glm(Rand_MVC~DisFAR_m+ DisTL_m + DisTR_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[3]] <- glm(Rand_MVC~DisFAR_m + DisRW_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[4]] <- glm(Rand_MVC~DisRW_m + DisTR_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[5]] <- glm(Rand_MVC~DisTL_m + DisTR_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[6]] <- glm(Rand_MVC~DisFAR_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[7]] <- glm(Rand_MVC~DisRW_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[8]] <- glm(Rand_MVC~DisTL_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[9]] <- glm(Rand_MVC~DisTR_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[10]] <- glm(Rand_MVC~1, family=binomial(link="logit"), data=spatialall)

##create a vector of names to trace back models in set
Modnames <- c("TravelDist1", "TravelDist2", "TravelDist3", "TravelDist6", "TravelDist7", "TravelDist8", 
              "TravelDist9", "TravelDist10", "TravelDist11", "Null")

##generate AICc table
aictab(cand.set = Cand.models, modnames = Modnames, sort = TRUE)
##round to 4 digits after decimal point and give log-likelihood
print(aictab(cand.set = Cand.models, modnames = Modnames, sort = TRUE),
      digits = 4, LL = TRUE)

Modnames <- data.frame(Names=c("TravelDist1", "TravelDist2", "TravelDist3", "TravelDist6", "TravelDist7", "TravelDist8", 
                               "TravelDist9", "TravelDist10", "TravelDist11", "Null"))

##for each model in Modnames run function NagelkerkeR2
library(fmsb)
Nag <- NULL
Nag <- rbind(Nag, data.frame(Nag=sapply(1:nrow(Modnames), function(i) {NagelkerkeR2(Cand.models[[i]])})))
Nag

##for each model in Modnames run deviance explained (null-resid)/null
library(fmsb)
Dev <- NULL
Dev <- rbind(Dev, data.frame(Dev=sapply(1:nrow(Modnames), function(i) {((Cand.models[[i]]$null.deviance-Cand.models[[i]]$deviance)/Cand.models[[i]]$null.deviance)})))
Dev

## Water Feature Based Models 
WaterFeat1<-glm(Rand_MVC~DisRiv_m + DisWet_m + DisOcn_m + DisLak_m, family=binomial(link="logit"), data=spatialall)
summary(WaterFeat1)
res1a<-resid(WaterFeat1)
fit1a<-fitted(WaterFeat1)
plot(fit1a,res1a,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DisRiv & DisWet & DisOcn & DisLak", pch=16)
WaterFeat2<-glm(Rand_MVC~DisRiv_m + DisWet_m + DisOcn_m, family=binomial(link="logit"), data=spatialall)
summary(WaterFeat2)
res2a<-resid(WaterFeat2)
fit2a<-fitted(WaterFeat2)
plot(fit2a,res2a,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DisRiv & DisWet & DisOcn", pch=16)
WaterFeat3<-glm(Rand_MVC~DisRiv_m + DisWet_m + DisLak_m, family=binomial(link="logit"), data=spatialall)
summary(WaterFeat3)
res3a<-resid(WaterFeat3)
fit3a<-fitted(WaterFeat3)
plot(fit3a,res3a,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DisRiv & DisWet & DisLak", pch=16)
WaterFeat4<-glm(Rand_MVC~DisRiv_m + DisOcn_m + DisLak_m, family=binomial(link="logit"), data=spatialall)
summary(WaterFeat4)
res4a<-resid(WaterFeat4)
fit4a<-fitted(WaterFeat4)
plot(fit4a,res4a,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DisRiv & DisOcn & DisLak", pch=16)
WaterFeat5<-glm(Rand_MVC~DisWet_m + DisOcn_m + DisLak_m, family=binomial(link="logit"), data=spatialall)
summary(WaterFeat5)
res5a<-resid(WaterFeat5)
fit5a<-fitted(WaterFeat5)
plot(fit5a,res5a,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DisWet & DisOcn & DisLak", pch=16)
WaterFeat6<-glm(Rand_MVC~DisRiv_m + DisWet_m, family=binomial(link="logit"), data=spatialall)
summary(WaterFeat6)
res6a<-resid(WaterFeat6)
fit6a<-fitted(WaterFeat6)
plot(fit6a,res6a,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DisRiv & DisWet", pch=16)
WaterFeat7<-glm(Rand_MVC~DisRiv_m + DisOcn_m, family=binomial(link="logit"), data=spatialall)
summary(WaterFeat7)
res7a<-resid(WaterFeat7)
fit7a<-fitted(WaterFeat7)
plot(fit7a,res7a,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DisRiv & DisOcn", pch=16)
WaterFeat8<-glm(Rand_MVC~DisRiv_m + DisLak_m, family=binomial(link="logit"), data=spatialall)
summary(WaterFeat8)
res8a<-resid(WaterFeat8)
fit8a<-fitted(WaterFeat8)
plot(fit8a,res8a,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DisRiv & DisLak", pch=16)
WaterFeat9<-glm(Rand_MVC~DisWet_m + DisOcn_m, family=binomial(link="logit"), data=spatialall)
summary(WaterFeat9)
res9a<-resid(WaterFeat9)
fit9a<-fitted(WaterFeat9)
plot(fit9a,res9a,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DisWet & DisOcn", pch=16)
WaterFeat10<-glm(Rand_MVC~DisWet_m + DisLak_m, family=binomial(link="logit"), data=spatialall)
summary(WaterFeat10)
res10a<-resid(WaterFeat10)
fit10a<-fitted(WaterFeat10)
plot(fit10a,res10a,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DisWet & DisLak", pch=16)
WaterFeat11<-glm(Rand_MVC~DisOcn_m + DisLak_m, family=binomial(link="logit"), data=spatialall)
summary(WaterFeat11)
res11a<-resid(WaterFeat11)
fit11a<-fitted(WaterFeat11)
plot(fit11a,res11a,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DisOcn & DisLak", pch=16)
WaterFeat12<-glm(Rand_MVC~DisRiv_m, family=binomial(link="logit"), data=spatialall)
summary(WaterFeat12)
res12a<-resid(WaterFeat12)
fit12a<-fitted(WaterFeat12)
plot(fit12a,res12a,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DisRiv", pch=16)
WaterFeat13<-glm(Rand_MVC~DisWet_m, family=binomial(link="logit"), data=spatialall)
summary(WaterFeat13)
res13a<-resid(WaterFeat13)
fit13a<-fitted(WaterFeat13)
plot(fit13a,res13a,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DisWet", pch=16)
WaterFeat14<-glm(Rand_MVC~DisOcn_m, family=binomial(link="logit"), data=spatialall)
summary(WaterFeat14)
res14a<-resid(WaterFeat14)
fit14a<-fitted(WaterFeat14)
plot(fit14a,res14a,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DisOcn", pch=16)
WaterFeat15<-glm(Rand_MVC~DisLak_m, family=binomial(link="logit"), data=spatialall)
summary(WaterFeat15)
res15a<-resid(WaterFeat15)
fit15a<-fitted(WaterFeat15)
plot(fit15a,res15a,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DisLak", pch=16)

## Used to create Table S13
library(AICcmodavg)
Cand.models <- list( )
Cand.models[[1]] <- glm(Rand_MVC~DisRiv_m + DisWet_m + DisOcn_m + DisLak_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[2]] <- glm(Rand_MVC~DisRiv_m + DisWet_m + DisOcn_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[3]] <- glm(Rand_MVC~DisRiv_m + DisWet_m + DisLak_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[4]] <- glm(Rand_MVC~DisRiv_m + DisOcn_m + DisLak_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[5]] <- glm(Rand_MVC~DisWet_m + DisOcn_m + DisLak_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[6]] <- glm(Rand_MVC~DisRiv_m + DisWet_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[7]] <- glm(Rand_MVC~DisRiv_m + DisOcn_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[8]] <- glm(Rand_MVC~DisRiv_m + DisLak_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[9]] <- glm(Rand_MVC~DisWet_m + DisOcn_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[10]] <- glm(Rand_MVC~DisWet_m + DisLak_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[11]] <- glm(Rand_MVC~DisOcn_m + DisLak_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[12]] <- glm(Rand_MVC~DisRiv_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[13]] <- glm(Rand_MVC~DisWet_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[14]] <- glm(Rand_MVC~DisOcn_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[15]] <- glm(Rand_MVC~DisLak_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[16]] <- glm(Rand_MVC~1, family=binomial(link="logit"), data=spatialall)

##create a vector of names to trace back models in set
Modnames <- c("WaterFeat1", "WaterFeat2", "WaterFeat3", "WaterFeat4","WaterFeat5", "WaterFeat6", "WaterFeat7", "WaterFeat8", 
              "WaterFeat9", "WaterFeat10", "WaterFeat11", "WaterFeat12", "WaterFeat13", "WaterFeat14", "WaterFeat15", "Null")

##generate AICc table
aictab(cand.set = Cand.models, modnames = Modnames, sort = TRUE)
##round to 4 digits after decimal point and give log-likelihood
print(aictab(cand.set = Cand.models, modnames = Modnames, sort = TRUE),
      digits = 4, LL = TRUE)

Modnames <- data.frame(Names=c("WaterFeat1", "WaterFeat2", "WaterFeat3", "WaterFeat4","WaterFeat5", "WaterFeat6", "WaterFeat7", "WaterFeat8", 
                               "WaterFeat9", "WaterFeat10", "WaterFeat11", "WaterFeat12", "WaterFeat13", "WaterFeat14", "WaterFeat15", "Null"))

##for each model in Modnames run function NagelkerkeR2
library(fmsb)
Nag <- NULL
Nag <- rbind(Nag, data.frame(Nag=sapply(1:nrow(Modnames), function(i) {NagelkerkeR2(Cand.models[[i]])})))
Nag

##for each model in Modnames run deviance explained (null-resid)/null
library(fmsb)
Dev <- NULL
Dev <- rbind(Dev, data.frame(Dev=sapply(1:nrow(Modnames), function(i) {((Cand.models[[i]]$null.deviance-Cand.models[[i]]$deviance)/Cand.models[[i]]$null.deviance)})))
Dev

## Terrain Based Models 
Terrain1<-glm(Rand_MVC~TerrRugg500 + Aspect, family=binomial(link="logit"), data=spatialall)
summary(Terrain1)
res1b<-resid(Terrain1)
fit1b<-fitted(Terrain1)
plot(fit1b,res1b,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n TerrRugg500 & Aspect", pch=16)
Terrain2<-glm(Rand_MVC~TerrRugg2736 + Aspect, family=binomial(link="logit"), data=spatialall)
summary(Terrain2)
res2b<-resid(Terrain2)
fit2b<-fitted(Terrain2)
plot(fit2b,res2b,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n TerrRugg2736 & Aspect", pch=16)
Terrain3<-glm(Rand_MVC~TerrRugg5471 + Aspect, family=binomial(link="logit"), data=spatialall)
summary(Terrain3)
res3b<-resid(Terrain3)
fit3b<-fitted(Terrain3)
plot(fit3b,res3b,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n TerrRugg5471 & Aspect", pch=16)
Terrain4<-glm(Rand_MVC~Slope_mean500 + Aspect, family=binomial(link="logit"), data=spatialall)
summary(Terrain4)
res4b<-resid(Terrain4)
fit4b<-fitted(Terrain4)
plot(fit4b,res4b,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n Slope_mean500 & Aspect", pch=16)
Terrain5<-glm(Rand_MVC~Slope_mean2736 + Aspect, family=binomial(link="logit"), data=spatialall)
summary(Terrain5)
res5b<-resid(Terrain5)
fit5b<-fitted(Terrain5)
plot(fit5b,res5b,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n Slope_mean2736 & Aspect", pch=16)
Terrain6<-glm(Rand_MVC~Slope_mean5471 + Aspect, family=binomial(link="logit"), data=spatialall)
summary(Terrain6)
res6b<-resid(Terrain6)
fit6b<-fitted(Terrain6)
plot(fit6b,res6b,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n Slope_mean5471 & Aspect", pch=16)
Terrain7<-glm(Rand_MVC~TerrRugg500, family=binomial(link="logit"), data=spatialall)
summary(Terrain7)
res7b<-resid(Terrain7)
fit7b<-fitted(Terrain7)
plot(fit7b,res7b,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n TerrRugg500", pch=16)
Terrain8<-glm(Rand_MVC~TerrRugg2736, family=binomial(link="logit"), data=spatialall)
summary(Terrain8)
res8b<-resid(Terrain8)
fit8b<-fitted(Terrain8)
plot(fit8b,res8b,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n TerrRugg2736", pch=16)
Terrain9<-glm(Rand_MVC~TerrRugg5471, family=binomial(link="logit"), data=spatialall)
summary(Terrain9)
res9b<-resid(Terrain9)
fit9b<-fitted(Terrain9)
plot(fit9b,res9b,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n TerrRugg5471", pch=16)
Terrain10<-glm(Rand_MVC~Aspect, family=binomial(link="logit"), data=spatialall)
summary(Terrain10)
res10b<-resid(Terrain10)
fit10b<-fitted(Terrain10)
plot(fit10b,res10b,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n Aspect", pch=16)
Terrain11<-glm(Rand_MVC~Slope_mean500, family=binomial(link="logit"), data=spatialall)
summary(Terrain11)
res11b<-resid(Terrain11)
fit11b<-fitted(Terrain11)
plot(fit11b,res11b,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n Slope_mean500", pch=16)
Terrain12<-glm(Rand_MVC~Slope_mean2736, family=binomial(link="logit"), data=spatialall)
summary(Terrain12)
res12b<-resid(Terrain12)
fit12b<-fitted(Terrain12)
plot(fit12b,res12b,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n Slope_mean2736", pch=16)
Terrain13<-glm(Rand_MVC~Slope_mean5471, family=binomial(link="logit"), data=spatialall)
summary(Terrain13)
res13b<-resid(Terrain13)
fit13b<-fitted(Terrain13)
plot(fit13b,res13b,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n Slope_mean5471", pch=16)

## Used to create Table S8
library(AICcmodavg)
Cand.models <- list( )
Cand.models[[1]] <- glm(Rand_MVC~TerrRugg500 + Aspect, family=binomial(link="logit"), data=spatialall)
Cand.models[[2]] <- glm(Rand_MVC~TerrRugg2736 + Aspect, family=binomial(link="logit"), data=spatialall)
Cand.models[[3]] <- glm(Rand_MVC~TerrRugg5471 + Aspect, family=binomial(link="logit"), data=spatialall)
Cand.models[[4]] <- glm(Rand_MVC~Slope_mean500 + Aspect, family=binomial(link="logit"), data=spatialall)
Cand.models[[5]] <- glm(Rand_MVC~Slope_mean2736 + Aspect, family=binomial(link="logit"), data=spatialall)
Cand.models[[6]] <- glm(Rand_MVC~Slope_mean5471 + Aspect, family=binomial(link="logit"), data=spatialall)
Cand.models[[7]] <- glm(Rand_MVC~TerrRugg500, family=binomial(link="logit"), data=spatialall)
Cand.models[[8]] <- glm(Rand_MVC~TerrRugg2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[9]] <- glm(Rand_MVC~TerrRugg5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[10]] <- glm(Rand_MVC~Aspect, family=binomial(link="logit"), data=spatialall)
Cand.models[[11]] <- glm(Rand_MVC~Slope_mean500, family=binomial(link="logit"), data=spatialall)
Cand.models[[12]] <- glm(Rand_MVC~Slope_mean2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[13]] <- glm(Rand_MVC~Slope_mean5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[14]] <- glm(Rand_MVC~1, family=binomial(link="logit"), data=spatialall)

##create a vector of names to trace back models in set
Modnames <- c("Terrain1", "Terrain2", "Terrain3", "Terrain4","Terrain5", "Terrain6", "Terrain7", "Terrain8", 
              "Terrain9", "Terrain10", "Terrain11", "Terrain12", "Terrain13", "Null")

##generate AICc table
aictab(cand.set = Cand.models, modnames = Modnames, sort = TRUE)
##round to 4 digits after decimal point and give log-likelihood
print(aictab(cand.set = Cand.models, modnames = Modnames, sort = TRUE),
      digits = 4, LL = TRUE)

Modnames <- data.frame(Names=c("Terrain1", "Terrain2", "Terrain3", "Terrain4","Terrain5", "Terrain6", "Terrain7", "Terrain8", 
                               "Terrain9", "Terrain10", "Terrain11", "Terrain12", "Terrain13", "Null"))

##for each model in Modnames run function NagelkerkeR2
library(fmsb)
Nag <- NULL
Nag <- rbind(Nag, data.frame(Nag=sapply(1:nrow(Modnames), function(i) {NagelkerkeR2(Cand.models[[i]])})))
Nag

##for each model in Modnames run deviance explained (null-resid)/null
library(fmsb)
Dev <- NULL
Dev <- rbind(Dev, data.frame(Dev=sapply(1:nrow(Modnames), function(i) {((Cand.models[[i]]$null.deviance-Cand.models[[i]]$deviance)/Cand.models[[i]]$null.deviance)})))
Dev

## Disturbance/ Road Based Models 
Road5<-glm(Rand_MVC~RdClass + Sinuosity + DisMA_m + DisDevA_m, family=binomial(link="logit"), data=spatialall)
summary(Road5)
res5c<-resid(Road5)
fit5c<-fitted(Road5)
plot(fit5c,res5c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & Sinuosity & MA & DevA", pch=16)

## Used to create Table 2 ****
Road6<-glm(Rand_MVC~RdClass + Sinuosity + DisMA_m + DisDevL_m, family=binomial(link="logit"), data=spatialall)
summary(Road6)
res6c<-resid(Road6)
fit6c<-fitted(Road6)
plot(fit6c,res6c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & Sinuosity & MA & DevL", pch=16)

## Continuation of Disturbance/ Road Based Models
Road7<-glm(Rand_MVC~RdClass + Sinuosity + DisMA_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
summary(Road7)
res7c<-resid(Road7)
fit7c<-fitted(Road7)
plot(fit7c,res7c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & Sinuosity & MA & DevS", pch=16)
Road8<-glm(Rand_MVC~RdClass + Sinuosity + DisDevA_m + DisDevM_m, family=binomial(link="logit"), data=spatialall)
summary(Road8)
res8c<-resid(Road8)
fit8c<-fitted(Road8)
plot(fit8c,res8c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & Sinuosity & DevA & DevM", pch=16)
Road9<-glm(Rand_MVC~RdClass + Sinuosity + DisDevA_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
summary(Road9)
res9c<-resid(Road9)
fit9c<-fitted(Road9)
plot(fit9c,res9c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & Sinuosity & DevA & DevS", pch=16)
Road10<-glm(Rand_MVC~RdClass + Sinuosity + DisDevL_m + DisDevM_m, family=binomial(link="logit"), data=spatialall)
summary(Road10)
res10c<-resid(Road10)
fit10c<-fitted(Road10)
plot(fit10c,res10c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & Sinuosity & DevL & DevM", pch=16)
Road12<-glm(Rand_MVC~RdClass + Sinuosity + DisDevM_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
summary(Road12)
res12c<-resid(Road12)
fit12c<-fitted(Road12)
plot(fit12c,res12c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & Sinuosity & DevM & DevS", pch=16)
Road14<-glm(Rand_MVC~RdClass + DisMA_m + DisDevL_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
summary(Road14)
res14c<-resid(Road14)
fit14c<-fitted(Road14)
plot(fit14c,res14c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & MA & DevL & DevS", pch=16)
Road16<-glm(Rand_MVC~RdClass + DisDevL_m + DisDevM_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
summary(Road16)
res16c<-resid(Road16)
fit16c<-fitted(Road16)
plot(fit16c,res16c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & DevL & DevM & DevS", pch=16)
Road17<-glm(Rand_MVC~Sinuosity + DisMA_m + DisDevA_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
summary(Road17)
res17c<-resid(Road17)
fit17c<-fitted(Road17)
plot(fit17c,res17c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n Sinuosity & MA & DevA & DevS", pch=16)
Road18<-glm(Rand_MVC~Sinuosity + DisMA_m + DisDevL_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
summary(Road18)
res18c<-resid(Road18)
fit18c<-fitted(Road18)
plot(fit18c,res18c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n Sinuosity & MA & DevL & DevS", pch=16)
Road19<-glm(Rand_MVC~Sinuosity + DisDevA_m + DisDevM_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
summary(Road19)
res19c<-resid(Road19)
fit19c<-fitted(Road19)
plot(fit19c,res19c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n Sinuosity & DevA & DevM & DevS", pch=16)
Road21<-glm(Rand_MVC~RdClass + Sinuosity + DisMA_m, family=binomial(link="logit"), data=spatialall)
summary(Road21)
res21c<-resid(Road21)
fit21c<-fitted(Road21)
plot(fit21c,res21c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & Sinuosity & MA", pch=16)
Road22<-glm(Rand_MVC~RdClass + Sinuosity + DisDevA_m, family=binomial(link="logit"), data=spatialall)
summary(Road22)
res22c<-resid(Road22)
fit22c<-fitted(Road22)
plot(fit22c,res22c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & Sinuosity & DevA", pch=16)
Road23<-glm(Rand_MVC~RdClass + Sinuosity + DisDevL_m, family=binomial(link="logit"), data=spatialall)
summary(Road23)
res23c<-resid(Road23)
fit23c<-fitted(Road23)
plot(fit23c,res23c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & Sinuosity & DevL", pch=16)
Road24<-glm(Rand_MVC~RdClass + Sinuosity + DisDevM_m, family=binomial(link="logit"), data=spatialall)
summary(Road24)
res24c<-resid(Road24)
fit24c<-fitted(Road24)
plot(fit24c,res24c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & Sinuosity & DevM", pch=16)
Road25<-glm(Rand_MVC~RdClass + Sinuosity + DisDevS_m, family=binomial(link="logit"), data=spatialall)
summary(Road25)
res25c<-resid(Road25)
fit25c<-fitted(Road25)
plot(fit25c,res25c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & Sinuosity & DevS", pch=16)
Road26<-glm(Rand_MVC~RdClass + DisMA_m + DisDevA_m, family=binomial(link="logit"), data=spatialall)
summary(Road26)
res26c<-resid(Road26)
fit26c<-fitted(Road26)
plot(fit26c,res26c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & MA & DevA", pch=16)
Road27<-glm(Rand_MVC~RdClass + DisMA_m + DisDevL_m, family=binomial(link="logit"), data=spatialall)
summary(Road27)
res27c<-resid(Road27)
fit27c<-fitted(Road27)
plot(fit27c,res27c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & MA & DevL", pch=16)
Road28<-glm(Rand_MVC~RdClass + DisMA_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
summary(Road28)
res28c<-resid(Road28)
fit28c<-fitted(Road28)
plot(fit28c,res28c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & MA & DevS", pch=16)
Road29<-glm(Rand_MVC~RdClass + DisDevA_m + DisDevM_m, family=binomial(link="logit"), data=spatialall)
summary(Road29)
res29c<-resid(Road29)
fit29c<-fitted(Road29)
plot(fit29c,res29c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & DevA & DevM", pch=16)
Road30<-glm(Rand_MVC~RdClass + DisDevA_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
summary(Road30)
res30c<-resid(Road30)
fit30c<-fitted(Road30)
plot(fit30c,res30c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & DevA & DevS", pch=16)
Road31<-glm(Rand_MVC~RdClass + DisDevL_m + DisDevM_m, family=binomial(link="logit"), data=spatialall)
summary(Road31)
res31c<-resid(Road31)
fit31c<-fitted(Road31)
plot(fit31c,res31c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & DevL & DevM", pch=16)
Road33<-glm(Rand_MVC~RdClass + DisDevM_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
summary(Road33)
res33c<-resid(Road33)
fit33c<-fitted(Road33)
plot(fit33c,res33c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & DevM & DevS", pch=16)
Road34<-glm(Rand_MVC~Sinuosity + DisMA_m + DisDevA_m, family=binomial(link="logit"), data=spatialall)
summary(Road34)
res34c<-resid(Road34)
fit34c<-fitted(Road34)
plot(fit34c,res34c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n Sinuosity & MA & DevA", pch=16)
Road35<-glm(Rand_MVC~Sinuosity + DisMA_m + DisDevL_m, family=binomial(link="logit"), data=spatialall)
summary(Road35)
res35c<-resid(Road35)
fit35c<-fitted(Road35)
plot(fit35c,res35c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n Sinuosity & MA & DevL", pch=16)
Road36<-glm(Rand_MVC~Sinuosity + DisMA_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
summary(Road36)
res36c<-resid(Road36)
fit36c<-fitted(Road36)
plot(fit36c,res36c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n Sinuosity & MA & DevS", pch=16)
Road37<-glm(Rand_MVC~Sinuosity + DisDevA_m + DisDevM_m, family=binomial(link="logit"), data=spatialall)
summary(Road37)
res37c<-resid(Road37)
fit37c<-fitted(Road37)
plot(fit37c,res37c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n Sinuosity & DevA & DevM", pch=16)
Road38<-glm(Rand_MVC~Sinuosity + DisDevA_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
summary(Road38)
res38c<-resid(Road38)
fit38c<-fitted(Road38)
plot(fit38c,res38c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n Sinuosity & DevA & DevS", pch=16)
Road39<-glm(Rand_MVC~Sinuosity + DisDevL_m + DisDevM_m, family=binomial(link="logit"), data=spatialall)
summary(Road39)
res39c<-resid(Road39)
fit39c<-fitted(Road39)
plot(fit39c,res39c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n Sinuosity & DevL & DevM", pch=16)
Road41<-glm(Rand_MVC~Sinuosity + DisDevM_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
summary(Road41)
res41c<-resid(Road41)
fit41c<-fitted(Road41)
plot(fit41c,res41c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n Sinuosity & DevM & DevS", pch=16)
Road42<-glm(Rand_MVC~DisMA_m + DisDevA_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
summary(Road42)
res42c<-resid(Road42)
fit42c<-fitted(Road42)
plot(fit42c,res42c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n MA & DevA & DevS", pch=16)
Road43<-glm(Rand_MVC~DisMA_m + DisDevL_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
summary(Road43)
res43c<-resid(Road43)
fit43c<-fitted(Road43)
plot(fit43c,res43c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n MA & DevL & DevS", pch=16)
Road44<-glm(Rand_MVC~DisDevA_m + DisDevM_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
summary(Road44)
res44c<-resid(Road44)
fit44c<-fitted(Road44)
plot(fit44c,res44c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DevA & DevM & DevS", pch=16)
Road46<-glm(Rand_MVC~RdClass + Sinuosity, family=binomial(link="logit"), data=spatialall)
summary(Road46)
res46c<-resid(Road46)
fit46c<-fitted(Road46)
plot(fit46c,res46c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & Sinuosity", pch=16)
Road47<-glm(Rand_MVC~RdClass + DisMA_m, family=binomial(link="logit"), data=spatialall)
summary(Road47)
res47c<-resid(Road47)
fit47c<-fitted(Road47)
plot(fit47c,res47c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & DisMA", pch=16)
Road48<-glm(Rand_MVC~RdClass + DisDevA_m, family=binomial(link="logit"), data=spatialall)
summary(Road48)
res48c<-resid(Road48)
fit48c<-fitted(Road48)
plot(fit48c,res48c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & DevA", pch=16)
Road49<-glm(Rand_MVC~RdClass + DisDevL_m, family=binomial(link="logit"), data=spatialall)
summary(Road49)
res49c<-resid(Road49)
fit49c<-fitted(Road49)
plot(fit49c,res49c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & DevL", pch=16)
Road50<-glm(Rand_MVC~RdClass + DisDevM_m, family=binomial(link="logit"), data=spatialall)
summary(Road50)
res50c<-resid(Road50)
fit50c<-fitted(Road50)
plot(fit50c,res50c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & DevM", pch=16)
Road51<-glm(Rand_MVC~RdClass + DisDevS_m, family=binomial(link="logit"), data=spatialall)
summary(Road51)
res51c<-resid(Road51)
fit51c<-fitted(Road51)
plot(fit51c,res51c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & DevS", pch=16)
Road52<-glm(Rand_MVC~Sinuosity + DisMA_m, family=binomial(link="logit"), data=spatialall)
summary(Road52)
res52c<-resid(Road52)
fit52c<-fitted(Road52)
plot(fit52c,res52c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n RdClass & DevS", pch=16)
Road53<-glm(Rand_MVC~Sinuosity + DisDevA_m, family=binomial(link="logit"), data=spatialall)
summary(Road53)
res53c<-resid(Road53)
fit53c<-fitted(Road53)
plot(fit53c,res53c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n Sinuosity & DevA", pch=16)
Road54<-glm(Rand_MVC~Sinuosity + DisDevL_m, family=binomial(link="logit"), data=spatialall)
summary(Road54)
res54c<-resid(Road54)
fit54c<-fitted(Road54)
plot(fit54c,res54c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n Sinuosity & DevL", pch=16)
Road55<-glm(Rand_MVC~Sinuosity + DisDevM_m, family=binomial(link="logit"), data=spatialall)
summary(Road55)
res55c<-resid(Road55)
fit55c<-fitted(Road55)
plot(fit55c,res55c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n Sinuosity & DevM", pch=16)
Road56<-glm(Rand_MVC~Sinuosity + DisDevS_m, family=binomial(link="logit"), data=spatialall)
summary(Road56)
res56c<-resid(Road56)
fit56c<-fitted(Road56)
plot(fit56c,res56c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n Sinuosity & DevS", pch=16)
Road57<-glm(Rand_MVC~DisMA_m + DisDevA_m, family=binomial(link="logit"), data=spatialall)
summary(Road57)
res57c<-resid(Road57)
fit57c<-fitted(Road57)
plot(fit57c,res57c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DisMA & DevA", pch=16)
Road58<-glm(Rand_MVC~DisMA_m + DisDevL_m, family=binomial(link="logit"), data=spatialall)
summary(Road58)
res58c<-resid(Road58)
fit58c<-fitted(Road58)
plot(fit58c,res58c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DisMA & DevL", pch=16)
Road59<-glm(Rand_MVC~DisMA_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
summary(Road59)
res59c<-resid(Road59)
fit59c<-fitted(Road59)
plot(fit59c,res59c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DisMA & DevS", pch=16)
Road60<-glm(Rand_MVC~DisDevA_m + DisDevM_m, family=binomial(link="logit"), data=spatialall)
summary(Road60)
res60c<-resid(Road60)
fit60c<-fitted(Road60)
plot(fit60c,res60c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DevA & DevM", pch=16)
Road62<-glm(Rand_MVC~DisDevL_m + DisDevM_m, family=binomial(link="logit"), data=spatialall)
summary(Road62)
res62c<-resid(Road62)
fit62c<-fitted(Road62)
plot(fit62c,res62c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DevL & DevM", pch=16)
Road63<-glm(Rand_MVC~DisDevL_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
summary(Road63)
res63c<-resid(Road63)
fit63c<-fitted(Road63)
plot(fit63c,res63c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DevL & DevS", pch=16)
Road64<-glm(Rand_MVC~DisDevM_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
summary(Road64)
res64c<-resid(Road64)
fit64c<-fitted(Road64)
plot(fit64c,res64c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DevM & DevS", pch=16)
Road65<-glm(Rand_MVC~RdClass, family=binomial(link="logit"), data=spatialall)
summary(Road65)
res65c<-resid(Road65)
fit65c<-fitted(Road65)
plot(fit65c,res65c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DevM & DevS", pch=16)
Road66<-glm(Rand_MVC~Sinuosity, family=binomial(link="logit"), data=spatialall)
summary(Road66)
res66c<-resid(Road66)
fit66c<-fitted(Road66)
plot(fit66c,res66c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n Sinuosity", pch=16)
Road67<-glm(Rand_MVC~DisMA_m, family=binomial(link="logit"), data=spatialall)
summary(Road67)
res67c<-resid(Road67)
fit67c<-fitted(Road67)
plot(fit67c,res67c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n MA", pch=16)
Road68<-glm(Rand_MVC~DisDevA_m, family=binomial(link="logit"), data=spatialall)
summary(Road68)
res68c<-resid(Road68)
fit68c<-fitted(Road68)
plot(fit68c,res68c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DevA", pch=16)
Road69<-glm(Rand_MVC~DisDevL_m, family=binomial(link="logit"), data=spatialall)
summary(Road69)
res69c<-resid(Road69)
fit69c<-fitted(Road69)
plot(fit69c,res69c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DevL", pch=16)
Road70<-glm(Rand_MVC~DisDevM_m, family=binomial(link="logit"), data=spatialall)
summary(Road70)
res70c<-resid(Road70)
fit70c<-fitted(Road70)
plot(fit70c,res70c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DevM", pch=16)
Road71<-glm(Rand_MVC~DisDevS_m, family=binomial(link="logit"), data=spatialall)
summary(Road71)
res71c<-resid(Road71)
fit71c<-fitted(Road71)
plot(fit71c,res71c,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DevS", pch=16)

## Used to create Table S11
library(AICcmodavg)
Cand.models <- list( )
Cand.models[[1]]<-glm(Rand_MVC~RdClass + Sinuosity + DisMA_m + DisDevA_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[2]]<-glm(Rand_MVC~RdClass + Sinuosity + DisMA_m + DisDevL_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[3]]<-glm(Rand_MVC~RdClass + Sinuosity + DisMA_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[4]]<-glm(Rand_MVC~RdClass + Sinuosity + DisDevA_m + DisDevM_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[5]]<-glm(Rand_MVC~RdClass + Sinuosity + DisDevA_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[6]]<-glm(Rand_MVC~RdClass + Sinuosity + DisDevL_m + DisDevM_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[7]]<-glm(Rand_MVC~RdClass + Sinuosity + DisDevM_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[8]]<-glm(Rand_MVC~RdClass + DisMA_m + DisDevL_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[9]]<-glm(Rand_MVC~RdClass + DisDevL_m + DisDevM_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[10]]<-glm(Rand_MVC~Sinuosity + DisMA_m + DisDevA_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[11]]<-glm(Rand_MVC~Sinuosity + DisMA_m + DisDevL_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[12]]<-glm(Rand_MVC~Sinuosity + DisDevA_m + DisDevM_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[13]]<-glm(Rand_MVC~RdClass + Sinuosity + DisMA_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[14]]<-glm(Rand_MVC~RdClass + Sinuosity + DisDevA_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[15]]<-glm(Rand_MVC~RdClass + Sinuosity + DisDevL_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[16]]<-glm(Rand_MVC~RdClass + Sinuosity + DisDevM_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[17]]<-glm(Rand_MVC~RdClass + Sinuosity + DisDevS_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[18]]<-glm(Rand_MVC~RdClass + DisMA_m + DisDevA_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[19]]<-glm(Rand_MVC~RdClass + DisMA_m + DisDevL_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[20]]<-glm(Rand_MVC~RdClass + DisMA_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[21]]<-glm(Rand_MVC~RdClass + DisDevA_m + DisDevM_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[22]]<-glm(Rand_MVC~RdClass + DisDevA_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[23]]<-glm(Rand_MVC~RdClass + DisDevL_m + DisDevM_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[24]]<-glm(Rand_MVC~RdClass + DisDevM_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[25]]<-glm(Rand_MVC~Sinuosity + DisMA_m + DisDevA_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[26]]<-glm(Rand_MVC~Sinuosity + DisMA_m + DisDevL_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[27]]<-glm(Rand_MVC~Sinuosity + DisMA_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[28]]<-glm(Rand_MVC~Sinuosity + DisDevA_m + DisDevM_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[29]]<-glm(Rand_MVC~Sinuosity + DisDevA_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[30]]<-glm(Rand_MVC~Sinuosity + DisDevL_m + DisDevM_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[31]]<-glm(Rand_MVC~Sinuosity + DisDevM_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[32]]<-glm(Rand_MVC~DisMA_m + DisDevA_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[33]]<-glm(Rand_MVC~DisMA_m + DisDevL_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[34]]<-glm(Rand_MVC~DisDevA_m + DisDevM_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[35]]<-glm(Rand_MVC~RdClass + Sinuosity, family=binomial(link="logit"), data=spatialall)
Cand.models[[36]]<-glm(Rand_MVC~RdClass + DisMA_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[37]]<-glm(Rand_MVC~RdClass + DisDevA_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[38]]<-glm(Rand_MVC~RdClass + DisDevL_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[39]]<-glm(Rand_MVC~RdClass + DisDevM_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[40]]<-glm(Rand_MVC~RdClass + DisDevS_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[41]]<-glm(Rand_MVC~Sinuosity + DisMA_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[42]]<-glm(Rand_MVC~Sinuosity + DisDevA_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[43]]<-glm(Rand_MVC~Sinuosity + DisDevL_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[44]]<-glm(Rand_MVC~Sinuosity + DisDevM_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[45]]<-glm(Rand_MVC~Sinuosity + DisDevS_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[46]]<-glm(Rand_MVC~DisMA_m + DisDevA_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[47]]<-glm(Rand_MVC~DisMA_m + DisDevL_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[48]]<-glm(Rand_MVC~DisMA_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[49]]<-glm(Rand_MVC~DisDevA_m + DisDevM_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[50]]<-glm(Rand_MVC~DisDevL_m + DisDevM_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[51]]<-glm(Rand_MVC~DisDevL_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[52]]<-glm(Rand_MVC~DisDevM_m + DisDevS_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[53]]<-glm(Rand_MVC~RdClass, family=binomial(link="logit"), data=spatialall)
Cand.models[[54]]<-glm(Rand_MVC~Sinuosity, family=binomial(link="logit"), data=spatialall)
Cand.models[[55]]<-glm(Rand_MVC~DisMA_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[56]]<-glm(Rand_MVC~DisDevA_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[57]]<-glm(Rand_MVC~DisDevL_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[58]]<-glm(Rand_MVC~DisDevM_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[59]]<-glm(Rand_MVC~DisDevS_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[60]]<-glm(Rand_MVC~1, family=binomial(link="logit"), data=spatialall)

##create a vector of names to trace back models in set
Modnames <- c("Road5", "Road6", "Road7", "Road8", "Road9", "Road10", "Road12", "Road14", "Road16", "Road17", "Road18", "Road19", "Road21", "Road22", "Road23", 
              "Road24", "Road25", "Road26", "Road27", "Road28", "Road29", "Road30", "Road31", "Road33","Road34", "Road35", "Road36", "Road37", "Road38", 
              "Road39", "Road41", "Road42", "Road43", "Road44", "Road46", "Road47", "Road48", "Road49","Road50", "Road51", "Road52", "Road53", "Road54", 
              "Road55", "Road56", "Road57", "Road58", "Road59", "Road60", "Road62", "Road63", "Road64", "Road65","Road66", "Road67", "Road68", "Road69", "Road70", 
              "Road71", "Null")

##generate AICc table
aictab(cand.set = Cand.models, modnames = Modnames, sort = TRUE)
##round to 4 digits after decimal point and give log-likelihood
print(aictab(cand.set = Cand.models, modnames = Modnames, sort = TRUE),
      digits = 4, LL = TRUE)

Modnames <- data.frame(Names=c("Road5", "Road6", "Road7", "Road8", "Road9", "Road10", "Road12", "Road14", "Road16", "Road17", "Road18", "Road19", "Road21", "Road22", "Road23", 
                               "Road24", "Road25", "Road26", "Road27", "Road28", "Road29", "Road30", "Road31", "Road33","Road34", "Road35", "Road36", "Road37", "Road38", 
                               "Road39", "Road41", "Road42", "Road43", "Road44", "Road46", "Road47", "Road48", "Road49","Road50", "Road51", "Road52", "Road53", "Road54", 
                               "Road55", "Road56", "Road57", "Road58", "Road59", "Road60", "Road62", "Road63", "Road64", "Road65","Road66", "Road67", "Road68", "Road69", "Road70", 
                               "Road71", "Null"))

##for each model in Modnames run function NagelkerkeR2
library(fmsb)
Nag <- NULL
Nag <- rbind(Nag, data.frame(Nag=sapply(1:nrow(Modnames), function(i) {NagelkerkeR2(Cand.models[[i]])})))
Nag

##for each model in Modnames run deviance explained (null-resid)/null
library(fmsb)
Dev <- NULL
Dev <- rbind(Dev, data.frame(Dev=sapply(1:nrow(Modnames), function(i) {((Cand.models[[i]]$null.deviance-Cand.models[[i]]$deviance)/Cand.models[[i]]$null.deviance)})))
Dev

## Mitigation Based Models
Mitigation1<-glm(Rand_MVC~VegCtLoc, family=binomial(link="logit"), data=spatialall)
summary(Mitigation1)
res1d<-resid(Mitigation1)
fit1d<-fitted(Mitigation1)
plot(fit1d,res1d,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n VegCtLoc", pch=16)

## Used to create Table S12
library(AICcmodavg)
Cand.models <- list( )
Cand.models[[1]] <- glm(Rand_MVC~VegCtLoc, family=binomial(link="logit"), data=spatialall)
Cand.models[[2]] <- glm(Rand_MVC~1, family=binomial(link="logit"), data=spatialall)

##create a vector of names to trace back models in set
Modnames <- c("Mitigation1", "Null")

##generate AICc table
aictab(cand.set = Cand.models, modnames = Modnames, sort = TRUE)
##round to 4 digits after decimal point and give log-likelihood
print(aictab(cand.set = Cand.models, modnames = Modnames, sort = TRUE),
      digits = 4, LL = TRUE)

Modnames <- data.frame(Names=c("Mitigation1", "Null"))

##for each model in Modnames run function NagelkerkeR2
library(fmsb)
Nag <- NULL
Nag <- rbind(Nag, data.frame(Nag=sapply(1:nrow(Modnames), function(i) {NagelkerkeR2(Cand.models[[i]])})))
Nag

##for each model in Modnames run deviance explained (null-resid)/null
library(fmsb)
Dev <- NULL
Dev <- rbind(Dev, data.frame(Dev=sapply(1:nrow(Modnames), function(i) {((Cand.models[[i]]$null.deviance-Cand.models[[i]]$deviance)/Cand.models[[i]]$null.deviance)})))
Dev

## Moose Density Models 
MooseDensity1<-glm(Rand_MVC~MooseDen, family=binomial(link="logit"), data=spatialall)
summary(MooseDensity1)
res1e<-resid(MooseDensity1)
fit1e<-fitted(MooseDensity1)
plot(fit1e,res1e,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n MooseDen", pch=16)

## Used to create Table S14
library(AICcmodavg)
Cand.models <- list( )
Cand.models[[1]] <- glm(Rand_MVC~MooseDen, family=binomial(link="logit"), data=spatialall)
Cand.models[[2]] <- glm(Rand_MVC~1, family=binomial(link="logit"), data=spatialall)

##create a vector of names to trace back models in set
Modnames <- c("MooseDensity1", "Null")

##generate AICc table
aictab(cand.set = Cand.models, modnames = Modnames, sort = TRUE)
##round to 4 digits after decimal point and give log-likelihood
print(aictab(cand.set = Cand.models, modnames = Modnames, sort = TRUE),
      digits = 4, LL = TRUE)

Modnames <- data.frame(Names=c("MooseDensity1", "Null"))

##for each model in Modnames run function NagelkerkeR2
library(fmsb)
Nag <- NULL
Nag <- rbind(Nag, data.frame(Nag=sapply(1:nrow(Modnames), function(i) {NagelkerkeR2(Cand.models[[i]])})))
Nag

##for each model in Modnames run deviance explained (null-resid)/null
library(fmsb)
Dev <- NULL
Dev <- rbind(Dev, data.frame(Dev=sapply(1:nrow(Modnames), function(i) {((Cand.models[[i]]$null.deviance-Cand.models[[i]]$deviance)/Cand.models[[i]]$null.deviance)})))
Dev

## Travel Corridor Based Models (Density)
TravelDen1<-glm(Rand_MVC~DenFAR500 + DenRW500 + DenTL500 + DenTR500, family=binomial(link="logit"), data=spatialall)
summary(TravelDen1)
res1f<-resid(TravelDen1)
fit1f<-fitted(TravelDen1)
plot(fit1f,res1f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n FAR & RW & TL & TR", pch=16)
TravelDen2<-glm(Rand_MVC~DenFAR2736 + DenRW2736 + DenTL2736 + DenTR2736, family=binomial(link="logit"), data=spatialall)
summary(TravelDen2)
res2f<-resid(TravelDen2)
fit2f<-fitted(TravelDen2)
plot(fit2f,res2f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenFAR2736 & DenRW2736 & DenTL2736 & DenTR2736", pch=16)
TravelDen3<-glm(Rand_MVC~DenFAR500 + DenRW500 + DenTL500, family=binomial(link="logit"), data=spatialall)
summary(TravelDen3)
res3f<-resid(TravelDen3)
fit3f<-fitted(TravelDen3)
plot(fit3f,res3f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenFAR500 & DenRW500 & DenTL500", pch=16)
TravelDen4<-glm(Rand_MVC~DenFAR500 + DenRW500 + DenTR500, family=binomial(link="logit"), data=spatialall)
summary(TravelDen4)
res4f<-resid(TravelDen4)
fit4f<-fitted(TravelDen4)
plot(fit4f,res4f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenFAR500 & DenRW500 & DenTR500", pch=16)
TravelDen5<-glm(Rand_MVC~DenFAR500 + DenTL500 + DenTR500, family=binomial(link="logit"), data=spatialall)
summary(TravelDen5)
res5f<-resid(TravelDen5)
fit5f<-fitted(TravelDen5)
plot(fit5f,res5f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenFAR500 & DenTL500 & DenTR500", pch=16)
TravelDen7<-glm(Rand_MVC~DenFAR2736 + DenRW2736 + DenTL2736, family=binomial(link="logit"), data=spatialall)
summary(TravelDen7)
res7f<-resid(TravelDen7)
fit7f<-fitted(TravelDen7)
plot(fit7f,res7f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenFAR2736 & DenRW2736 & DenTL2736", pch=16)
TravelDen8<-glm(Rand_MVC~DenFAR2736 + DenRW2736 + DenTR2736, family=binomial(link="logit"), data=spatialall)
summary(TravelDen8)
res8f<-resid(TravelDen8)
fit8f<-fitted(TravelDen8)
plot(fit8f,res8f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenFAR2736 & DenRW2736 & DenTR2736", pch=16)
TravelDen9<-glm(Rand_MVC~DenFAR2736 + DenTL2736 + DenTR2736, family=binomial(link="logit"), data=spatialall)
summary(TravelDen9)
res9f<-resid(TravelDen9)
fit9f<-fitted(TravelDen9)
plot(fit9f,res9f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenFAR2736 & DenTL2736 & DenTR2736", pch=16)
TravelDen11<-glm(Rand_MVC~DenFAR5471 + DenRW5471 + DenTR5471, family=binomial(link="logit"), data=spatialall)
summary(TravelDen11)
res11f<-resid(TravelDen11)
fit11f<-fitted(TravelDen11)
plot(fit11f,res11f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenFAR5471 & DenRW5471 & DenTR5471", pch=16)
TravelDen12<-glm(Rand_MVC~DenFAR5471 + DenTL5471 + DenTR5471, family=binomial(link="logit"), data=spatialall)
summary(TravelDen12)
res12f<-resid(TravelDen12)
fit12f<-fitted(TravelDen12)
plot(fit12f,res12f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenFAR5471 & DenTL5471 & DenTR5471", pch=16)
TravelDen13<-glm(Rand_MVC~DenFAR500 + DenRW500, family=binomial(link="logit"), data=spatialall)
summary(TravelDen13)
res13f<-resid(TravelDen13)
fit13f<-fitted(TravelDen13)
plot(fit13f,res13f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenFAR500 & DenRW500", pch=16)
TravelDen14<-glm(Rand_MVC~DenFAR500 + DenTL500, family=binomial(link="logit"), data=spatialall)
summary(TravelDen14)
res14f<-resid(TravelDen14)
fit14f<-fitted(TravelDen14)
plot(fit14f,res14f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenFAR500 & DenTL500", pch=16)
TravelDen15<-glm(Rand_MVC~DenFAR500 + DenTR500, family=binomial(link="logit"), data=spatialall)
summary(TravelDen15)
res15f<-resid(TravelDen15)
fit15f<-fitted(TravelDen15)
plot(fit15f,res15f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenFAR500 & DenTR500", pch=16)
TravelDen19<-glm(Rand_MVC~DenFAR2736 + DenRW2736, family=binomial(link="logit"), data=spatialall)
summary(TravelDen19)
res19f<-resid(TravelDen19)
fit19f<-fitted(TravelDen19)
plot(fit19f,res19f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenFAR2736 & DenRW2736", pch=16)
TravelDen20<-glm(Rand_MVC~DenFAR2736 + DenTL2736, family=binomial(link="logit"), data=spatialall)
summary(TravelDen20)
res20f<-resid(TravelDen20)
fit20f<-fitted(TravelDen20)
plot(fit20f,res20f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenFAR2736 & DenTL2736", pch=16)
TravelDen21<-glm(Rand_MVC~DenFAR2736 + DenTR2736, family=binomial(link="logit"), data=spatialall)
summary(TravelDen21)
res21f<-resid(TravelDen21)
fit21f<-fitted(TravelDen21)
plot(fit21f,res21f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenFAR2736 & DenTR2736", pch=16)
TravelDen23<-glm(Rand_MVC~DenRW2736 + DenTR2736, family=binomial(link="logit"), data=spatialall)
summary(TravelDen23)
res23f<-resid(TravelDen23)
fit23f<-fitted(TravelDen23)
plot(fit23f,res23f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenRW2736 & DenTR2736", pch=16)
TravelDen24<-glm(Rand_MVC~DenTL2736 + DenTR2736, family=binomial(link="logit"), data=spatialall)
summary(TravelDen24)
res24f<-resid(TravelDen24)
fit24f<-fitted(TravelDen24)
plot(fit24f,res24f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenTL2736 & DenTR2736", pch=16)
TravelDen25<-glm(Rand_MVC~DenFAR5471 + DenRW5471, family=binomial(link="logit"), data=spatialall)
summary(TravelDen25)
res25f<-resid(TravelDen25)
fit25f<-fitted(TravelDen25)
plot(fit25f,res25f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenFAR5471 & DenRW5471", pch=16)
TravelDen26<-glm(Rand_MVC~DenFAR5471 + DenTL5471, family=binomial(link="logit"), data=spatialall)
summary(TravelDen26)
res26f<-resid(TravelDen26)
fit26f<-fitted(TravelDen26)
plot(fit26f,res26f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenFAR5471 & DenTL5471", pch=16)
TravelDen27<-glm(Rand_MVC~DenFAR5471 + DenTR5471, family=binomial(link="logit"), data=spatialall)
summary(TravelDen27)
res27f<-resid(TravelDen27)
fit27f<-fitted(TravelDen27)
plot(fit27f,res27f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenFAR5471 & DenTR5471", pch=16)
TravelDen28<-glm(Rand_MVC~DenRW5471 + DenTR5471, family=binomial(link="logit"), data=spatialall)
summary(TravelDen28)
res28f<-resid(TravelDen28)
fit28f<-fitted(TravelDen28)
plot(fit28f,res28f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenRW5471 & DenTR5471", pch=16)
TravelDen29<-glm(Rand_MVC~DenTL5471 + DenTR5471, family=binomial(link="logit"), data=spatialall)
summary(TravelDen29)
res29f<-resid(TravelDen29)
fit29f<-fitted(TravelDen29)
plot(fit29f,res29f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenTL5471 & DenTR5471", pch=16)
TravelDen30<-glm(Rand_MVC~DenFAR500, family=binomial(link="logit"), data=spatialall)
summary(TravelDen30)
res30f<-resid(TravelDen30)
fit30f<-fitted(TravelDen30)
plot(fit30f,res30f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenFAR500", pch=16)
TravelDen31<-glm(Rand_MVC~DenRW500, family=binomial(link="logit"), data=spatialall)
summary(TravelDen31)
res31f<-resid(TravelDen31)
fit31f<-fitted(TravelDen31)
plot(fit31f,res31f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenRW500", pch=16)
TravelDen32<-glm(Rand_MVC~DenTL500, family=binomial(link="logit"), data=spatialall)
summary(TravelDen32)
res32f<-resid(TravelDen32)
fit32f<-fitted(TravelDen32)
plot(fit32f,res32f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenTL500", pch=16)
TravelDen33<-glm(Rand_MVC~DenTR500, family=binomial(link="logit"), data=spatialall)
summary(TravelDen33)
res33f<-resid(TravelDen33)
fit33f<-fitted(TravelDen33)
plot(fit33f,res33f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenTL500", pch=16)
TravelDen34<-glm(Rand_MVC~DenFAR2736, family=binomial(link="logit"), data=spatialall)
summary(TravelDen34)
res34f<-resid(TravelDen34)
fit34f<-fitted(TravelDen34)
plot(fit34f,res34f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenFAR2736", pch=16)
TravelDen35<-glm(Rand_MVC~DenRW2736, family=binomial(link="logit"), data=spatialall)
summary(TravelDen35)
res35f<-resid(TravelDen35)
fit35f<-fitted(TravelDen35)
plot(fit35f,res35f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenRW2736", pch=16)
TravelDen36<-glm(Rand_MVC~DenTL2736, family=binomial(link="logit"), data=spatialall)
summary(TravelDen36)
res36f<-resid(TravelDen36)
fit36f<-fitted(TravelDen36)
plot(fit36f,res36f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenTL2736", pch=16)
TravelDen37<-glm(Rand_MVC~DenTR2736, family=binomial(link="logit"), data=spatialall)
summary(TravelDen37)
res37f<-resid(TravelDen37)
fit37f<-fitted(TravelDen37)
plot(fit37f,res37f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenTR2736", pch=16)
TravelDen38<-glm(Rand_MVC~DenFAR5471, family=binomial(link="logit"), data=spatialall)
summary(TravelDen38)
res38f<-resid(TravelDen38)
fit38f<-fitted(TravelDen38)
plot(fit38f,res38f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenFAR5471", pch=16)
TravelDen39<-glm(Rand_MVC~DenRW5471, family=binomial(link="logit"), data=spatialall)
summary(TravelDen39)
res39f<-resid(TravelDen39)
fit39f<-fitted(TravelDen39)
plot(fit39f,res39f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenRW5471", pch=16)
TravelDen40<-glm(Rand_MVC~DenTL5471, family=binomial(link="logit"), data=spatialall)
summary(TravelDen40)
res40f<-resid(TravelDen40)
fit40f<-fitted(TravelDen40)
plot(fit40f,res40f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenTL5471", pch=16)
TravelDen41<-glm(Rand_MVC~DenTR5471, family=binomial(link="logit"), data=spatialall)
summary(TravelDen41)
res41f<-resid(TravelDen41)
fit41f<-fitted(TravelDen41)
plot(fit41f,res41f,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n DenTR5471", pch=16)

## Used to create Table S9
library(AICcmodavg)
Cand.models <- list( )
Cand.models[[1]]<-glm(Rand_MVC~DenFAR500 + DenRW500 + DenTL500 + DenTR500, family=binomial(link="logit"), data=spatialall)
Cand.models[[2]]<-glm(Rand_MVC~DenFAR2736 + DenRW2736 + DenTL2736 + DenTR2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[3]]<-glm(Rand_MVC~DenFAR500 + DenRW500 + DenTL500, family=binomial(link="logit"), data=spatialall)
Cand.models[[4]]<-glm(Rand_MVC~DenFAR500 + DenRW500 + DenTR500, family=binomial(link="logit"), data=spatialall)
Cand.models[[5]]<-glm(Rand_MVC~DenFAR500 + DenTL500 + DenTR500, family=binomial(link="logit"), data=spatialall)
Cand.models[[6]]<-glm(Rand_MVC~DenFAR2736 + DenRW2736 + DenTL2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[7]]<-glm(Rand_MVC~DenFAR2736 + DenRW2736 + DenTR2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[8]]<-glm(Rand_MVC~DenFAR2736 + DenTL2736 + DenTR2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[9]]<-glm(Rand_MVC~DenFAR5471 + DenRW5471 + DenTR5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[10]]<-glm(Rand_MVC~DenFAR5471 + DenTL5471 + DenTR5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[11]]<-glm(Rand_MVC~DenFAR500 + DenRW500, family=binomial(link="logit"), data=spatialall)
Cand.models[[12]]<-glm(Rand_MVC~DenFAR500 + DenTL500, family=binomial(link="logit"), data=spatialall)
Cand.models[[13]]<-glm(Rand_MVC~DenFAR500 + DenTR500, family=binomial(link="logit"), data=spatialall)
Cand.models[[14]]<-glm(Rand_MVC~DenFAR2736 + DenRW2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[15]]<-glm(Rand_MVC~DenFAR2736 + DenTL2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[16]]<-glm(Rand_MVC~DenFAR2736 + DenTR2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[17]]<-glm(Rand_MVC~DenRW2736 + DenTR2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[18]]<-glm(Rand_MVC~DenTL2736 + DenTR2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[19]]<-glm(Rand_MVC~DenFAR5471 + DenRW5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[20]]<-glm(Rand_MVC~DenFAR5471 + DenTL5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[21]]<-glm(Rand_MVC~DenFAR5471 + DenTR5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[22]]<-glm(Rand_MVC~DenRW5471 + DenTR5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[23]]<-glm(Rand_MVC~DenTL5471 + DenTR5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[24]]<-glm(Rand_MVC~DenFAR500, family=binomial(link="logit"), data=spatialall)
Cand.models[[25]]<-glm(Rand_MVC~DenRW500, family=binomial(link="logit"), data=spatialall)
Cand.models[[26]]<-glm(Rand_MVC~DenTL500, family=binomial(link="logit"), data=spatialall)
Cand.models[[27]]<-glm(Rand_MVC~DenTR500, family=binomial(link="logit"), data=spatialall)
Cand.models[[28]]<-glm(Rand_MVC~DenFAR2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[29]]<-glm(Rand_MVC~DenRW2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[30]]<-glm(Rand_MVC~DenTL2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[31]]<-glm(Rand_MVC~DenTR2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[32]]<-glm(Rand_MVC~DenFAR5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[33]]<-glm(Rand_MVC~DenRW5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[34]]<-glm(Rand_MVC~DenTL5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[35]]<-glm(Rand_MVC~DenTR5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[36]]<-glm(Rand_MVC~1, family=binomial(link="logit"), data=spatialall)

##create a vector of names to trace back models in set
Modnames <- c("TravelDen1", "TravelDen2", "TravelDen3", "TravelDen4","TravelDen5", "TravelDen7", "TravelDen8", "TravelDen9", "TravelDen11", 
              "TravelDen12", "TravelDen13", "TravelDen14", "TravelDen15", "TravelDen19", "TravelDen20", "TravelDen21", "TravelDen23", "TravelDen24", 
              "TravelDen25", "TravelDen26", "TravelDen27", "TravelDen28", "TravelDen29", "TravelDen30", "TravelDen31", "TravelDen32", "TravelDen33", 
              "TravelDen34", "TravelDen35", "TravelDen36", "TravelDen37", "TravelDen38", "TravelDen39", "TravelDen40", "TravelDen41", "Null")

##generate AICc table
aictab(cand.set = Cand.models, modnames = Modnames, sort = TRUE)
##round to 4 digits after decimal point and give log-likelihood
print(aictab(cand.set = Cand.models, modnames = Modnames, sort = TRUE),
      digits = 4, LL = TRUE)

Modnames <- data.frame(Names=c("TravelDen1", "TravelDen2", "TravelDen3", "TravelDen4","TravelDen5", "TravelDen7", "TravelDen8", "TravelDen9", "TravelDen11", 
                               "TravelDen12", "TravelDen13", "TravelDen14", "TravelDen15", "TravelDen19", "TravelDen20", "TravelDen21", "TravelDen23", "TravelDen24", 
                               "TravelDen25", "TravelDen26", "TravelDen27", "TravelDen28", "TravelDen29", "TravelDen30", "TravelDen31", "TravelDen32", "TravelDen33", 
                               "TravelDen34", "TravelDen35", "TravelDen36", "TravelDen37", "TravelDen38", "TravelDen39", "TravelDen40", "TravelDen41", "Null"))

##for each model in Modnames run function NagelkerkeR2
library(fmsb)
Nag <- NULL
Nag <- rbind(Nag, data.frame(Nag=sapply(1:nrow(Modnames), function(i) {NagelkerkeR2(Cand.models[[i]])})))
Nag

##for each model in Modnames run deviance explained (null-resid)/null
library(fmsb)
Dev <- NULL
Dev <- rbind(Dev, data.frame(Dev=sapply(1:nrow(Modnames), function(i) {((Cand.models[[i]]$null.deviance-Cand.models[[i]]$deviance)/Cand.models[[i]]$null.deviance)})))
Dev

## Composition Based Models - 500 Buffer 
Comp500A3<-glm(Rand_MVC~PropDecid500 + PropConif500 + PropWater500 + PropDev500 + PropGrass500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A3)
res3g<-resid(Comp500A3)
fit3g<-fitted(Comp500A3)
plot(fit3g,res3g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid500 & PropConif500 & PropWater500 & PropDev500 & PropGrass500", pch=16)
Comp500A4<-glm(Rand_MVC~PropDecid500 + PropConif500 + PropWater500 + PropDev500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A4)
res4g<-resid(Comp500A4)
fit4g<-fitted(Comp500A4)
plot(fit4g,res4g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid500 & PropConif500 & PropWater500 & PropDev500 & PropShrub500", pch=16)
Comp500A8<-glm(Rand_MVC~PropConif500 + PropWater500 + PropDev500 + PropGrass500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A8)
res8g<-resid(Comp500A8)
fit8g<-fitted(Comp500A8)
plot(fit8g,res8g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif500 & PropWater500 & PropDev500 & PropGrass500 & PropShrub500", pch=16)
Comp500A10<-glm(Rand_MVC~PropConif500 + PropWater500 + PropDev500 + PropShrub500 + PropBare500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A10)
res10g<-resid(Comp500A10)
fit10g<-fitted(Comp500A10)
plot(fit10g,res10g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif500 + PropWater500 + PropDev500 + PropShrub500 + PropBare500", pch=16)
Comp500A13<-glm(Rand_MVC~PropWater500 + PropDev500 + PropGrass500 + PropShrub500 + PropBare500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A13)
res13g<-resid(Comp500A13)
fit13g<-fitted(Comp500A13)
plot(fit13g,res13g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater500 + PropDev500 + PropGrass500 + PropShrub500 + PropBare500", pch=16)
Comp500A16<-glm(Rand_MVC~PropDecid500 + PropConif500 + PropWater500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A16)
res16g<-resid(Comp500A16)
fit16g<-fitted(Comp500A16)
plot(fit16g,res16g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid500 + PropConif500 + PropWater500 + PropShrub500", pch=16)
Comp500A18<-glm(Rand_MVC~PropDecid500 + PropConif500 + PropDev500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A18)
res18g<-resid(Comp500A18)
fit18g<-fitted(Comp500A18)
plot(fit18g,res18g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid500 + PropConif500 + PropDev500 + PropShrub500", pch=16)
Comp500A21<-glm(Rand_MVC~PropDecid500 + PropWater500 + PropDev500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A21)
res21g<-resid(Comp500A21)
fit21g<-fitted(Comp500A21)
plot(fit21g,res21g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid500 + PropWater500 + PropDev500 + PropShrub500", pch=16)
Comp500A24<-glm(Rand_MVC~PropConif500 + PropWater500 + PropDev500 + PropGrass500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A24)
res24g<-resid(Comp500A24)
fit24g<-fitted(Comp500A24)
plot(fit24g,res24g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif500 + PropWater500 + PropDev500 + PropGrass500", pch=16)
Comp500A25<-glm(Rand_MVC~PropConif500 + PropWater500 + PropDev500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A25)
res25g<-resid(Comp500A25)
fit25g<-fitted(Comp500A25)
plot(fit25g,res25g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif500 + PropWater500 + PropDev500 + PropShrub500", pch=16)
Comp500A26<-glm(Rand_MVC~PropConif500 + PropWater500 + PropDev500 + PropBare500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A26)
res26g<-resid(Comp500A26)
fit26g<-fitted(Comp500A26)
plot(fit26g,res26g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif500 + PropWater500 + PropDev500 + PropBare500", pch=16)
Comp500A27<-glm(Rand_MVC~PropConif500 + PropWater500 + PropGrass500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A27)
res27g<-resid(Comp500A27)
fit27g<-fitted(Comp500A27)
plot(fit27g,res27g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif500 + PropWater500 + PropGrass500 + PropShrub500", pch=16)
Comp500A29<-glm(Rand_MVC~PropConif500 + PropWater500 + PropShrub500 + PropBare500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A29)
res29g<-resid(Comp500A29)
fit29g<-fitted(Comp500A29)
plot(fit29g,res29g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif500 + PropWater500 + PropShrub500 + PropBare500", pch=16)
Comp500A30<-glm(Rand_MVC~PropConif500 + PropDev500 + PropGrass500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A30)
res30g<-resid(Comp500A30)
fit30g<-fitted(Comp500A30)
plot(fit30g,res30g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif500 + PropDev500 + PropGrass500 + PropShrub500", pch=16)
Comp500A32<-glm(Rand_MVC~PropConif500 + PropDev500 + PropShrub500 + PropBare500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A32)
res32g<-resid(Comp500A32)
fit32g<-fitted(Comp500A32)
plot(fit32g,res32g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif500 + PropDev500 + PropShrub500 + PropBare500", pch=16)
Comp500A34<-glm(Rand_MVC~PropWater500 + PropDev500 + PropGrass500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A34)
res34g<-resid(Comp500A34)
fit34g<-fitted(Comp500A34)
plot(fit34g,res34g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater500 + PropDev500 + PropGrass500 + PropShrub500", pch=16)
Comp500A36<-glm(Rand_MVC~PropWater500 + PropDev500 + PropShrub500 + PropBare500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A36)
res36g<-resid(Comp500A36)
fit36g<-fitted(Comp500A36)
plot(fit36g,res36g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater500 + PropDev500 + PropShrub500 + PropBare500", pch=16)
Comp500A37<-glm(Rand_MVC~PropWater500 + PropGrass500 + PropShrub500 + PropBare500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A37)
res37g<-resid(Comp500A37)
fit37g<-fitted(Comp500A37)
plot(fit37g,res37g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater500 + PropGrass500 + PropShrub500 + PropBare500", pch=16)
Comp500A38<-glm(Rand_MVC~PropDev500 + PropGrass500 + PropShrub500 + PropBare500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A38)
res38g<-resid(Comp500A38)
fit38g<-fitted(Comp500A38)
plot(fit38g,res38g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDev500 + PropGrass500 + PropShrub500 + PropBare500", pch=16)
Comp500A39<-glm(Rand_MVC~PropDecid500 + PropConif500 + PropWater500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A39)
res39g<-resid(Comp500A39)
fit39g<-fitted(Comp500A39)
plot(fit39g,res39g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid500 + PropConif500 + PropWater500", pch=16)
Comp500A40<-glm(Rand_MVC~PropDecid500 + PropConif500 + PropDev500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A40)
res40g<-resid(Comp500A40)
fit40g<-fitted(Comp500A40)
plot(fit40g,res40g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid500 + PropConif500 + PropDev500", pch=16)
Comp500A42<-glm(Rand_MVC~PropDecid500 + PropConif500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A42)
res42g<-resid(Comp500A42)
fit42g<-fitted(Comp500A42)
plot(fit42g,res42g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid500 + PropConif500 + PropShrub500", pch=16)
Comp500A43<-glm(Rand_MVC~PropDecid500 + PropWater500 + PropDev500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A43)
res43g<-resid(Comp500A43)
fit43g<-fitted(Comp500A43)
plot(fit43g,res43g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid500 + PropWater500 + PropDev500", pch=16)
Comp500A45<-glm(Rand_MVC~PropDecid500 + PropWater500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A45)
res45g<-resid(Comp500A45)
fit45g<-fitted(Comp500A45)
plot(fit45g,res45g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid500 + PropWater500 + PropShrub500", pch=16)
Comp500A46<-glm(Rand_MVC~PropDecid500 + PropDev500 + PropGrass500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A46)
res46g<-resid(Comp500A46)
fit46g<-fitted(Comp500A46)
plot(fit46g,res46g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid500 + PropDev500 + PropGrass500", pch=16)
Comp500A47<-glm(Rand_MVC~PropDecid500 + PropDev500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A47)
res47g<-resid(Comp500A47)
fit47g<-fitted(Comp500A47)
plot(fit47g,res47g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid500 + PropDev500 + PropShrub500", pch=16)
Comp500A48<-glm(Rand_MVC~PropDecid500 + PropGrass500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A48)
res48g<-resid(Comp500A48)
fit48g<-fitted(Comp500A48)
plot(fit48g,res48g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid500 + PropGrass500 + PropShrub500", pch=16)
Comp500A49<-glm(Rand_MVC~PropConif500 + PropWater500 + PropDev500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A49)
res49g<-resid(Comp500A49)
fit49g<-fitted(Comp500A49)
plot(fit49g,res49g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif500 + PropWater500 + PropDev500", pch=16)
Comp500A50<-glm(Rand_MVC~PropConif500 + PropWater500 + PropGrass500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A50)
res50g<-resid(Comp500A50)
fit50g<-fitted(Comp500A50)
plot(fit50g,res50g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif500 + PropWater500 + PropGrass500", pch=16)
Comp500A51<-glm(Rand_MVC~PropConif500 + PropWater500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A51)
res51g<-resid(Comp500A51)
fit51g<-fitted(Comp500A51)
plot(fit51g,res51g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif500 + PropWater500 + PropShrub500", pch=16)
Comp500A52<-glm(Rand_MVC~PropConif500 + PropWater500 + PropBare500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A52)
res52g<-resid(Comp500A52)
fit52g<-fitted(Comp500A52)
plot(fit52g,res52g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif500 + PropWater500 + PropBare500", pch=16)
Comp500A53<-glm(Rand_MVC~PropConif500 + PropDev500 + PropGrass500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A53)
res53g<-resid(Comp500A53)
fit53g<-fitted(Comp500A53)
plot(fit53g,res53g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif500 + PropDev500 + PropGrass500", pch=16)
Comp500A54<-glm(Rand_MVC~PropConif500 + PropDev500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A54)
res54g<-resid(Comp500A54)
fit54g<-fitted(Comp500A54)
plot(fit54g,res54g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif500 + PropDev500 + PropShrub500", pch=16)
Comp500A55<-glm(Rand_MVC~PropConif500 + PropDev500 + PropBare500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A55)
res55g<-resid(Comp500A55)
fit55g<-fitted(Comp500A55)
plot(fit55g,res55g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif500 + PropDev500 + PropBare500", pch=16)
Comp500A56<-glm(Rand_MVC~PropConif500 + PropGrass500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A56)
res56g<-resid(Comp500A56)
fit56g<-fitted(Comp500A56)
plot(fit56g,res56g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif500 + PropGrass500 + PropShrub500", pch=16)
Comp500A58<-glm(Rand_MVC~PropConif500 + PropShrub500 + PropBare500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A58)
res58g<-resid(Comp500A58)
fit58g<-fitted(Comp500A58)
plot(fit58g,res58g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif500 + PropShrub500 + PropBare500", pch=16)
Comp500A59<-glm(Rand_MVC~PropWater500 + PropDev500 + PropGrass500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A59)
res59g<-resid(Comp500A59)
fit59g<-fitted(Comp500A59)
plot(fit59g,res59g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater500 + PropDev500 + PropGrass500", pch=16)
Comp500A60<-glm(Rand_MVC~PropWater500 + PropDev500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A60)
res60g<-resid(Comp500A60)
fit60g<-fitted(Comp500A60)
plot(fit60g,res60g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater500 + PropDev500 + PropShrub500", pch=16)
Comp500A61<-glm(Rand_MVC~PropWater500 + PropDev500 + PropBare500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A61)
res61g<-resid(Comp500A61)
fit61g<-fitted(Comp500A61)
plot(fit61g,res61g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater500 + PropDev500 + PropBare500", pch=16)
Comp500A62<-glm(Rand_MVC~PropWater500 + PropGrass500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A62)
res62g<-resid(Comp500A62)
fit62g<-fitted(Comp500A62)
plot(fit62g,res62g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater500 + PropGrass500 + PropShrub500", pch=16)
Comp500A64<-glm(Rand_MVC~PropWater500 + PropShrub500 + PropBare500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A64)
res64g<-resid(Comp500A64)
fit64g<-fitted(Comp500A64)
plot(fit64g,res64g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater500 + PropShrub500 + PropBare500", pch=16)
Comp500A65<-glm(Rand_MVC~PropDev500 + PropGrass500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A65)
res65g<-resid(Comp500A65)
fit65g<-fitted(Comp500A65)
plot(fit65g,res65g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDev500 + PropGrass500 + PropShrub500", pch=16)
Comp500A66<-glm(Rand_MVC~PropDev500 + PropGrass500 + PropBare500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A66)
res66g<-resid(Comp500A66)
fit66g<-fitted(Comp500A66)
plot(fit66g,res66g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDev500 + PropGrass500 + PropBare500", pch=16)
Comp500A67<-glm(Rand_MVC~PropDev500 + PropShrub500 + PropBare500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A67)
res67g<-resid(Comp500A67)
fit67g<-fitted(Comp500A67)
plot(fit67g,res67g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDev500 + PropShrub500 + PropBare500", pch=16)
Comp500A68<-glm(Rand_MVC~PropGrass500 + PropShrub500 + PropBare500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A68)
res68g<-resid(Comp500A68)
fit68g<-fitted(Comp500A68)
plot(fit68g,res68g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropGrass500 + PropShrub500 + PropBare500", pch=16)
Comp500A69<-glm(Rand_MVC~PropDecid500 + PropConif500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A69)
res69g<-resid(Comp500A69)
fit69g<-fitted(Comp500A69)
plot(fit69g,res69g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid500 + PropConif500", pch=16)
Comp500A70<-glm(Rand_MVC~PropDecid500 + PropWater500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A70)
res70g<-resid(Comp500A70)
fit70g<-fitted(Comp500A70)
plot(fit70g,res70g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid500 + PropWater500", pch=16)
Comp500A71<-glm(Rand_MVC~PropDecid500 + PropDev500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A71)
res71g<-resid(Comp500A71)
fit71g<-fitted(Comp500A71)
plot(fit71g,res71g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid500 + PropDev500", pch=16)
Comp500A73<-glm(Rand_MVC~PropDecid500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A73)
res73g<-resid(Comp500A73)
fit73g<-fitted(Comp500A73)
plot(fit73g,res73g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid500 + PropShrub500", pch=16)
Comp500A74<-glm(Rand_MVC~PropConif500 + PropWater500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A74)
res74g<-resid(Comp500A74)
fit74g<-fitted(Comp500A74)
plot(fit74g,res74g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif500 + PropWater500", pch=16)
Comp500A75<-glm(Rand_MVC~PropConif500 + PropDev500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A75)
res75g<-resid(Comp500A75)
fit75g<-fitted(Comp500A75)
plot(fit75g,res75g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif500 + PropDev500", pch=16)
Comp500A76<-glm(Rand_MVC~PropConif500 + PropGrass500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A76)
res76g<-resid(Comp500A76)
fit76g<-fitted(Comp500A76)
plot(fit76g,res76g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif500 + PropGrass500", pch=16)
Comp500A77<-glm(Rand_MVC~PropConif500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A77)
res77g<-resid(Comp500A77)
fit77g<-fitted(Comp500A77)
plot(fit77g,res77g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif500 + PropShrub500", pch=16)
Comp500A78<-glm(Rand_MVC~PropConif500 + PropBare500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A78)
res78g<-resid(Comp500A78)
fit78g<-fitted(Comp500A78)
plot(fit78g,res78g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif500 + PropBare500", pch=16)
Comp500A79<-glm(Rand_MVC~PropWater500 + PropDev500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A79)
res79g<-resid(Comp500A79)
fit79g<-fitted(Comp500A79)
plot(fit79g,res79g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater500 + PropDev500", pch=16)
Comp500A80<-glm(Rand_MVC~PropWater500 + PropGrass500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A80)
res80g<-resid(Comp500A80)
fit80g<-fitted(Comp500A80)
plot(fit80g,res80g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater500 + PropGrass500", pch=16)
Comp500A81<-glm(Rand_MVC~PropWater500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A81)
res81g<-resid(Comp500A81)
fit81g<-fitted(Comp500A81)
plot(fit81g,res81g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater500 + PropShrub500", pch=16)
Comp500A82<-glm(Rand_MVC~PropWater500 + PropBare500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A82)
res82g<-resid(Comp500A82)
fit82g<-fitted(Comp500A82)
plot(fit82g,res82g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater500 + PropBare500", pch=16)
Comp500A83<-glm(Rand_MVC~PropDev500 + PropGrass500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A83)
res83g<-resid(Comp500A83)
fit83g<-fitted(Comp500A83)
plot(fit83g,res83g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDev500 + PropGrass500", pch=16)
Comp500A84<-glm(Rand_MVC~PropDev500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A84)
res84g<-resid(Comp500A84)
fit84g<-fitted(Comp500A84)
plot(fit84g,res84g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDev500 + PropShrub500", pch=16)
Comp500A85<-glm(Rand_MVC~PropDev500 + PropBare500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A85)
res85g<-resid(Comp500A85)
fit85g<-fitted(Comp500A85)
plot(fit85g,res85g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDev500 + PropBare500", pch=16)
Comp500A86<-glm(Rand_MVC~PropGrass500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A86)
res86g<-resid(Comp500A86)
fit86g<-fitted(Comp500A86)
plot(fit86g,res86g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropGrass500 + PropShrub500", pch=16)
Comp500A87<-glm(Rand_MVC~PropGrass500 + PropBare500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A87)
res87g<-resid(Comp500A87)
fit87g<-fitted(Comp500A87)
plot(fit87g,res87g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropGrass500 + PropBare500", pch=16)
Comp500A88<-glm(Rand_MVC~PropShrub500 + PropBare500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A88)
res88g<-resid(Comp500A88)
fit88g<-fitted(Comp500A88)
plot(fit88g,res88g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropShrub500 + PropBare500", pch=16)
Comp500A89<-glm(Rand_MVC~PropDecid500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A89)
res89g<-resid(Comp500A89)
fit89g<-fitted(Comp500A89)
plot(fit89g,res89g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid500", pch=16)
Comp500A90<-glm(Rand_MVC~PropConif500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A90)
res90g<-resid(Comp500A90)
fit90g<-fitted(Comp500A90)
plot(fit90g,res90g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif500", pch=16)
Comp500A91<-glm(Rand_MVC~PropWater500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A91)
res91g<-resid(Comp500A91)
fit91g<-fitted(Comp500A91)
plot(fit91g,res91g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater500", pch=16)
Comp500A92<-glm(Rand_MVC~PropDev500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A92)
res92g<-resid(Comp500A92)
fit92g<-fitted(Comp500A92)
plot(fit92g,res92g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDev500", pch=16)
Comp500A93<-glm(Rand_MVC~PropGrass500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A93)
res93g<-resid(Comp500A93)
fit93g<-fitted(Comp500A93)
plot(fit93g,res93g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropGrass500", pch=16)
Comp500A94<-glm(Rand_MVC~PropShrub500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A94)
res94g<-resid(Comp500A94)
fit94g<-fitted(Comp500A94)
plot(fit94g,res94g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropShrub500", pch=16)
Comp500A95<-glm(Rand_MVC~PropBare500, family=binomial(link="logit"), data=spatialall)
summary(Comp500A95)
res95g<-resid(Comp500A95)
fit95g<-fitted(Comp500A95)
plot(fit95g,res95g,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropBare500", pch=16)

## Used to create Table S5
library(AICcmodavg)
Cand.models <- list( )
Cand.models[[1]]<-glm(Rand_MVC~PropDecid500 + PropConif500 + PropWater500 + PropDev500 + PropGrass500, family=binomial(link="logit"), data=spatialall)
Cand.models[[2]]<-glm(Rand_MVC~PropDecid500 + PropConif500 + PropWater500 + PropDev500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
Cand.models[[3]]<-glm(Rand_MVC~PropConif500 + PropWater500 + PropDev500 + PropGrass500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
Cand.models[[4]]<-glm(Rand_MVC~PropConif500 + PropWater500 + PropDev500 + PropShrub500 + PropBare500, family=binomial(link="logit"), data=spatialall)
Cand.models[[5]]<-glm(Rand_MVC~PropWater500 + PropDev500 + PropGrass500 + PropShrub500 + PropBare500, family=binomial(link="logit"), data=spatialall)
Cand.models[[6]]<-glm(Rand_MVC~PropDecid500 + PropConif500 + PropWater500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
Cand.models[[7]]<-glm(Rand_MVC~PropDecid500 + PropConif500 + PropDev500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
Cand.models[[8]]<-glm(Rand_MVC~PropDecid500 + PropWater500 + PropDev500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
Cand.models[[9]]<-glm(Rand_MVC~PropConif500 + PropWater500 + PropDev500 + PropGrass500, family=binomial(link="logit"), data=spatialall)
Cand.models[[10]]<-glm(Rand_MVC~PropConif500 + PropWater500 + PropDev500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
Cand.models[[11]]<-glm(Rand_MVC~PropConif500 + PropWater500 + PropDev500 + PropBare500, family=binomial(link="logit"), data=spatialall)
Cand.models[[12]]<-glm(Rand_MVC~PropConif500 + PropWater500 + PropGrass500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
Cand.models[[13]]<-glm(Rand_MVC~PropConif500 + PropWater500 + PropShrub500 + PropBare500, family=binomial(link="logit"), data=spatialall)
Cand.models[[14]]<-glm(Rand_MVC~PropConif500 + PropDev500 + PropGrass500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
Cand.models[[15]]<-glm(Rand_MVC~PropConif500 + PropDev500 + PropShrub500 + PropBare500, family=binomial(link="logit"), data=spatialall)
Cand.models[[16]]<-glm(Rand_MVC~PropWater500 + PropDev500 + PropGrass500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
Cand.models[[17]]<-glm(Rand_MVC~PropWater500 + PropDev500 + PropShrub500 + PropBare500, family=binomial(link="logit"), data=spatialall)
Cand.models[[18]]<-glm(Rand_MVC~PropWater500 + PropGrass500 + PropShrub500 + PropBare500, family=binomial(link="logit"), data=spatialall)
Cand.models[[19]]<-glm(Rand_MVC~PropDev500 + PropGrass500 + PropShrub500 + PropBare500, family=binomial(link="logit"), data=spatialall)
Cand.models[[20]]<-glm(Rand_MVC~PropDecid500 + PropConif500 + PropWater500, family=binomial(link="logit"), data=spatialall)
Cand.models[[21]]<-glm(Rand_MVC~PropDecid500 + PropConif500 + PropDev500, family=binomial(link="logit"), data=spatialall)
Cand.models[[22]]<-glm(Rand_MVC~PropDecid500 + PropConif500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
Cand.models[[23]]<-glm(Rand_MVC~PropDecid500 + PropWater500 + PropDev500, family=binomial(link="logit"), data=spatialall)
Cand.models[[24]]<-glm(Rand_MVC~PropDecid500 + PropWater500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
Cand.models[[25]]<-glm(Rand_MVC~PropDecid500 + PropDev500 + PropGrass500, family=binomial(link="logit"), data=spatialall)
Cand.models[[26]]<-glm(Rand_MVC~PropDecid500 + PropDev500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
Cand.models[[27]]<-glm(Rand_MVC~PropDecid500 + PropGrass500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
Cand.models[[28]]<-glm(Rand_MVC~PropConif500 + PropWater500 + PropDev500, family=binomial(link="logit"), data=spatialall)
Cand.models[[29]]<-glm(Rand_MVC~PropConif500 + PropWater500 + PropGrass500, family=binomial(link="logit"), data=spatialall)
Cand.models[[30]]<-glm(Rand_MVC~PropConif500 + PropWater500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
Cand.models[[31]]<-glm(Rand_MVC~PropConif500 + PropWater500 + PropBare500, family=binomial(link="logit"), data=spatialall)
Cand.models[[32]]<-glm(Rand_MVC~PropConif500 + PropDev500 + PropGrass500, family=binomial(link="logit"), data=spatialall)
Cand.models[[33]]<-glm(Rand_MVC~PropConif500 + PropDev500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
Cand.models[[34]]<-glm(Rand_MVC~PropConif500 + PropDev500 + PropBare500, family=binomial(link="logit"), data=spatialall)
Cand.models[[35]]<-glm(Rand_MVC~PropConif500 + PropGrass500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
Cand.models[[36]]<-glm(Rand_MVC~PropConif500 + PropShrub500 + PropBare500, family=binomial(link="logit"), data=spatialall)
Cand.models[[37]]<-glm(Rand_MVC~PropWater500 + PropDev500 + PropGrass500, family=binomial(link="logit"), data=spatialall)
Cand.models[[38]]<-glm(Rand_MVC~PropWater500 + PropDev500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
Cand.models[[39]]<-glm(Rand_MVC~PropWater500 + PropDev500 + PropBare500, family=binomial(link="logit"), data=spatialall)
Cand.models[[40]]<-glm(Rand_MVC~PropWater500 + PropGrass500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
Cand.models[[41]]<-glm(Rand_MVC~PropWater500 + PropShrub500 + PropBare500, family=binomial(link="logit"), data=spatialall)
Cand.models[[42]]<-glm(Rand_MVC~PropDev500 + PropGrass500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
Cand.models[[43]]<-glm(Rand_MVC~PropDev500 + PropGrass500 + PropBare500, family=binomial(link="logit"), data=spatialall)
Cand.models[[44]]<-glm(Rand_MVC~PropDev500 + PropShrub500 + PropBare500, family=binomial(link="logit"), data=spatialall)
Cand.models[[45]]<-glm(Rand_MVC~PropGrass500 + PropShrub500 + PropBare500, family=binomial(link="logit"), data=spatialall)
Cand.models[[46]]<-glm(Rand_MVC~PropDecid500 + PropConif500, family=binomial(link="logit"), data=spatialall)
Cand.models[[47]]<-glm(Rand_MVC~PropDecid500 + PropWater500, family=binomial(link="logit"), data=spatialall)
Cand.models[[48]]<-glm(Rand_MVC~PropDecid500 + PropDev500, family=binomial(link="logit"), data=spatialall)
Cand.models[[49]]<-glm(Rand_MVC~PropDecid500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
Cand.models[[50]]<-glm(Rand_MVC~PropConif500 + PropWater500, family=binomial(link="logit"), data=spatialall)
Cand.models[[51]]<-glm(Rand_MVC~PropConif500 + PropDev500, family=binomial(link="logit"), data=spatialall)
Cand.models[[52]]<-glm(Rand_MVC~PropConif500 + PropGrass500, family=binomial(link="logit"), data=spatialall)
Cand.models[[53]]<-glm(Rand_MVC~PropConif500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
Cand.models[[54]]<-glm(Rand_MVC~PropConif500 + PropBare500, family=binomial(link="logit"), data=spatialall)
Cand.models[[55]]<-glm(Rand_MVC~PropWater500 + PropDev500, family=binomial(link="logit"), data=spatialall)
Cand.models[[56]]<-glm(Rand_MVC~PropWater500 + PropGrass500, family=binomial(link="logit"), data=spatialall)
Cand.models[[57]]<-glm(Rand_MVC~PropWater500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
Cand.models[[58]]<-glm(Rand_MVC~PropWater500 + PropBare500, family=binomial(link="logit"), data=spatialall)
Cand.models[[59]]<-glm(Rand_MVC~PropDev500 + PropGrass500, family=binomial(link="logit"), data=spatialall)
Cand.models[[60]]<-glm(Rand_MVC~PropDev500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
Cand.models[[61]]<-glm(Rand_MVC~PropDev500 + PropBare500, family=binomial(link="logit"), data=spatialall)
Cand.models[[62]]<-glm(Rand_MVC~PropGrass500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
Cand.models[[63]]<-glm(Rand_MVC~PropGrass500 + PropBare500, family=binomial(link="logit"), data=spatialall)
Cand.models[[64]]<-glm(Rand_MVC~PropShrub500 + PropBare500, family=binomial(link="logit"), data=spatialall)
Cand.models[[65]]<-glm(Rand_MVC~PropDecid500, family=binomial(link="logit"), data=spatialall)
Cand.models[[66]]<-glm(Rand_MVC~PropConif500, family=binomial(link="logit"), data=spatialall)
Cand.models[[67]]<-glm(Rand_MVC~PropWater500, family=binomial(link="logit"), data=spatialall)
Cand.models[[68]]<-glm(Rand_MVC~PropDev500, family=binomial(link="logit"), data=spatialall)
Cand.models[[69]]<-glm(Rand_MVC~PropGrass500, family=binomial(link="logit"), data=spatialall)
Cand.models[[70]]<-glm(Rand_MVC~PropShrub500, family=binomial(link="logit"), data=spatialall)
Cand.models[[71]]<-glm(Rand_MVC~PropBare500, family=binomial(link="logit"), data=spatialall)
Cand.models[[72]]<-glm(Rand_MVC~1, family=binomial(link="logit"), data=spatialall)

##create a vector of names to trace back models in set
Modnames <- c("Comp500A3", "Comp500A4", "Comp500A8", "Comp500A10", "Comp500A13", "Comp500A16", "Comp500A18", "Comp500A21",  
              "Comp500A24", "Comp500A25", "Comp500A26", "Comp500A27", "Comp500A29", "Comp500A30", "Comp500A32", "Comp500A34", 
              "Comp500A36", "Comp500A37", "Comp500A38", "Comp500A39", "Comp500A40", "Comp500A42", "Comp500A43", "Comp500A45", 
              "Comp500A46", "Comp500A47", "Comp500A48", "Comp500A49","Comp500A50", "Comp500A51", "Comp500A52", "Comp500A53", 
              "Comp500A54", "Comp500A55", "Comp500A56", "Comp500A58", "Comp500A59", "Comp500A60", "Comp500A61", "Comp500A62", 
              "Comp500A64", "Comp500A65", "Comp500A66", "Comp500A67", "Comp500A68", "Comp500A69", "Comp500A70", "Comp500A71",  
              "Comp500A73", "Comp500A74", "Comp500A75", "Comp500A76", "Comp500A77", "Comp500A78", "Comp500A79", "Comp500A80", 
              "Comp500A81", "Comp500A82", "Comp500A83", "Comp500A84", "Comp500A85", "Comp500A86", "Comp500A87", "Comp500A88", 
              "Comp500A89", "Comp500A90", "Comp500A91", "Comp500A92", "Comp500A93", "Comp500A94", "Comp500A95", "Null")

##generate AICc table
aictab(cand.set = Cand.models, modnames = Modnames, sort = TRUE)
##round to 4 digits after decimal point and give log-likelihood
print(aictab(cand.set = Cand.models, modnames = Modnames, sort = TRUE),
      digits = 4, LL = TRUE)

Modnames <- data.frame(Names=c("Comp500A3", "Comp500A4", "Comp500A8", "Comp500A10", "Comp500A13", "Comp500A16", "Comp500A18", "Comp500A21",  
                               "Comp500A24", "Comp500A25", "Comp500A26", "Comp500A27", "Comp500A29", "Comp500A30", "Comp500A32", "Comp500A34", 
                               "Comp500A36", "Comp500A37", "Comp500A38", "Comp500A39", "Comp500A40", "Comp500A42", "Comp500A43", "Comp500A45", 
                               "Comp500A46", "Comp500A47", "Comp500A48", "Comp500A49","Comp500A50", "Comp500A51", "Comp500A52", "Comp500A53", 
                               "Comp500A54", "Comp500A55", "Comp500A56", "Comp500A58", "Comp500A59", "Comp500A60", "Comp500A61", "Comp500A62", 
                               "Comp500A64", "Comp500A65", "Comp500A66", "Comp500A67", "Comp500A68", "Comp500A69", "Comp500A70", "Comp500A71",  
                               "Comp500A73", "Comp500A74", "Comp500A75", "Comp500A76", "Comp500A77", "Comp500A78", "Comp500A79", "Comp500A80", 
                               "Comp500A81", "Comp500A82", "Comp500A83", "Comp500A84", "Comp500A85", "Comp500A86", "Comp500A87", "Comp500A88", 
                               "Comp500A89", "Comp500A90", "Comp500A91", "Comp500A92", "Comp500A93", "Comp500A94", "Comp500A95", "Null"))

##for each model in Modnames run function NagelkerkeR2
library(fmsb)
Nag <- NULL
Nag <- rbind(Nag, data.frame(Nag=sapply(1:nrow(Modnames), function(i) {NagelkerkeR2(Cand.models[[i]])})))
Nag

##for each model in Modnames run deviance explained (null-resid)/null
library(fmsb)
Dev <- NULL
Dev <- rbind(Dev, data.frame(Dev=sapply(1:nrow(Modnames), function(i) {((Cand.models[[i]]$null.deviance-Cand.models[[i]]$deviance)/Cand.models[[i]]$null.deviance)})))
Dev

## Composition Based Models - 2736 Buffer 
Comp2736A3<-glm(Rand_MVC~PropDecid2736 + PropConif2736 + PropWater2736 + PropDev2736 + PropGrass2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A3)
res3h<-resid(Comp2736A3)
fit3h<-fitted(Comp2736A3)
plot(fit3h,res3h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid2736 & PropConif2736 & PropWater2736 & PropDev2736 & PropGrass2736", pch=16)
Comp2736A17<-glm(Rand_MVC~PropDecid2736 + PropConif2736 + PropDev2736 + PropGrass2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A17)
res17h<-resid(Comp2736A17)
fit17h<-fitted(Comp2736A17)
plot(fit17h,res17h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid2736 + PropConif2736 + PropDev2736 + PropGrass2736", pch=16)
Comp2736A30<-glm(Rand_MVC~PropConif2736 + PropDev2736 + PropGrass2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A30)
res30h<-resid(Comp2736A30)
fit30h<-fitted(Comp2736A30)
plot(fit30h,res30h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif2736 + PropDev2736 + PropGrass2736 + PropShrub2736", pch=16)
Comp2736A34<-glm(Rand_MVC~PropWater2736 + PropDev2736 + PropGrass2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A34)
res34h<-resid(Comp2736A34)
fit34h<-fitted(Comp2736A34)
plot(fit34h,res34h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater2736 + PropDev2736 + PropGrass2736 + PropShrub2736", pch=16)
Comp2736A35<-glm(Rand_MVC~PropWater2736 + PropDev2736 + PropGrass2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A35)
res35h<-resid(Comp2736A35)
fit35h<-fitted(Comp2736A35)
plot(fit35h,res35h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater2736 + PropDev2736 + PropGrass2736 + PropBare2736", pch=16)
Comp2736A38<-glm(Rand_MVC~PropDev2736 + PropGrass2736 + PropShrub2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A38)
res38h<-resid(Comp2736A38)
fit38h<-fitted(Comp2736A38)
plot(fit38h,res38h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDev2736 + PropGrass2736 + PropShrub2736 + PropBare2736", pch=16)
Comp2736A47<-glm(Rand_MVC~PropDecid2736 + PropDev2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A47)
res47h<-resid(Comp2736A47)
fit47h<-fitted(Comp2736A47)
plot(fit47h,res47h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid2736 + PropDev2736 + PropShrub2736", pch=16)
Comp2736A48<-glm(Rand_MVC~PropDecid2736 + PropGrass2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A48)
res48h<-resid(Comp2736A48)
fit48h<-fitted(Comp2736A48)
plot(fit48h,res48h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid2736 + PropGrass2736 + PropShrub2736", pch=16)
Comp2736A53<-glm(Rand_MVC~PropConif2736 + PropDev2736 + PropGrass2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A53)
res53h<-resid(Comp2736A53)
fit53h<-fitted(Comp2736A53)
plot(fit53h,res53h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif2736 + PropDev2736 + PropGrass2736", pch=16)
Comp2736A55<-glm(Rand_MVC~PropConif2736 + PropDev2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A55)
res55h<-resid(Comp2736A55)
fit55h<-fitted(Comp2736A55)
plot(fit55h,res55h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif2736 + PropDev2736 + PropBare2736", pch=16)
Comp2736A56<-glm(Rand_MVC~PropConif2736 + PropGrass2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A56)
res56h<-resid(Comp2736A56)
fit56h<-fitted(Comp2736A56)
plot(fit56h,res56h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif2736 + PropGrass2736 + PropShrub2736", pch=16)
Comp2736A59<-glm(Rand_MVC~PropWater2736 + PropDev2736 + PropGrass2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A59)
res59h<-resid(Comp2736A59)
fit59h<-fitted(Comp2736A59)
plot(fit59h,res59h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater2736 + PropDev2736 + PropGrass2736", pch=16)
Comp2736A63<-glm(Rand_MVC~PropWater2736 + PropGrass2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A63)
res63h<-resid(Comp2736A63)
fit63h<-fitted(Comp2736A63)
plot(fit63h,res63h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater2736 + PropGrass2736 + PropBare2736", pch=16)
Comp2736A65<-glm(Rand_MVC~PropDev2736 + PropGrass2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A65)
res65h<-resid(Comp2736A65)
fit65h<-fitted(Comp2736A65)
plot(fit65h,res65h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDev2736 + PropGrass2736 + PropShrub2736", pch=16)
Comp2736A66<-glm(Rand_MVC~PropDev2736 + PropGrass2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A66)
res66h<-resid(Comp2736A66)
fit66h<-fitted(Comp2736A66)
plot(fit66h,res66h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDev2736 + PropGrass2736 + PropBare2736", pch=16)
Comp2736A67<-glm(Rand_MVC~PropDev2736 + PropShrub2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A67)
res67h<-resid(Comp2736A67)
fit67h<-fitted(Comp2736A67)
plot(fit67h,res67h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDev2736 + PropShrub2736 + PropBare2736", pch=16)
Comp2736A69<-glm(Rand_MVC~PropDecid2736 + PropConif2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A69)
res69h<-resid(Comp2736A69)
fit69h<-fitted(Comp2736A69)
plot(fit69h,res69h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid2736 + PropConif2736", pch=16)
Comp2736A73<-glm(Rand_MVC~PropDecid2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A73)
res73h<-resid(Comp2736A73)
fit73h<-fitted(Comp2736A73)
plot(fit73h,res73h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid2736 + PropShrub2736", pch=16)
Comp2736A75<-glm(Rand_MVC~PropConif2736 + PropDev2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A75)
res75h<-resid(Comp2736A75)
fit75h<-fitted(Comp2736A75)
plot(fit75h,res75h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif2736 + PropDev2736", pch=16)
Comp2736A76<-glm(Rand_MVC~PropConif2736 + PropGrass2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A76)
res76h<-resid(Comp2736A76)
fit76h<-fitted(Comp2736A76)
plot(fit76h,res76h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif2736 + PropGrass2736", pch=16)
Comp2736A78<-glm(Rand_MVC~PropConif2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A78)
res78h<-resid(Comp2736A78)
fit78h<-fitted(Comp2736A78)
plot(fit78h,res78h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif2736 + PropBare2736", pch=16)
Comp2736A79<-glm(Rand_MVC~PropWater2736 + PropDev2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A79)
res79h<-resid(Comp2736A79)
fit79h<-fitted(Comp2736A79)
plot(fit79h,res79h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater2736 + PropDev2736", pch=16)
Comp2736A80<-glm(Rand_MVC~PropWater2736 + PropGrass2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A80)
res80h<-resid(Comp2736A80)
fit80h<-fitted(Comp2736A80)
plot(fit80h,res80h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater2736 + PropGrass2736", pch=16)
Comp2736A83<-glm(Rand_MVC~PropDev2736 + PropGrass2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A83)
res83h<-resid(Comp2736A83)
fit83h<-fitted(Comp2736A83)
plot(fit83h,res83h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDev2736 + PropGrass2736", pch=16)
Comp2736A84<-glm(Rand_MVC~PropDev2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A84)
res84h<-resid(Comp2736A84)
fit84h<-fitted(Comp2736A84)
plot(fit84h,res84h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDev2736 + PropShrub2736", pch=16)
Comp2736A85<-glm(Rand_MVC~PropDev2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A85)
res85h<-resid(Comp2736A85)
fit85h<-fitted(Comp2736A85)
plot(fit85h,res85h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDev2736 + PropBare2736", pch=16)
Comp2736A86<-glm(Rand_MVC~PropGrass2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A86)
res86h<-resid(Comp2736A86)
fit86h<-fitted(Comp2736A86)
plot(fit86h,res86h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropGrass2736 + PropShrub2736", pch=16)
Comp2736A87<-glm(Rand_MVC~PropGrass2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A87)
res87h<-resid(Comp2736A87)
fit87h<-fitted(Comp2736A87)
plot(fit87h,res87h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropGrass2736 + PropBare2736", pch=16)
Comp2736A89<-glm(Rand_MVC~PropDecid2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A89)
res89h<-resid(Comp2736A89)
fit89h<-fitted(Comp2736A89)
plot(fit89h,res89h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid2736", pch=16)
Comp2736A90<-glm(Rand_MVC~PropConif2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A90)
res90h<-resid(Comp2736A90)
fit90h<-fitted(Comp2736A90)
plot(fit90h,res90h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif2736", pch=16)
Comp2736A91<-glm(Rand_MVC~PropWater2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A91)
res91h<-resid(Comp2736A91)
fit91h<-fitted(Comp2736A91)
plot(fit91h,res91h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater2736", pch=16)
Comp2736A92<-glm(Rand_MVC~PropDev2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A92)
res92h<-resid(Comp2736A92)
fit92h<-fitted(Comp2736A92)
plot(fit92h,res92h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDev2736", pch=16)
Comp2736A93<-glm(Rand_MVC~PropGrass2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A93)
res93h<-resid(Comp2736A93)
fit93h<-fitted(Comp2736A93)
plot(fit93h,res93h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropGrass2736", pch=16)
Comp2736A94<-glm(Rand_MVC~PropShrub2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A94)
res94h<-resid(Comp2736A94)
fit94h<-fitted(Comp2736A94)
plot(fit94h,res94h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropShrub2736", pch=16)
Comp2736A95<-glm(Rand_MVC~PropBare2736, family=binomial(link="logit"), data=spatialall)
summary(Comp2736A95)
res95h<-resid(Comp2736A95)
fit95h<-fitted(Comp2736A95)
plot(fit95h,res95h,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropBare2736", pch=16)

## Used to create Table S6
library(AICcmodavg)
Cand.models <- list( )
Cand.models[[1]]<-glm(Rand_MVC~PropDecid2736 + PropConif2736 + PropWater2736 + PropDev2736 + PropGrass2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[2]]<-glm(Rand_MVC~PropDecid2736 + PropConif2736 + PropDev2736 + PropGrass2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[3]]<-glm(Rand_MVC~PropConif2736 + PropDev2736 + PropGrass2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[4]]<-glm(Rand_MVC~PropWater2736 + PropDev2736 + PropGrass2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[5]]<-glm(Rand_MVC~PropWater2736 + PropDev2736 + PropGrass2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[6]]<-glm(Rand_MVC~PropDev2736 + PropGrass2736 + PropShrub2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[7]]<-glm(Rand_MVC~PropDecid2736 + PropDev2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[8]]<-glm(Rand_MVC~PropDecid2736 + PropGrass2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[9]]<-glm(Rand_MVC~PropConif2736 + PropDev2736 + PropGrass2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[10]]<-glm(Rand_MVC~PropConif2736 + PropDev2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[11]]<-glm(Rand_MVC~PropConif2736 + PropGrass2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[12]]<-glm(Rand_MVC~PropWater2736 + PropDev2736 + PropGrass2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[13]]<-glm(Rand_MVC~PropWater2736 + PropGrass2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[14]]<-glm(Rand_MVC~PropDev2736 + PropGrass2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[15]]<-glm(Rand_MVC~PropDev2736 + PropGrass2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[16]]<-glm(Rand_MVC~PropDev2736 + PropShrub2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[17]]<-glm(Rand_MVC~PropDecid2736 + PropConif2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[18]]<-glm(Rand_MVC~PropDecid2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[19]]<-glm(Rand_MVC~PropConif2736 + PropDev2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[20]]<-glm(Rand_MVC~PropConif2736 + PropGrass2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[21]]<-glm(Rand_MVC~PropConif2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[22]]<-glm(Rand_MVC~PropWater2736 + PropDev2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[23]]<-glm(Rand_MVC~PropWater2736 + PropGrass2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[24]]<-glm(Rand_MVC~PropDev2736 + PropGrass2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[25]]<-glm(Rand_MVC~PropDev2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[26]]<-glm(Rand_MVC~PropDev2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[27]]<-glm(Rand_MVC~PropGrass2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[28]]<-glm(Rand_MVC~PropGrass2736 + PropBare2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[29]]<-glm(Rand_MVC~PropDecid2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[30]]<-glm(Rand_MVC~PropConif2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[31]]<-glm(Rand_MVC~PropWater2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[32]]<-glm(Rand_MVC~PropDev2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[33]]<-glm(Rand_MVC~PropGrass2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[34]]<-glm(Rand_MVC~PropShrub2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[35]]<-glm(Rand_MVC~PropBare2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[36]]<-glm(Rand_MVC~1, family=binomial(link="logit"), data=spatialall)

##create a vector of names to trace back models in set
Modnames <- c("Comp2736A3", "Comp2736A17", "Comp2736A30", "Comp2736A34", "Comp2736A35", "Comp2736A38", 
              "Comp2736A47", "Comp2736A48", "Comp2736A53", "Comp2736A55", "Comp2736A56", "Comp2736A59", 
              "Comp2736A63", "Comp2736A65", "Comp2736A66", "Comp2736A67",  "Comp2736A69", "Comp2736A73", 
              "Comp2736A75", "Comp2736A76", "Comp2736A78", "Comp2736A79", "Comp2736A80", "Comp2736A83", 
              "Comp2736A84", "Comp2736A85", "Comp2736A86", "Comp2736A87", "Comp2736A89", "Comp2736A90", 
              "Comp2736A91", "Comp2736A92", "Comp2736A93", "Comp2736A94", "Comp2736A95", "Null")

##generate AICc table
aictab(cand.set = Cand.models, modnames = Modnames, sort = TRUE)
##round to 4 digits after decimal point and give log-likelihood
print(aictab(cand.set = Cand.models, modnames = Modnames, sort = TRUE),
      digits = 4, LL = TRUE)

Modnames <- data.frame(Names=c("Comp2736A3", "Comp2736A17", "Comp2736A30", "Comp2736A34", "Comp2736A35", "Comp2736A38", 
                               "Comp2736A47", "Comp2736A48", "Comp2736A53", "Comp2736A55", "Comp2736A56", "Comp2736A59", 
                               "Comp2736A63", "Comp2736A65", "Comp2736A66", "Comp2736A67",  "Comp2736A69", "Comp2736A73", 
                               "Comp2736A75", "Comp2736A76", "Comp2736A78", "Comp2736A79", "Comp2736A80", "Comp2736A83", 
                               "Comp2736A84", "Comp2736A85", "Comp2736A86", "Comp2736A87", "Comp2736A89", "Comp2736A90", 
                               "Comp2736A91", "Comp2736A92", "Comp2736A93", "Comp2736A94", "Comp2736A95", "Null"))

##for each model in Modnames run function NagelkerkeR2
library(fmsb)
Nag <- NULL
Nag <- rbind(Nag, data.frame(Nag=sapply(1:nrow(Modnames), function(i) {NagelkerkeR2(Cand.models[[i]])})))
Nag

##for each model in Modnames run deviance explained (null-resid)/null
library(fmsb)
Dev <- NULL
Dev <- rbind(Dev, data.frame(Dev=sapply(1:nrow(Modnames), function(i) {((Cand.models[[i]]$null.deviance-Cand.models[[i]]$deviance)/Cand.models[[i]]$null.deviance)})))
Dev

## Composition Based Models - 5471 Buffer 
Comp5471A1<-glm(Rand_MVC~PropDecid5471 + PropConif5471 + PropWater5471 + PropDev5471 + PropGrass5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A1)
res1i<-resid(Comp5471A1)
fit1i<-fitted(Comp5471A1)
plot(fit1i,res1i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid5471 & PropConif5471 & PropWater5471 & PropDev5471 & PropGrass5471 & PropShrub5471", pch=16)
Comp5471A3<-glm(Rand_MVC~PropDecid5471 + PropConif5471 + PropWater5471 + PropDev5471 + PropGrass5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A3)
res3i<-resid(Comp5471A3)
fit3i<-fitted(Comp5471A3)
plot(fit3i,res3i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid5471 & PropConif5471 & PropWater5471 & PropDev5471 & PropGrass5471", pch=16)
Comp5471A6<-glm(Rand_MVC~PropDecid5471 + PropConif5471 + PropDev5471 + PropGrass5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A6)
res6i<-resid(Comp5471A6)
fit6i<-fitted(Comp5471A6)
plot(fit6i,res6i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid5471 & PropConif5471 & PropDev5471 & PropGrass5471 & PropShrub5471", pch=16)
Comp5471A12<-glm(Rand_MVC~PropConif5471 + PropDev5471 + PropGrass5471 + PropShrub5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A12)
res12i<-resid(Comp5471A12)
fit12i<-fitted(Comp5471A12)
plot(fit12i,res12i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif5471 + PropDev5471 + PropGrass5471 + PropShrub5471 + PropBare5471", pch=16)
Comp5471A13<-glm(Rand_MVC~PropWater5471 + PropDev5471 + PropGrass5471 + PropShrub5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A13)
res13i<-resid(Comp5471A13)
fit13i<-fitted(Comp5471A13)
plot(fit13i,res13i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater5471 + PropDev5471 + PropGrass5471 + PropShrub5471 + PropBare5471", pch=16)
Comp5471A17<-glm(Rand_MVC~PropDecid5471 + PropConif5471 + PropDev5471 + PropGrass5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A17)
res17i<-resid(Comp5471A17)
fit17i<-fitted(Comp5471A17)
plot(fit17i,res17i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid5471 + PropConif5471 + PropDev5471 + PropGrass5471", pch=16)
Comp5471A20<-glm(Rand_MVC~PropDecid5471 + PropWater5471 + PropDev5471 + PropGrass5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A20)
res20i<-resid(Comp5471A20)
fit20i<-fitted(Comp5471A20)
plot(fit20i,res20i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid5471 + PropWater5471 + PropDev5471 + PropGrass5471", pch=16)
Comp5471A30<-glm(Rand_MVC~PropConif5471 + PropDev5471 + PropGrass5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A30)
res30i<-resid(Comp5471A30)
fit30i<-fitted(Comp5471A30)
plot(fit30i,res30i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif5471 + PropDev5471 + PropGrass5471 + PropShrub5471", pch=16)
Comp5471A31<-glm(Rand_MVC~PropConif5471 + PropDev5471 + PropGrass5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A31)
res31i<-resid(Comp5471A31)
fit31i<-fitted(Comp5471A31)
plot(fit31i,res32i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif5471 + PropDev5471 + PropGrass5471 + PropBare5471", pch=16)
Comp5471A32<-glm(Rand_MVC~PropConif5471 + PropDev5471 + PropShrub5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A32)
res32i<-resid(Comp5471A32)
fit32i<-fitted(Comp5471A32)
plot(fit32i,res32i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif5471 + PropDev5471 + PropShrub5471 + PropBare5471", pch=16)
Comp5471A34<-glm(Rand_MVC~PropWater5471 + PropDev5471 + PropGrass5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A34)
res34i<-resid(Comp5471A34)
fit34i<-fitted(Comp5471A34)
plot(fit34i,res34i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater5471 + PropDev5471 + PropGrass5471 + PropShrub5471", pch=16)
Comp5471A35<-glm(Rand_MVC~PropWater5471 + PropDev5471 + PropGrass5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A35)
res35i<-resid(Comp5471A35)
fit35i<-fitted(Comp5471A35)
plot(fit35i,res35i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater5471 + PropDev5471 + PropGrass5471 + PropBare5471", pch=16)
Comp5471A38<-glm(Rand_MVC~PropDev5471 + PropGrass5471 + PropShrub5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A38)
res38i<-resid(Comp5471A38)
fit38i<-fitted(Comp5471A38)
plot(fit38i,res38i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDev5471 + PropGrass5471 + PropShrub5471 + PropBare5471", pch=16)
Comp5471A41<-glm(Rand_MVC~PropDecid5471 + PropConif5471 + PropGrass5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A41)
res41i<-resid(Comp5471A41)
fit41i<-fitted(Comp5471A41)
plot(fit41i,res41i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid5471 + PropConif5471 + PropGrass5471", pch=16)
Comp5471A42<-glm(Rand_MVC~PropDecid5471 + PropConif5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A42)
res42i<-resid(Comp5471A42)
fit42i<-fitted(Comp5471A42)
plot(fit42i,res42i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid5471 + PropConif5471 + PropShrub5471", pch=16)
Comp5471A53<-glm(Rand_MVC~PropConif5471 + PropDev5471 + PropGrass5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A53)
res53i<-resid(Comp5471A53)
fit53i<-fitted(Comp5471A53)
plot(fit53i,res53i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif5471 + PropDev5471 + PropGrass5471", pch=16)
Comp5471A54<-glm(Rand_MVC~PropConif5471 + PropDev5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A54)
res54i<-resid(Comp5471A54)
fit54i<-fitted(Comp5471A54)
plot(fit54i,res54i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif5471 + PropDev5471 + PropShrub5471", pch=16)
Comp5471A55<-glm(Rand_MVC~PropConif5471 + PropDev5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A55)
res55i<-resid(Comp5471A55)
fit55i<-fitted(Comp5471A55)
plot(fit55i,res55i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif5471 + PropDev5471 + PropBare5471", pch=16)
Comp5471A56<-glm(Rand_MVC~PropConif5471 + PropGrass5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A56)
res56i<-resid(Comp5471A56)
fit56i<-fitted(Comp5471A56)
plot(fit56i,res56i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif5471 + PropGrass5471 + PropShrub5471", pch=16)
Comp5471A57<-glm(Rand_MVC~PropConif5471 + PropGrass5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A57)
res57i<-resid(Comp5471A57)
fit57i<-fitted(Comp5471A57)
plot(fit57i,res57i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif5471 + PropGrass5471 + PropBare5471", pch=16)
Comp5471A58<-glm(Rand_MVC~PropConif5471 + PropShrub5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A58)
res58i<-resid(Comp5471A58)
fit58i<-fitted(Comp5471A58)
plot(fit58i,res58i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif5471 + PropShrub5471 + PropBare5471", pch=16)
Comp5471A59<-glm(Rand_MVC~PropWater5471 + PropDev5471 + PropGrass5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A59)
res59i<-resid(Comp5471A59)
fit59i<-fitted(Comp5471A59)
plot(fit59i,res59i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater5471 + PropDev5471 + PropGrass5471", pch=16)
Comp5471A61<-glm(Rand_MVC~PropWater5471 + PropDev5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A61)
res61i<-resid(Comp5471A61)
fit61i<-fitted(Comp5471A61)
plot(fit61i,res61i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater5471 + PropDev5471 + PropBare5471", pch=16)
Comp5471A63<-glm(Rand_MVC~PropWater5471 + PropGrass5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A63)
res63i<-resid(Comp5471A63)
fit63i<-fitted(Comp5471A63)
plot(fit63i,res63i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater5471 + PropGrass5471 + PropBare5471", pch=16)
Comp5471A65<-glm(Rand_MVC~PropDev5471 + PropGrass5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A65)
res65i<-resid(Comp5471A65)
fit65i<-fitted(Comp5471A65)
plot(fit65i,res65i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDev5471 + PropGrass5471 + PropShrub5471", pch=16)
Comp5471A66<-glm(Rand_MVC~PropDev5471 + PropGrass5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A66)
res66i<-resid(Comp5471A66)
fit66i<-fitted(Comp5471A66)
plot(fit66i,res66i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDev5471 + PropGrass5471 + PropBare5471", pch=16)
Comp5471A67<-glm(Rand_MVC~PropDev5471 + PropShrub5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A67)
res67i<-resid(Comp5471A67)
fit67i<-fitted(Comp5471A67)
plot(fit67i,res67i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDev5471 + PropShrub5471 + PropBare5471", pch=16)
Comp5471A68<-glm(Rand_MVC~PropGrass5471 + PropShrub5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A68)
res68i<-resid(Comp5471A68)
fit68i<-fitted(Comp5471A68)
plot(fit68i,res68i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropGrass5471 + PropShrub5471 + PropBare5471", pch=16)
Comp5471A73<-glm(Rand_MVC~PropDecid5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A73)
res73i<-resid(Comp5471A73)
fit73i<-fitted(Comp5471A73)
plot(fit73i,res73i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid5471 + PropShrub5471", pch=16)
Comp5471A75<-glm(Rand_MVC~PropConif5471 + PropDev5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A75)
res75i<-resid(Comp5471A75)
fit75i<-fitted(Comp5471A75)
plot(fit75i,res75i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif5471 + PropDev5471", pch=16)
Comp5471A76<-glm(Rand_MVC~PropConif5471 + PropGrass5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A76)
res76i<-resid(Comp5471A76)
fit76i<-fitted(Comp5471A76)
plot(fit76i,res76i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif5471 + PropGrass5471", pch=16)
Comp5471A77<-glm(Rand_MVC~PropConif5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A77)
res77i<-resid(Comp5471A77)
fit77i<-fitted(Comp5471A77)
plot(fit77i,res77i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif5471 + PropShrub5471", pch=16)
Comp5471A78<-glm(Rand_MVC~PropConif5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A78)
res78i<-resid(Comp5471A78)
fit78i<-fitted(Comp5471A78)
plot(fit78i,res78i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif5471 + PropBare5471", pch=16)
Comp5471A79<-glm(Rand_MVC~PropWater5471 + PropDev5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A79)
res79i<-resid(Comp5471A79)
fit79i<-fitted(Comp5471A79)
plot(fit79i,res79i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater5471 + PropDev5471", pch=16)
Comp5471A80<-glm(Rand_MVC~PropWater5471 + PropGrass5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A80)
res80i<-resid(Comp5471A80)
fit80i<-fitted(Comp5471A80)
plot(fit80i,res80i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater5471 + PropGrass5471", pch=16)
Comp5471A83<-glm(Rand_MVC~PropDev5471 + PropGrass5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A83)
res83i<-resid(Comp5471A83)
fit83i<-fitted(Comp5471A83)
plot(fit83i,res83i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDev5471 + PropGrass5471", pch=16)
Comp5471A84<-glm(Rand_MVC~PropDev5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A84)
res84i<-resid(Comp5471A84)
fit84i<-fitted(Comp5471A84)
plot(fit84i,res84i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDev5471 + PropShrub5471", pch=16)
Comp5471A85<-glm(Rand_MVC~PropDev5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A85)
res85i<-resid(Comp5471A85)
fit85i<-fitted(Comp5471A85)
plot(fit85i,res85i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDev5471 + PropBare5471", pch=16)
Comp5471A86<-glm(Rand_MVC~PropGrass5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A86)
res86i<-resid(Comp5471A86)
fit86i<-fitted(Comp5471A86)
plot(fit86i,res86i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropGrass5471 + PropShrub5471", pch=16)
Comp5471A87<-glm(Rand_MVC~PropGrass5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A87)
res87i<-resid(Comp5471A87)
fit87i<-fitted(Comp5471A87)
plot(fit87i,res87i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropGrass5471 + PropBare5471", pch=16)
Comp5471A88<-glm(Rand_MVC~PropShrub5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A88)
res88i<-resid(Comp5471A88)
fit88i<-fitted(Comp5471A88)
plot(fit88i,res88i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropShrub5471 + PropBare5471", pch=16)
Comp5471A89<-glm(Rand_MVC~PropDecid5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A89)
res89i<-resid(Comp5471A89)
fit89i<-fitted(Comp5471A89)
plot(fit89i,res89i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDecid5471", pch=16)
Comp5471A90<-glm(Rand_MVC~PropConif5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A90)
res90i<-resid(Comp5471A90)
fit90i<-fitted(Comp5471A90)
plot(fit90i,res90i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropConif5471", pch=16)
Comp5471A91<-glm(Rand_MVC~PropWater5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A91)
res91i<-resid(Comp5471A91)
fit91i<-fitted(Comp5471A91)
plot(fit91i,res91i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropWater5471", pch=16)
Comp5471A92<-glm(Rand_MVC~PropDev5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A92)
res92i<-resid(Comp5471A92)
fit92i<-fitted(Comp5471A92)
plot(fit92i,res92i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropDev5471", pch=16)
Comp5471A93<-glm(Rand_MVC~PropGrass5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A93)
res93i<-resid(Comp5471A93)
fit93i<-fitted(Comp5471A93)
plot(fit93i,res93i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropGrass5471", pch=16)
Comp5471A94<-glm(Rand_MVC~PropShrub5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A94)
res94i<-resid(Comp5471A94)
fit94i<-fitted(Comp5471A94)
plot(fit94i,res94i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropShrub5471", pch=16)
Comp5471A95<-glm(Rand_MVC~PropBare5471, family=binomial(link="logit"), data=spatialall)
summary(Comp5471A95)
res95i<-resid(Comp5471A95)
fit95i<-fitted(Comp5471A95)
plot(fit95i,res95i,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC vs Fits\n PropBare5471", pch=16)

## Used to create Table S7
library(AICcmodavg)
Cand.models <- list( )
Cand.models[[1]]<-glm(Rand_MVC~PropDecid5471 + PropConif5471 + PropWater5471 + PropDev5471 + PropGrass5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[2]]<-glm(Rand_MVC~PropDecid5471 + PropConif5471 + PropWater5471 + PropDev5471 + PropGrass5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[3]]<-glm(Rand_MVC~PropDecid5471 + PropConif5471 + PropDev5471 + PropGrass5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[4]]<-glm(Rand_MVC~PropConif5471 + PropDev5471 + PropGrass5471 + PropShrub5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[5]]<-glm(Rand_MVC~PropWater5471 + PropDev5471 + PropGrass5471 + PropShrub5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[6]]<-glm(Rand_MVC~PropDecid5471 + PropConif5471 + PropDev5471 + PropGrass5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[7]]<-glm(Rand_MVC~PropDecid5471 + PropWater5471 + PropDev5471 + PropGrass5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[8]]<-glm(Rand_MVC~PropConif5471 + PropDev5471 + PropGrass5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[9]]<-glm(Rand_MVC~PropConif5471 + PropDev5471 + PropGrass5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[10]]<-glm(Rand_MVC~PropConif5471 + PropDev5471 + PropShrub5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[11]]<-glm(Rand_MVC~PropWater5471 + PropDev5471 + PropGrass5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[12]]<-glm(Rand_MVC~PropWater5471 + PropDev5471 + PropGrass5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[13]]<-glm(Rand_MVC~PropDev5471 + PropGrass5471 + PropShrub5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[14]]<-glm(Rand_MVC~PropDecid5471 + PropConif5471 + PropGrass5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[15]]<-glm(Rand_MVC~PropDecid5471 + PropConif5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[16]]<-glm(Rand_MVC~PropConif5471 + PropDev5471 + PropGrass5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[17]]<-glm(Rand_MVC~PropConif5471 + PropDev5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[18]]<-glm(Rand_MVC~PropConif5471 + PropDev5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[19]]<-glm(Rand_MVC~PropConif5471 + PropGrass5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[20]]<-glm(Rand_MVC~PropConif5471 + PropGrass5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[21]]<-glm(Rand_MVC~PropConif5471 + PropShrub5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[22]]<-glm(Rand_MVC~PropWater5471 + PropDev5471 + PropGrass5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[23]]<-glm(Rand_MVC~PropWater5471 + PropDev5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[24]]<-glm(Rand_MVC~PropWater5471 + PropGrass5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[25]]<-glm(Rand_MVC~PropDev5471 + PropGrass5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[26]]<-glm(Rand_MVC~PropDev5471 + PropGrass5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[27]]<-glm(Rand_MVC~PropDev5471 + PropShrub5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[28]]<-glm(Rand_MVC~PropGrass5471 + PropShrub5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[29]]<-glm(Rand_MVC~PropDecid5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[30]]<-glm(Rand_MVC~PropConif5471 + PropDev5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[31]]<-glm(Rand_MVC~PropConif5471 + PropGrass5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[32]]<-glm(Rand_MVC~PropConif5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[33]]<-glm(Rand_MVC~PropConif5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[34]]<-glm(Rand_MVC~PropWater5471 + PropDev5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[35]]<-glm(Rand_MVC~PropWater5471 + PropGrass5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[36]]<-glm(Rand_MVC~PropDev5471 + PropGrass5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[37]]<-glm(Rand_MVC~PropDev5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[38]]<-glm(Rand_MVC~PropDev5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[39]]<-glm(Rand_MVC~PropGrass5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[40]]<-glm(Rand_MVC~PropGrass5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[41]]<-glm(Rand_MVC~PropShrub5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[42]]<-glm(Rand_MVC~PropDecid5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[43]]<-glm(Rand_MVC~PropConif5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[44]]<-glm(Rand_MVC~PropWater5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[45]]<-glm(Rand_MVC~PropDev5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[46]]<-glm(Rand_MVC~PropGrass5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[47]]<-glm(Rand_MVC~PropShrub5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[48]]<-glm(Rand_MVC~PropBare5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[49]]<-glm(Rand_MVC~1, family=binomial(link="logit"), data=spatialall)

##create a vector of names to trace back models in set
Modnames <- c("Comp5471A1", "Comp5471A3", "Comp5471A6", "Comp5471A12", "Comp5471A13", "Comp5471A17","Comp5471A20",
              "Comp5471A30", "Comp5471A31", "Comp5471A32", "Comp5471A34", "Comp5471A35", "Comp5471A38", "Comp5471A41", "Comp5471A42",
              "Comp5471A53", "Comp5471A54", "Comp5471A55", "Comp5471A56", "Comp5471A57", "Comp5471A58", "Comp5471A59", "Comp5471A61", 
              "Comp5471A63", "Comp5471A65", "Comp5471A66", "Comp5471A67", "Comp5471A68", "Comp5471A73", "Comp5471A75", "Comp5471A76", 
              "Comp5471A77", "Comp5471A78", "Comp5471A79", "Comp5471A80", "Comp5471A83", "Comp5471A84", "Comp5471A85", "Comp5471A86", 
              "Comp5471A87", "Comp5471A88", "Comp5471A89", "Comp5471A90", "Comp5471A91", "Comp5471A92", "Comp5471A93", "Comp5471A94", 
              "Comp5471A95", "Null")


##generate AICc table
aictab(cand.set = Cand.models, modnames = Modnames, sort = TRUE)
##round to 4 digits after decimal point and give log-likelihood
print(aictab(cand.set = Cand.models, modnames = Modnames, sort = TRUE),
      digits = 4, LL = TRUE)

Modnames <- data.frame(Names=c("Comp5471A1", "Comp5471A3", "Comp5471A6", "Comp5471A12", "Comp5471A13", "Comp5471A17","Comp5471A20",
                               "Comp5471A30", "Comp5471A31", "Comp5471A32", "Comp5471A34", "Comp5471A35", "Comp5471A38", "Comp5471A41", "Comp5471A42",
                               "Comp5471A53", "Comp5471A54", "Comp5471A55", "Comp5471A56", "Comp5471A57", "Comp5471A58", "Comp5471A59", "Comp5471A61", 
                               "Comp5471A63", "Comp5471A65", "Comp5471A66", "Comp5471A67", "Comp5471A68", "Comp5471A73", "Comp5471A75", "Comp5471A76", 
                               "Comp5471A77", "Comp5471A78", "Comp5471A79", "Comp5471A80", "Comp5471A83", "Comp5471A84", "Comp5471A85", "Comp5471A86", 
                               "Comp5471A87", "Comp5471A88", "Comp5471A89", "Comp5471A90", "Comp5471A91", "Comp5471A92", "Comp5471A93", "Comp5471A94", 
                               "Comp5471A95", "Null"))

##for each model in Modnames run function NagelkerkeR2
library(fmsb)
Nag <- NULL
Nag <- rbind(Nag, data.frame(Nag=sapply(1:nrow(Modnames), function(i) {NagelkerkeR2(Cand.models[[i]])})))
Nag

##for each model in Modnames run deviance explained (null-resid)/null
library(fmsb)
Dev <- NULL
Dev <- rbind(Dev, data.frame(Dev=sapply(1:nrow(Modnames), function(i) {((Cand.models[[i]]$null.deviance-Cand.models[[i]]$deviance)/Cand.models[[i]]$null.deviance)})))
Dev

## Null model
Null<-glm(Rand_MVC~1, family=binomial(link="logit"), data=spatialall)
summary(Null)
res1j<-resid(Null)
fit1j<-fitted(Null)
plot(fit1j,res1j,ylab="Residuals",xlab="Fitted Values",main="Presence or Absence of MVC Residuals vs Fits\n Null", pch=16)

library(AICcmodavg)
Cand.models <- list( )
Cand.models[[1]]<-glm(Rand_MVC~1, family=binomial(link="logit"), data=spatialall)

##create a vector of names to trace back models in set
Modnames <- c("Null")

##generate AICc table
aictab(cand.set = Cand.models, modnames = Modnames, sort = TRUE)
##round to 4 digits after decimal point and give log-likelihood
print(aictab(cand.set = Cand.models, modnames = Modnames, sort = TRUE),
      digits = 4, LL = TRUE)

Modnames <- data.frame(Names=c("Null"))

##for each model in Modnames run function NagelkerkeR2
library(fmsb)
Nag <- NULL
Nag <- rbind(Nag, data.frame(Nag=sapply(1:nrow(Modnames), function(i) {NagelkerkeR2(Cand.models[[i]])})))
Nag

##for each model in Modnames run deviance explained (null-resid)/null
library(fmsb)
Dev <- NULL
Dev <- rbind(Dev, data.frame(Dev=sapply(1:nrow(Modnames), function(i) {((Cand.models[[i]]$null.deviance-Cand.models[[i]]$deviance)/Cand.models[[i]]$null.deviance)})))
Dev

####################################################################################################################################################

## Combining the top models (delta AICc values of <2) from each of the 8 model groups (10 sections because of the 3 composition based model groups: 500m, 2736m, 5471m) 
## to determine the overall most parsimonious model
## Used to create Table S15

library(AICcmodavg)
Cand.models <- list( )
Cand.models[[1]] <- glm(Rand_MVC~DisTL_m + DisTR_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[2]] <- glm(Rand_MVC~DisFAR_m+ DisTL_m + DisTR_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[3]] <- glm(Rand_MVC~DisRiv_m + DisWet_m + DisOcn_m + DisLak_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[4]] <- glm(Rand_MVC~TerrRugg500, family=binomial(link="logit"), data=spatialall)
Cand.models[[5]] <- glm(Rand_MVC~TerrRugg500 + Aspect, family=binomial(link="logit"), data=spatialall)
Cand.models[[6]] <- glm(Rand_MVC~Slope_mean500, family=binomial(link="logit"), data=spatialall)
Cand.models[[7]] <- glm(Rand_MVC~Slope_mean500 + Aspect, family=binomial(link="logit"), data=spatialall)
Cand.models[[8]] <- glm(Rand_MVC~RdClass + Sinuosity + DisMA_m + DisDevL_m, family=binomial(link="logit"), data=spatialall)
Cand.models[[9]] <- glm(Rand_MVC~VegCtLoc, family=binomial(link="logit"), data=spatialall)
Cand.models[[10]] <- glm(Rand_MVC~MooseDen, family=binomial(link="logit"), data=spatialall)
Cand.models[[11]] <- glm(Rand_MVC~DenFAR2736 + DenRW2736 + DenTL2736 + DenTR2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[12]] <- glm(Rand_MVC~PropConif500 + PropWater500 + PropDev500 + PropGrass500 + PropShrub500, family=binomial(link="logit"), data=spatialall)
Cand.models[[13]] <- glm(Rand_MVC~PropConif500 + PropWater500 + PropDev500 + PropGrass500, family=binomial(link="logit"), data=spatialall)
Cand.models[[14]] <- glm(Rand_MVC~PropConif2736 + PropDev2736 + PropGrass2736 + PropShrub2736, family=binomial(link="logit"), data=spatialall)
Cand.models[[15]] <- glm(Rand_MVC~PropConif5471 + PropDev5471 + PropGrass5471 + PropShrub5471 + PropBare5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[16]] <- glm(Rand_MVC~PropConif5471 + PropDev5471 + PropGrass5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[17]] <- glm(Rand_MVC~PropDecid5471 + PropConif5471 + PropDev5471 + PropGrass5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[18]] <- glm(Rand_MVC~PropDecid5471 + PropConif5471 + PropWater5471 + PropDev5471 + PropGrass5471 + PropShrub5471, family=binomial(link="logit"), data=spatialall)
Cand.models[[19]] <- glm(Rand_MVC~1, family=binomial(link="logit"), data=spatialall)

##create a vector of names to trace back models in set
Modnames <- c("TravelDist7", "TravelDist2", "WaterFeat1", "Terrain7", "Terrain1", "Terrain11", "Terrain4",
              "Road6", "Mitigation1", "MooseDensity1", "TravelDen2", "Comp500A8", "Comp500A24",
              "Comp2736A30", "Comp5471A12", "Comp5471A30", "Comp5471A6", "Comp5471A1", "Null")

##generate AICc table
aictab(cand.set = Cand.models, modnames = Modnames, sort = TRUE)
##round to 4 digits after decimal point and give log-likelihood
print(aictab(cand.set = Cand.models, modnames = Modnames, sort = TRUE),
      digits = 4, LL = TRUE)

Modnames <- data.frame(Names=c("TravelDist7", "TravelDist2", "WaterFeat1", "Terrain7", "Terrain1", "Terrain11", "Terrain4",
                               "Road6", "Mitigation1", "MooseDensity1", "TravelDen2", "Comp500A8", "Comp500A24",
                               "Comp2736A30", "Comp5471A12", "Comp5471A30", "Comp5471A6", "Comp5471A1", "Null"))

##for each model in Modnames run function NagelkerkeR2
library(fmsb)
Nag <- NULL
Nag <- rbind(Nag, data.frame(Nag=sapply(1:nrow(Modnames), function(i) {NagelkerkeR2(Cand.models[[i]])})))
Nag

##for each model in Modnames run deviance explained (null-resid)/null
library(fmsb)
Dev <- NULL
Dev <- rbind(Dev, data.frame(Dev=sapply(1:nrow(Modnames), function(i) {((Cand.models[[i]]$null.deviance-Cand.models[[i]]$deviance)/Cand.models[[i]]$null.deviance)})))
Dev

####################################################################################################################################################

## K-fold cross validation --> accross model comparison for models with delta AICc <2
## Used to create Table S16
library(boot)
## Adjusted cross-validation estimate of error with cost function included
## The response variable is binary variable therefore the cost function below was applied
cost <- function(r, pi = 0) mean(abs(r-pi) > 0.5)

cv.glm(data=spatialall, glmfit=Road6, cost, K=10)
cv.glm(data=spatialall, glmfit=Mitigation1, cost, K=10)
cv.glm(data=spatialall, glmfit=TravelDen2, cost, K=10)
cv.glm(data=spatialall, glmfit=TravelDist7, cost, K=10)
cv.glm(data=spatialall, glmfit=TravelDist2, cost, K=10)
cv.glm(data=spatialall, glmfit=WaterFeat1, cost, K=10)
cv.glm(data=spatialall, glmfit=Comp5471A12, cost, K=10)
cv.glm(data=spatialall, glmfit=Comp5471A30, cost, K=10)
cv.glm(data=spatialall, glmfit=Comp5471A6, cost, K=10)
cv.glm(data=spatialall, glmfit=Comp5471A1, cost, K=10)
cv.glm(data=spatialall, glmfit=Comp2736A30, cost, K=10)
cv.glm(data=spatialall, glmfit=Comp500A8, cost, K=10)
cv.glm(data=spatialall, glmfit=Terrain7, cost, K=10)
cv.glm(data=spatialall, glmfit=Terrain1, cost, K=10)
cv.glm(data=spatialall, glmfit=Terrain11, cost, K=10)
cv.glm(data=spatialall, glmfit=Comp500A24, cost, K=10)
cv.glm(data=spatialall, glmfit=Terrain4, cost, K=10)
cv.glm(data=spatialall, glmfit=MooseDensity1, cost, K=10)
